@@ -14,9 +14,10 @@
 
 #pragma once
 
+#include "../microbench.hpp"
+
 #include <iostream>
 
-#include "../microbench.hpp"
 #include <bsoncxx/json.hpp>
 #include <bsoncxx/types.hpp>
 
@@ -27,9 +28,7 @@ class bson_encoding : public microbench {
     bson_encoding() = delete;
 
     bson_encoding(std::string name, double task_size, std::string json_file)
-        : microbench{std::move(name),
-                     task_size,
-                     std::set<benchmark_type>{benchmark_type::bson_bench}},
+        : microbench{std::move(name), task_size, std::set<benchmark_type>{benchmark_type::bson_bench}},
           _json_file{std::move(json_file)} {}
 
    protected:
@@ -63,4 +62,4 @@ void bson_encoding::task() {
 }
 
 void bson_encoding::teardown() {}
-}  // namespace benchmark
+} // namespace benchmark
