@@ -19,6 +19,7 @@
 #include <bsoncxx/builder/basic/document.hpp>
 #include <bsoncxx/builder/basic/kvp.hpp>
 #include <bsoncxx/stdx/optional.hpp>
+
 #include <mongocxx/client.hpp>
 #include <mongocxx/instance.hpp>
 #include <mongocxx/uri.hpp>
@@ -33,10 +34,7 @@ class insert_one : public microbench {
     insert_one() = delete;
 
     insert_one(std::string name, double task_size, std::int32_t iter, std::string json_file)
-        : microbench{std::move(name),
-                     task_size,
-                     std::set<benchmark_type>{benchmark_type::single_bench,
-                                              benchmark_type::write_bench}},
+        : microbench{std::move(name), task_size, std::set<benchmark_type>{benchmark_type::single_bench, benchmark_type::write_bench}},
           _conn{mongocxx::uri{}},
           _iter{iter},
           _file_name{std::move(json_file)} {}
@@ -80,4 +78,4 @@ void insert_one::task() {
 void insert_one::teardown() {
     _conn["perftest"].drop();
 }
-}  // namespace benchmark
+} // namespace benchmark
