@@ -18,6 +18,7 @@
 
 #include <bsoncxx/builder/basic/document.hpp>
 #include <bsoncxx/builder/basic/kvp.hpp>
+
 #include <mongocxx/client.hpp>
 #include <mongocxx/instance.hpp>
 #include <mongocxx/uri.hpp>
@@ -30,9 +31,7 @@ using bsoncxx::builder::basic::make_document;
 class run_command : public microbench {
    public:
     run_command()
-        : microbench{"TestRunCommand",
-                     0.13,
-                     std::set<benchmark_type>{benchmark_type::run_command_bench}},
+        : microbench{"TestRunCommand", 0.13, std::set<benchmark_type>{benchmark_type::run_command_bench}},
           _conn{mongocxx::uri{}} {
         _db = _conn["perftest"];
     }
@@ -50,4 +49,4 @@ void run_command::task() {
         _db.run_command(command.view());
     }
 }
-}  // namespace benchmark
+} // namespace benchmark
