@@ -26,16 +26,16 @@ namespace {
 void example() {
     try {
         bsoncxx::document::element e;
-        bsoncxx::types::bson_value::view v = e.get_value();  // Throws.
+        bsoncxx::types::bson_value::view v = e.get_value(); // Throws.
 
         EXPECT(false && "should not reach this point");
-    } catch (const bsoncxx::exception& ex) {
+    } catch (bsoncxx::exception const& ex) {
         EXPECT(ex.code() == bsoncxx::error_code::k_unset_element);
     }
 }
 // [Example]
 
-}  // namespace
+} // namespace
 
 RUNNER_REGISTER_COMPONENT() {
     example();
