@@ -28,16 +28,16 @@ void example() {
     mongocxx::collection coll;
 
     try {
-        auto name = coll.name();  // DO NOT DO THIS. Throws.
+        auto name = coll.name(); // DO NOT DO THIS. Throws.
 
         EXPECT(false && "should not reach this point");
-    } catch (const mongocxx::exception& ex) {
+    } catch (mongocxx::exception const& ex) {
         EXPECT(ex.code() == mongocxx::error_code::k_invalid_collection_object);
     }
 }
 // [Example]
 
-}  // namespace
+} // namespace
 
 RUNNER_REGISTER_COMPONENT_WITH_INSTANCE() {
     example();
