@@ -29,10 +29,10 @@ void example() {
         EXPECT(&mongocxx::instance::current() == &instance);
 
         try {
-            mongocxx::instance another_instance;  // Throws.
+            mongocxx::instance another_instance; // Throws.
 
             EXPECT(false && "should not reach this point");
-        } catch (const mongocxx::exception& ex) {
+        } catch (mongocxx::exception const& ex) {
             EXPECT(ex.code() == mongocxx::error_code::k_cannot_recreate_instance);
         }
 
@@ -41,7 +41,7 @@ void example() {
 }
 // [Example]
 
-}  // namespace
+} // namespace
 
 RUNNER_REGISTER_FORKING_COMPONENT() {
     example();
