@@ -29,7 +29,7 @@ int EXAMPLES_CDECL main() {
     decimal128 d128;
     try {
         d128 = decimal128{"1.234E+3456"};
-    } catch (const bsoncxx::exception&) {
+    } catch (bsoncxx::exception const&) {
         // The example won't fail, but in general, arbitrary strings
         // might not convert properly.
         return EXIT_FAILURE;
