@@ -1,4 +1,4 @@
-// Copyright 2015 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -19,22 +19,25 @@
 #include <bsoncxx/builder/basic/document.hpp>
 #include <bsoncxx/builder/basic/kvp.hpp>
 #include <bsoncxx/json.hpp>
-#include <bsoncxx/stdx/make_unique.hpp>
+
 #include <mongocxx/client.hpp>
 #include <mongocxx/instance.hpp>
 #include <mongocxx/logger.hpp>
 #include <mongocxx/options/client.hpp>
 #include <mongocxx/uri.hpp>
 
+#include <examples/macros.hh>
+
 namespace {
 
 class logger final : public mongocxx::logger {
    public:
     explicit logger(std::ostream* stream) : _stream(stream) {}
 
-    void operator()(mongocxx::log_level level,
-                    bsoncxx::stdx::string_view domain,
-                    bsoncxx::stdx::string_view message) noexcept override {
+    void operator()(
+        mongocxx::log_level level,
+        bsoncxx::stdx::string_view domain,
+        bsoncxx::stdx::string_view message) noexcept override {
         if (level >= mongocxx::log_level::k_trace)
             return;
         *_stream << '[' << mongocxx::to_string(level) << '@' << domain << "] " << message << '\n';
@@ -44,19 +47,24 @@ class logger final : public mongocxx::logger {
     std::ostream* const _stream;
 };
 
-}  // namespace
+// Use `std::make_unique` with C++14 and newer.
+std::unique_ptr<logger> make_logger() {
+    return std::unique_ptr<logger>(new logger(&std::cout));
+}
 
-int main(int argc, char* argv[]) {
+} // namespace
+
+int EXAMPLES_CDECL main(int argc, char* argv[]) {
     using bsoncxx::builder::basic::kvp;
     using bsoncxx::builder::basic::make_document;
 
     // The mongocxx::instance constructor and destructor initialize and shut down the driver,
     // respectively. Therefore, a mongocxx::instance must be created before using the driver and
     // must remain alive for as long as the driver is in use.
-    mongocxx::instance inst{bsoncxx::stdx::make_unique<logger>(&std::cout)};
+    mongocxx::instance inst{make_logger()};
 
     try {
-        const auto uri = mongocxx::uri{(argc >= 2) ? argv[1] : mongocxx::uri::k_default_uri};
+        auto const uri = mongocxx::uri{(argc >= 2) ? argv[1] : mongocxx::uri::k_default_uri};
 
         mongocxx::options::client client_options;
         if (uri.tls()) {
@@ -83,7 +91,7 @@ int main(int argc, char* argv[]) {
 
         return EXIT_SUCCESS;
 
-    } catch (const std::exception& xcp) {
+    } catch (std::exception const& xcp) {
         std::cout << "connection failed: " << xcp.what() << "\n";
         return EXIT_FAILURE;
     }
