@@ -1,4 +1,4 @@
-// Copyright 2017 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -17,15 +17,18 @@
 #include <bsoncxx/builder/basic/document.hpp>
 #include <bsoncxx/builder/basic/kvp.hpp>
 #include <bsoncxx/json.hpp>
+
 #include <mongocxx/client.hpp>
 #include <mongocxx/instance.hpp>
 #include <mongocxx/options/find.hpp>
 #include <mongocxx/uri.hpp>
 
+#include <examples/macros.hh>
+
 using bsoncxx::builder::basic::kvp;
 using bsoncxx::builder::basic::make_document;
 
-int main(int, char**) {
+int EXAMPLES_CDECL main() {
     // The mongocxx::instance constructor and destructor initialize and shut down the driver,
     // respectively. Therefore, a mongocxx::instance must be created before using the driver and
     // must remain alive for as long as the driver is in use.
@@ -36,8 +39,7 @@ int main(int, char**) {
     coll.drop();
 
     // Insert a test document
-    auto result =
-        coll.insert_one(make_document(kvp("user info", make_document(kvp("user name", "Joe")))));
+    auto result = coll.insert_one(make_document(kvp("user info", make_document(kvp("user name", "Joe")))));
     std::cout << "Inserted " << result->inserted_id().get_oid().value.to_string() << std::endl;
 
     // Create the find options with the projection
