@@ -15,7 +15,6 @@
 #include <algorithm>
 #include <cstdint>
 #include <iostream>
-#include <random>
 
 #include <bsoncxx/builder/basic/document.hpp>
 #include <bsoncxx/builder/basic/kvp.hpp>
@@ -48,26 +47,27 @@ using bsoncxx::types::bson_value::make_value;
 
 using namespace mongocxx;
 
-const int kKeyLength = 96;
+int const kKeyLength = 96;
 
 int EXAMPLES_CDECL main() {
     instance inst{};
 
-    // This must be the same master key that was used to create
-    // the encryption key; here, we use a random key as a placeholder.
-    std::uint8_t key_storage[kKeyLength];
-    std::generate_n(key_storage, kKeyLength, []() {
-        return static_cast<std::uint8_t>(std::rand() % UINT8_MAX);
-    });
-    bsoncxx::types::b_binary local_master_key{
-        bsoncxx::binary_sub_type::k_binary, kKeyLength, key_storage};
-
-    auto kms_providers = document{} << "local" << open_document << "key" << local_master_key
-                                    << close_document << finalize;
-
-    class client key_vault_client {
-        uri {}
+    // This must be the same master key that was used to create the encryption key.
+    // An arbitrary key is used as a placeholder for this example.
+    std::uint8_t const key_storage[kKeyLength]{
+        0x45, 0xA3, 0x5B, 0xC8, 0x91, 0x76, 0x2E, 0x0F, 0x34, 0x6A, 0xD1, 0xB8, 0x55, 0x9C, 0xEA, 0x1F,
+        0x88, 0x12, 0x6D, 0x3B, 0x75, 0x2A, 0xF0, 0x97, 0x41, 0xE3, 0x5C, 0xB9, 0x66, 0x0D, 0xAF, 0x52,
+        0x23, 0xC4, 0x8E, 0x19, 0x74, 0xAB, 0x2F, 0xD0, 0x39, 0x6B, 0x84, 0xFC, 0x14, 0x7E, 0x93, 0x27,
+        0x5D, 0x86, 0x1C, 0xA8, 0x72, 0x30, 0xB7, 0x4F, 0x09, 0xE1, 0xCA, 0x53, 0x2D, 0x94, 0xBA, 0x68,
+        0x0E, 0xF5, 0x48, 0x16, 0x7F, 0xAE, 0x21, 0x6C, 0x9D, 0x82, 0x0B, 0xF2, 0x5A, 0x37, 0xCC, 0x18,
+        0x4A, 0x6E, 0x95, 0xBD, 0x33, 0x57, 0xA1, 0x08, 0xDF, 0x20, 0x69, 0xE7, 0x12, 0x8B, 0xF4, 0x3D,
     };
+    bsoncxx::types::b_binary local_master_key{bsoncxx::binary_sub_type::k_binary, kKeyLength, key_storage};
+
+    auto kms_providers = document{} << "local" << open_document << "key" << local_master_key << close_document
+                                    << finalize;
+
+    class client key_vault_client{uri{}};
     auto key_vault = key_vault_client["keyvault"]["datakeys"];
 
     // Ensure that two data keys cannot share the same keyAltName by adding
@@ -76,8 +76,7 @@ int EXAMPLES_CDECL main() {
 
     mongocxx::options::index index_options{};
     index_options.unique(true);
-    auto expression = document{} << "keyAltNames" << open_document << "$exists" << true
-                                 << close_document << finalize;
+    auto expression = document{} << "keyAltNames" << open_document << "$exists" << true << close_document << finalize;
     index_options.partial_filter_expression(expression.view());
     key_vault.create_index(make_document(kvp("keyAltNames", 1)), index_options);
 
@@ -93,13 +92,12 @@ int EXAMPLES_CDECL main() {
     auto data_key_id = client_encryption.create_data_key("local");
 
     // Create a new json schema for the encryptedField.
-    auto json_schema = document{} << "properties" << open_document << "encryptedField"
-                                  << open_document << "encrypt" << open_document << "keyId"
-                                  << open_array << data_key_id << close_array << "bsonType"
+    auto json_schema = document{} << "properties" << open_document << "encryptedField" << open_document << "encrypt"
+                                  << open_document << "keyId" << open_array << data_key_id << close_array << "bsonType"
                                   << "string"
                                   << "algorithm"
-                                  << "AEAD_AES_256_CBC_HMAC_SHA_512-Deterministic" << close_document
-                                  << close_document << close_document << "bsonType"
+                                  << "AEAD_AES_256_CBC_HMAC_SHA_512-Deterministic" << close_document << close_document
+                                  << close_document << "bsonType"
                                   << "object" << finalize;
 
     // Set up auto encryption opts.
@@ -110,9 +108,7 @@ int EXAMPLES_CDECL main() {
     // Create a client with auto encryption enabled.
     options::client client_opts{};
     client_opts.auto_encryption_opts(std::move(auto_encrypt_opts));
-    class client client {
-        uri{}, std::move(client_opts)
-    };
+    class client client{uri{}, std::move(client_opts)};
 
     auto db = client["test"];
 
@@ -125,8 +121,8 @@ int EXAMPLES_CDECL main() {
     // Create the collection with the encryption JSON Schema.
     auto cmd = document{} << "create"
                           << "coll"
-                          << "validator" << open_document << "$jsonSchema" << json_schema.view()
-                          << close_document << finalize;
+                          << "validator" << open_document << "$jsonSchema" << json_schema.view() << close_document
+                          << finalize;
     db.run_command(cmd.view());
 
     auto coll = db["coll"];
@@ -138,9 +134,7 @@ int EXAMPLES_CDECL main() {
 
     std::cout << "Decrypted document: " << bsoncxx::to_json(*res) << std::endl;
 
-    class client unencrypted_client {
-        uri {}
-    };
+    class client unencrypted_client{uri{}};
     res = unencrypted_client["test"]["coll"].find_one({});
 
     std::cout << "Encrypted document: " << bsoncxx::to_json(*res) << std::endl;
@@ -149,7 +143,7 @@ int EXAMPLES_CDECL main() {
         // Inserting via the unencrypted client fails, because the server
         // requires that the encryptedField actually be encrypted.
         unencrypted_client["test"]["coll"].insert_one(to_insert.view());
-    } catch (const std::exception& e) {
+    } catch (std::exception const& e) {
         std::cout << "Unencrypted insert failed: " << e.what() << std::endl;
     }
 }
