@@ -1,4 +1,4 @@
-// Copyright 2015 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -22,13 +22,29 @@
 #include <bsoncxx/config/prelude.hpp>
 
 namespace bsoncxx {
-inline namespace v_noabi {
+namespace v_noabi {
 namespace array {
 
-using view_or_value = bsoncxx::view_or_value<array::view, array::value>;
+///
+/// Equivalent to `v_noabi::view_or_value<v_noabi::array::view, v_noabi::array::value>`.
+///
+using view_or_value = v_noabi::view_or_value<view, value>;
 
-}  // namespace array
-}  // namespace v_noabi
-}  // namespace bsoncxx
+} // namespace array
+} // namespace v_noabi
+} // namespace bsoncxx
+
+namespace bsoncxx {
+namespace array {
+
+using ::bsoncxx::v_noabi::array::view_or_value;
+
+} // namespace array
+} // namespace bsoncxx
 
 #include <bsoncxx/config/postlude.hpp>
+
+///
+/// @file
+/// Provides @ref bsoncxx::v_noabi::array::view_or_value.
+///
