@@ -15,6 +15,7 @@
 #pragma once
 
 #include <bsoncxx/builder/basic/sub_array.hpp>
+#include <bsoncxx/builder/basic/sub_binary.hpp>
 #include <bsoncxx/builder/basic/sub_document.hpp>
 #include <bsoncxx/stdx/type_traits.hpp>
 
@@ -27,25 +28,32 @@ namespace basic {
 namespace impl {
 
 template <typename T>
-detail::requires_t<void, detail::is_invocable<T, sub_document>>  //
-generic_append(core* core, T&& func) {
+detail::requires_t<void, detail::is_invocable<T, sub_document>> generic_append(core* core, T&& func) {
     core->open_document();
-    detail::invoke(std::forward<T>(func), sub_document(core));
+    detail::invoke(std::forward<T>(func), sub_document{core});
     core->close_document();
 }
 
-template <typename T, typename Placeholder = void>  // placeholder 'void' for VS2015 compat
-detail::requires_t<void, detail::is_invocable<T, sub_array>>  //
-generic_append(core* core, T&& func) {
+template <typename T, typename Placeholder = void> // placeholder 'void' for VS2015 compat
+detail::requires_t<void, detail::is_invocable<T, sub_array>> generic_append(core* core, T&& func) {
     core->open_array();
-    detail::invoke(std::forward<T>(func), sub_array(core));
+    detail::invoke(std::forward<T>(func), sub_array{core});
     core->close_array();
 }
 
+template <typename T>
+detail::requires_t<void, detail::is_invocable<T, sub_binary>> generic_append(core* core, T&& func) {
+    // Opened by the user invoking `sub_binary::allocate()` in `func`.
+    detail::invoke(std::forward<T>(func), sub_binary{core});
+    core->close_binary();
+}
+
 template <typename T, typename = void, typename = void>
-detail::requires_not_t<void,  //
-                       detail::is_invocable<T, sub_document>,
-                       detail::is_invocable<T, sub_array>>
+detail::requires_not_t<
+    void,
+    detail::is_invocable<T, sub_document>,
+    detail::is_invocable<T, sub_array>,
+    detail::is_invocable<T, sub_binary>>
 generic_append(core* core, T&& t) {
     core->append(std::forward<T>(t));
 }
@@ -55,11 +63,11 @@ void value_append(core* core, T&& t) {
     generic_append(core, std::forward<T>(t));
 }
 
-}  // namespace impl
-}  // namespace basic
-}  // namespace builder
-}  // namespace v_noabi
-}  // namespace bsoncxx
+} // namespace impl
+} // namespace basic
+} // namespace builder
+} // namespace v_noabi
+} // namespace bsoncxx
 
 #include <bsoncxx/config/postlude.hpp>
 
