@@ -24,10 +24,10 @@ namespace stream {
 template <class base = closed_context>
 class key_context;
 
-}  // namespace stream
-}  // namespace builder
-}  // namespace v_noabi
-}  // namespace bsoncxx
+} // namespace stream
+} // namespace builder
+} // namespace v_noabi
+} // namespace bsoncxx
 
 namespace bsoncxx {
 namespace builder {
@@ -35,26 +35,11 @@ namespace stream {
 
 using ::bsoncxx::v_noabi::builder::stream::key_context;
 
-}  // namespace stream
-}  // namespace builder
-}  // namespace bsoncxx
+} // namespace stream
+} // namespace builder
+} // namespace bsoncxx
 
 ///
 /// @file
 /// Declares @ref bsoncxx::v_noabi::builder::stream::key_context.
 ///
-
-#if defined(BSONCXX_PRIVATE_DOXYGEN_PREPROCESSOR)
-
-namespace bsoncxx {
-namespace builder {
-namespace stream {
-
-/// @ref bsoncxx::v_noabi::builder::stream::key_context
-class key_context {};
-
-}  // namespace stream
-}  // namespace builder
-}  // namespace bsoncxx
-
-#endif  // defined(BSONCXX_PRIVATE_DOXYGEN_PREPROCESSOR)
