@@ -1,4 +1,3 @@
-
 // Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
@@ -31,8 +30,9 @@ namespace builder {
 namespace stream {
 
 ///
-/// A stream context which expects a key, which can later be followed by
-/// value, then more key/value pairs.
+/// A stream context which expects a key.
+///
+/// This can later be followed by value, then more key/value pairs.
 ///
 /// The template argument can be used to hold additional information about
 /// containing documents or arrays. I.e. value_context<> implies that this
@@ -69,7 +69,7 @@ class key_context {
     /// key.
     ///
     template <std::size_t n>
-    value_context<key_context> operator<<(const char (&v)[n]) {
+    value_context<key_context> operator<<(char const (&v)[n]) {
         _core->key_view(stdx::string_view{v, n - 1});
         return value_context<key_context>(_core);
     }
@@ -113,8 +113,7 @@ class key_context {
     ///   The callback to invoke
     ///
     template <typename T>
-    detail::requires_t<key_context&, detail::is_invocable<T, key_context>>  //
-    operator<<(T&& func) {
+    detail::requires_t<key_context&, detail::is_invocable<T, key_context>> operator<<(T&& func) {
         detail::invoke(std::forward<T>(func), *this);
         return *this;
     }
@@ -130,9 +129,10 @@ class key_context {
     /// @return A value type which holds the complete bson document.
     ///
     template <typename T>
-    detail::requires_t<bsoncxx::v_noabi::document::value,
-                       std::is_same<base, closed_context>,
-                       detail::is_alike<T, finalize_type>>
+    detail::requires_t<
+        bsoncxx::v_noabi::document::value,
+        std::is_same<base, closed_context>,
+        detail::is_alike<T, finalize_type>>
     operator<<(T&&) {
         return _core->extract_document();
     }
@@ -156,7 +156,7 @@ class key_context {
     ///
     /// The argument must be a close_document_type token (it is otherwise ignored).
     ///
-    base operator<<(const close_document_type) {
+    base operator<<(close_document_type const) {
         _core->close_document();
         return unwrap();
     }
@@ -177,10 +177,10 @@ class key_context {
     core* _core;
 };
 
-}  // namespace stream
-}  // namespace builder
-}  // namespace v_noabi
-}  // namespace bsoncxx
+} // namespace stream
+} // namespace builder
+} // namespace v_noabi
+} // namespace bsoncxx
 
 #include <bsoncxx/config/postlude.hpp>
 
