@@ -23,10 +23,10 @@ namespace stream {
 
 class single_context;
 
-}  // namespace stream
-}  // namespace builder
-}  // namespace v_noabi
-}  // namespace bsoncxx
+} // namespace stream
+} // namespace builder
+} // namespace v_noabi
+} // namespace bsoncxx
 
 namespace bsoncxx {
 namespace builder {
@@ -34,26 +34,11 @@ namespace stream {
 
 using ::bsoncxx::v_noabi::builder::stream::single_context;
 
-}  // namespace stream
-}  // namespace builder
-}  // namespace bsoncxx
+} // namespace stream
+} // namespace builder
+} // namespace bsoncxx
 
 ///
 /// @file
 /// Declares @ref bsoncxx::v_noabi::builder::stream::single_context.
 ///
-
-#if defined(BSONCXX_PRIVATE_DOXYGEN_PREPROCESSOR)
-
-namespace bsoncxx {
-namespace builder {
-namespace stream {
-
-/// @ref bsoncxx::v_noabi::builder::stream::single_context
-class single_context {};
-
-}  // namespace stream
-}  // namespace builder
-}  // namespace bsoncxx
-
-#endif  // defined(BSONCXX_PRIVATE_DOXYGEN_PREPROCESSOR)
