@@ -24,10 +24,10 @@ namespace stream {
 template <class base>
 class value_context;
 
-}  // namespace stream
-}  // namespace builder
-}  // namespace v_noabi
-}  // namespace bsoncxx
+} // namespace stream
+} // namespace builder
+} // namespace v_noabi
+} // namespace bsoncxx
 
 namespace bsoncxx {
 namespace builder {
@@ -35,9 +35,9 @@ namespace stream {
 
 using ::bsoncxx::v_noabi::builder::stream::value_context;
 
-}  // namespace stream
-}  // namespace builder
-}  // namespace bsoncxx
+} // namespace stream
+} // namespace builder
+} // namespace bsoncxx
 
 #include <bsoncxx/config/postlude.hpp>
 
@@ -45,18 +45,3 @@ using ::bsoncxx::v_noabi::builder::stream::value_context;
 /// @file
 /// Declares @ref bsoncxx::v_noabi::builder::stream::value_context.
 ///
-
-#if defined(BSONCXX_PRIVATE_DOXYGEN_PREPROCESSOR)
-
-namespace bsoncxx {
-namespace builder {
-namespace stream {
-
-/// @ref bsoncxx::v_noabi::builder::stream::value_context
-class value_context {};
-
-}  // namespace stream
-}  // namespace builder
-}  // namespace bsoncxx
-
-#endif  // defined(BSONCXX_PRIVATE_DOXYGEN_PREPROCESSOR)
