@@ -29,17 +29,17 @@ namespace document {
 ///
 using view_or_value = v_noabi::view_or_value<v_noabi::document::view, v_noabi::document::value>;
 
-}  // namespace document
-}  // namespace v_noabi
-}  // namespace bsoncxx
+} // namespace document
+} // namespace v_noabi
+} // namespace bsoncxx
 
 namespace bsoncxx {
 namespace document {
 
 using ::bsoncxx::v_noabi::document::view_or_value;
 
-}  // namespace document
-}  // namespace bsoncxx
+} // namespace document
+} // namespace bsoncxx
 
 #include <bsoncxx/config/postlude.hpp>
 
@@ -47,16 +47,3 @@ using ::bsoncxx::v_noabi::document::view_or_value;
 /// @file
 /// Provides @ref bsoncxx::v_noabi::document::view_or_value.
 ///
-
-#if defined(BSONCXX_PRIVATE_DOXYGEN_PREPROCESSOR)
-
-namespace bsoncxx {
-namespace document {
-
-/// @ref bsoncxx::v_noabi::document::view_or_value
-class view_or_value {};
-
-}  // namespace document
-}  // namespace bsoncxx
-
-#endif  // defined(BSONCXX_PRIVATE_DOXYGEN_PREPROCESSOR)
