@@ -21,27 +21,16 @@ namespace v_noabi {
 
 enum class ExtendedJsonMode : std::uint8_t;
 
-}  // namespace v_noabi
-}  // namespace bsoncxx
+} // namespace v_noabi
+} // namespace bsoncxx
 
 namespace bsoncxx {
 
 using ::bsoncxx::v_noabi::ExtendedJsonMode;
 
-}  // namespace bsoncxx
+} // namespace bsoncxx
 
 ///
 /// @file
 /// Declares @ref bsoncxx::v_noabi::ExtendedJsonMode.
 ///
-
-#if defined(BSONCXX_PRIVATE_DOXYGEN_PREPROCESSOR)
-
-namespace bsoncxx {
-
-/// @ref bsoncxx::v_noabi::ExtendedJsonMode
-enum class ExtendedJsonMode {};
-
-}  // namespace bsoncxx
-
-#endif  // defined(BSONCXX_PRIVATE_DOXYGEN_PREPROCESSOR)
