@@ -28,13 +28,13 @@ namespace v_noabi {
 namespace string {
 
 ///
-/// Class representing a view-or-value variant type for strings.
+/// A view-or-value variant type for strings.
 ///
 /// @par Derived From
 /// - @ref bsoncxx::v_noabi::view_or_value<stdx::string_view, std::string>
 ///
 /// This class adds several string-specific methods to the bsoncxx::v_noabi::view_or_value template:
-/// - a constructor overload for const char*
+/// - a constructor overload for char const*
 /// - a constructor overload for std::string by l-value reference
 /// - a safe c_str() operation to return null-terminated c-style strings.
 ///
@@ -57,7 +57,7 @@ class view_or_value : public bsoncxx::v_noabi::view_or_value<stdx::string_view,
     ///
     /// @param str A null-terminated string
     ///
-    view_or_value(const char* str)
+    view_or_value(char const* str)
         : bsoncxx::v_noabi::view_or_value<stdx::string_view, std::string>(stdx::string_view(str)) {}
 
     ///
@@ -70,7 +70,7 @@ class view_or_value : public bsoncxx::v_noabi::view_or_value<stdx::string_view,
     ///
     /// @param str A std::string l-value reference.
     ///
-    view_or_value(const std::string& str)
+    view_or_value(std::string const& str)
         : bsoncxx::v_noabi::view_or_value<stdx::string_view, std::string>(stdx::string_view(str)) {}
 
     ///
@@ -90,42 +90,42 @@ class view_or_value : public bsoncxx::v_noabi::view_or_value<stdx::string_view,
     /// guaranteed to return a null-terminated string unless it is used in
     /// combination with terminated().
     ///
-    /// @return A const char* of this string.
+    /// @return A char const* of this string.
     ///
-    BSONCXX_ABI_EXPORT_CDECL(const char*) data() const;
+    BSONCXX_ABI_EXPORT_CDECL(char const*) data() const;
 };
 
 ///
-/// Comparison operators for comparing string::view_or_value directly with `const char*`.
+/// Comparison operators for comparing string::view_or_value directly with `char const*`.
 ///
 /// @{
 
 /// @relatesalso bsoncxx::v_noabi::string::view_or_value
-inline bool operator==(const view_or_value& lhs, const char* rhs) {
+inline bool operator==(view_or_value const& lhs, char const* rhs) {
     return lhs.view() == stdx::string_view(rhs);
 }
 
 /// @relatesalso bsoncxx::v_noabi::string::view_or_value
-inline bool operator!=(const view_or_value& lhs, const char* rhs) {
+inline bool operator!=(view_or_value const& lhs, char const* rhs) {
     return !(lhs == rhs);
 }
 
 /// @relatesalso bsoncxx::v_noabi::string::view_or_value
-inline bool operator==(const char* lhs, const view_or_value& rhs) {
+inline bool operator==(char const* lhs, view_or_value const& rhs) {
     return rhs == lhs;
 }
 
 /// @relatesalso bsoncxx::v_noabi::string::view_or_value
-inline bool operator!=(const char* lhs, const view_or_value& rhs) {
+inline bool operator!=(char const* lhs, view_or_value const& rhs) {
     return !(rhs == lhs);
 }
 
 /// @}
 ///
 
-}  // namespace string
-}  // namespace v_noabi
-}  // namespace bsoncxx
+} // namespace string
+} // namespace v_noabi
+} // namespace bsoncxx
 
 namespace bsoncxx {
 namespace string {
@@ -133,8 +133,8 @@ namespace string {
 using ::bsoncxx::v_noabi::string::operator==;
 using ::bsoncxx::v_noabi::string::operator!=;
 
-}  // namespace string
-}  // namespace bsoncxx
+} // namespace string
+} // namespace bsoncxx
 
 #include <bsoncxx/config/postlude.hpp>
 
@@ -142,25 +142,3 @@ using ::bsoncxx::v_noabi::string::operator!=;
 /// @file
 /// Provides @ref bsoncxx::v_noabi::string::view_or_value.
 ///
-
-#if defined(BSONCXX_PRIVATE_DOXYGEN_PREPROCESSOR)
-
-namespace bsoncxx {
-namespace string {
-
-/// @ref bsoncxx::v_noabi::string::operator==(const v_noabi::string::view_or_value& lhs, const char* rhs)
-inline bool operator==(const v_noabi::string::view_or_value& lhs, const char* rhs);
-
-/// @ref bsoncxx::v_noabi::string::operator!=(const v_noabi::string::view_or_value& lhs, const char* rhs)
-inline bool operator!=(const v_noabi::string::view_or_value& lhs, const char* rhs);
-
-/// @ref bsoncxx::v_noabi::string::operator==(const char* lhs, const v_noabi::string::view_or_value& rhs)
-inline bool operator==(const char* lhs, const v_noabi::string::view_or_value& rhs);
-
-/// @ref bsoncxx::v_noabi::string::operator!=(const char* lhs, const v_noabi::string::view_or_value& rhs)
-inline bool operator!=(const char* lhs, const v_noabi::string::view_or_value& rhs);
-
-}  // namespace string
-}  // namespace bsoncxx
-
-#endif  // defined(BSONCXX_PRIVATE_DOXYGEN_PREPROCESSOR)
