@@ -29,8 +29,8 @@
 
 #include <bsoncxx/config/prelude.hpp>
 
-BSONCXX_PUSH_WARNINGS();
-BSONCXX_DISABLE_WARNING(GNU("-Wfloat-equal"));
+BSONCXX_PRIVATE_WARNINGS_PUSH();
+BSONCXX_PRIVATE_WARNINGS_DISABLE(GNU("-Wfloat-equal"));
 
 namespace bsoncxx {
 namespace v_noabi {
@@ -41,27 +41,27 @@ namespace v_noabi {
 /// @showenumvalues
 ///
 enum class type : std::uint8_t {
-    k_double = 0x01,      ///< 64-bit binary floating point.
-    k_string = 0x02,      ///< UTF-8 string.
-    k_document = 0x03,    ///< Embedded document.
-    k_array = 0x04,       ///< Array.
-    k_binary = 0x05,      ///< Binary data.
-    k_undefined = 0x06,   ///< Undefined value. @deprecated
-    k_oid = 0x07,         ///< ObjectId.
-    k_bool = 0x08,        ///< Boolean.
-    k_date = 0x09,        ///< UTC datetime.
-    k_null = 0x0A,        ///< Null value.
-    k_regex = 0x0B,       ///< Regular expression.
-    k_dbpointer = 0x0C,   ///< DBPointer. @deprecated
-    k_code = 0x0D,        ///< JavaScript code.
-    k_symbol = 0x0E,      ///< Symbol. @deprecated
-    k_codewscope = 0x0F,  ///< JavaScript code with scope.
-    k_int32 = 0x10,       ///< 32-bit integer.
-    k_timestamp = 0x11,   ///< Timestamp.
-    k_int64 = 0x12,       ///< 64-bit integer.
-    k_decimal128 = 0x13,  ///< 128-bit decimal floating point.
-    k_maxkey = 0x7F,      ///< Min key.
-    k_minkey = 0xFF,      ///< Max key.
+    k_double = 0x01,     ///< 64-bit binary floating point.
+    k_string = 0x02,     ///< UTF-8 string.
+    k_document = 0x03,   ///< Embedded document.
+    k_array = 0x04,      ///< Array.
+    k_binary = 0x05,     ///< Binary data.
+    k_undefined = 0x06,  ///< Undefined value. @deprecated
+    k_oid = 0x07,        ///< ObjectId.
+    k_bool = 0x08,       ///< Boolean.
+    k_date = 0x09,       ///< UTC datetime.
+    k_null = 0x0A,       ///< Null value.
+    k_regex = 0x0B,      ///< Regular expression.
+    k_dbpointer = 0x0C,  ///< DBPointer. @deprecated
+    k_code = 0x0D,       ///< JavaScript code.
+    k_symbol = 0x0E,     ///< Symbol. @deprecated
+    k_codewscope = 0x0F, ///< JavaScript code with scope.
+    k_int32 = 0x10,      ///< 32-bit integer.
+    k_timestamp = 0x11,  ///< Timestamp.
+    k_int64 = 0x12,      ///< 64-bit integer.
+    k_decimal128 = 0x13, ///< 128-bit decimal floating point.
+    k_maxkey = 0x7F,     ///< Min key.
+    k_minkey = 0xFF,     ///< Max key.
 };
 
 ///
@@ -70,16 +70,17 @@ enum class type : std::uint8_t {
 /// @showenumvalues
 ///
 enum class binary_sub_type : std::uint8_t {
-    k_binary = 0x00,             ///< Generic binary subtype.
-    k_function = 0x01,           ///< Function.
-    k_binary_deprecated = 0x02,  ///< Binary (Old). @deprecated
-    k_uuid_deprecated = 0x03,    ///< UUID (Old). @deprecated
-    k_uuid = 0x04,               ///< UUID.
-    k_md5 = 0x05,                ///< MD5.
-    k_encrypted = 0x06,          ///< Encrypted BSON value.
-    k_column = 0x07,             ///< Compressed BSON column.
-    k_sensitive = 0x08,          ///< Sensitive.
-    k_user = 0x80,               ///< User defined.
+    k_binary = 0x00,            ///< Generic binary subtype.
+    k_function = 0x01,          ///< Function.
+    k_binary_deprecated = 0x02, ///< Binary (Old). @deprecated
+    k_uuid_deprecated = 0x03,   ///< UUID (Old). @deprecated
+    k_uuid = 0x04,              ///< UUID.
+    k_md5 = 0x05,               ///< MD5.
+    k_encrypted = 0x06,         ///< Encrypted BSON value.
+    k_column = 0x07,            ///< Compressed BSON column.
+    k_sensitive = 0x08,         ///< Sensitive.
+    k_vector = 0x09,            ///< BSON Binary Vector.
+    k_user = 0x80,              ///< User defined.
 };
 
 ///
@@ -125,7 +126,7 @@ struct b_double {
 ///
 /// @relatesalso bsoncxx::v_noabi::types::b_double
 ///
-inline bool operator==(const b_double& lhs, const b_double& rhs) {
+inline bool operator==(b_double const& lhs, b_double const& rhs) {
     return lhs.value == rhs.value;
 }
 
@@ -159,7 +160,7 @@ struct b_string {
 ///
 /// @relatesalso bsoncxx::v_noabi::types::b_string
 ///
-inline bool operator==(const b_string& lhs, const b_string& rhs) {
+inline bool operator==(b_string const& lhs, b_string const& rhs) {
     return lhs.value == rhs.value;
 }
 
@@ -191,7 +192,7 @@ struct b_document {
 ///
 /// @relatesalso bsoncxx::v_noabi::types::b_document
 ///
-inline bool operator==(const b_document& lhs, const b_document& rhs) {
+inline bool operator==(b_document const& lhs, b_document const& rhs) {
     return lhs.value == rhs.value;
 }
 
@@ -216,7 +217,7 @@ struct b_array {
 ///
 /// @relatesalso bsoncxx::v_noabi::types::b_array
 ///
-inline bool operator==(const b_array& lhs, const b_array& rhs) {
+inline bool operator==(b_array const& lhs, b_array const& rhs) {
     return lhs.value == rhs.value;
 }
 
@@ -228,7 +229,7 @@ struct b_binary {
 
     binary_sub_type sub_type;
     uint32_t size;
-    const uint8_t* bytes;
+    uint8_t const* bytes;
 };
 
 ///
@@ -236,7 +237,7 @@ struct b_binary {
 ///
 /// @relatesalso bsoncxx::v_noabi::types::b_binary
 ///
-inline bool operator==(const b_binary& lhs, const b_binary& rhs) {
+inline bool operator==(b_binary const& lhs, b_binary const& rhs) {
     return lhs.sub_type == rhs.sub_type && lhs.size == rhs.size &&
            (!lhs.size || (std::memcmp(lhs.bytes, rhs.bytes, lhs.size) == 0));
 }
@@ -255,7 +256,7 @@ struct b_undefined {
 ///
 /// @relatesalso bsoncxx::v_noabi::types::b_undefined
 ///
-inline bool operator==(const b_undefined&, const b_undefined&) {
+inline bool operator==(b_undefined const&, b_undefined const&) {
     return true;
 }
 
@@ -273,7 +274,7 @@ struct b_oid {
 ///
 /// @relatesalso bsoncxx::v_noabi::types::b_oid
 ///
-inline bool operator==(const b_oid& lhs, const b_oid& rhs) {
+inline bool operator==(b_oid const& lhs, b_oid const& rhs) {
     return lhs.value == rhs.value;
 }
 
@@ -298,7 +299,7 @@ struct b_bool {
 ///
 /// @relatesalso bsoncxx::v_noabi::types::b_bool
 ///
-inline bool operator==(const b_bool& lhs, const b_bool& rhs) {
+inline bool operator==(b_bool const& lhs, b_bool const& rhs) {
     return lhs.value == rhs.value;
 }
 
@@ -322,7 +323,7 @@ struct b_date {
     /// @param tp
     ///   A system_clock time_point.
     ///
-    explicit b_date(const std::chrono::system_clock::time_point& tp)
+    explicit b_date(std::chrono::system_clock::time_point const& tp)
         : value(std::chrono::duration_cast<std::chrono::milliseconds>(tp.time_since_epoch())) {}
 
     std::chrono::milliseconds value;
@@ -355,7 +356,7 @@ struct b_date {
 ///
 /// @relatesalso bsoncxx::v_noabi::types::b_date
 ///
-inline bool operator==(const b_date& lhs, const b_date& rhs) {
+inline bool operator==(b_date const& lhs, b_date const& rhs) {
     return lhs.value == rhs.value;
 }
 
@@ -371,7 +372,7 @@ struct b_null {
 ///
 /// @relatesalso bsoncxx::v_noabi::types::b_null
 ///
-inline bool operator==(const b_null&, const b_null&) {
+inline bool operator==(b_null const&, b_null const&) {
     return true;
 }
 
@@ -390,11 +391,8 @@ struct b_regex {
     /// @param options
     ///   The regex options
     ///
-    template <typename T,
-              typename U = stdx::string_view,
-              detail::requires_not_t<int, detail::is_alike<b_regex, T>> = 0>
-    explicit b_regex(T&& regex, U&& options = U{})
-        : regex(std::forward<T>(regex)), options(std::forward<U>(options)) {}
+    template <typename T, typename U = stdx::string_view, detail::requires_not_t<int, detail::is_alike<b_regex, T>> = 0>
+    explicit b_regex(T&& regex, U&& options = U{}) : regex(std::forward<T>(regex)), options(std::forward<U>(options)) {}
 
     stdx::string_view regex;
     stdx::string_view options;
@@ -405,7 +403,7 @@ struct b_regex {
 ///
 /// @relatesalso bsoncxx::v_noabi::types::b_regex
 ///
-inline bool operator==(const b_regex& lhs, const b_regex& rhs) {
+inline bool operator==(b_regex const& lhs, b_regex const& rhs) {
     return lhs.regex == rhs.regex && lhs.options == rhs.options;
 }
 
@@ -426,7 +424,7 @@ struct b_dbpointer {
 ///
 /// @relatesalso bsoncxx::v_noabi::types::b_dbpointer
 ///
-inline bool operator==(const b_dbpointer& lhs, const b_dbpointer& rhs) {
+inline bool operator==(b_dbpointer const& lhs, b_dbpointer const& rhs) {
     return lhs.collection == rhs.collection && lhs.value == rhs.value;
 }
 
@@ -460,7 +458,7 @@ struct b_code {
 ///
 /// @relatesalso bsoncxx::v_noabi::types::b_code
 ///
-inline bool operator==(const b_code& lhs, const b_code& rhs) {
+inline bool operator==(b_code const& lhs, b_code const& rhs) {
     return lhs.code == rhs.code;
 }
 
@@ -496,7 +494,7 @@ struct b_symbol {
 ///
 /// @relatesalso bsoncxx::v_noabi::types::b_symbol
 ///
-inline bool operator==(const b_symbol& lhs, const b_symbol& rhs) {
+inline bool operator==(b_symbol const& lhs, b_symbol const& rhs) {
     return lhs.symbol == rhs.symbol;
 }
 
@@ -515,11 +513,8 @@ struct b_codewscope {
     /// @param scope
     ///   A bson document view holding the scope environment.
     ///
-    template <typename T,
-              typename U,
-              detail::requires_not_t<int, detail::is_alike<b_codewscope, T>> = 0>
-    explicit b_codewscope(T&& code, U&& scope)
-        : code(std::forward<T>(code)), scope(std::forward<U>(scope)) {}
+    template <typename T, typename U, detail::requires_not_t<int, detail::is_alike<b_codewscope, T>> = 0>
+    explicit b_codewscope(T&& code, U&& scope) : code(std::forward<T>(code)), scope(std::forward<U>(scope)) {}
 
     stdx::string_view code;
     document::view scope;
@@ -530,7 +525,7 @@ struct b_codewscope {
 ///
 /// @relatesalso bsoncxx::v_noabi::types::b_codewscope
 ///
-inline bool operator==(const b_codewscope& lhs, const b_codewscope& rhs) {
+inline bool operator==(b_codewscope const& lhs, b_codewscope const& rhs) {
     return lhs.code == rhs.code && lhs.scope == rhs.scope;
 }
 
@@ -555,7 +550,7 @@ struct b_int32 {
 ///
 /// @relatesalso bsoncxx::v_noabi::types::b_int32
 ///
-inline bool operator==(const b_int32& lhs, const b_int32& rhs) {
+inline bool operator==(b_int32 const& lhs, b_int32 const& rhs) {
     return lhs.value == rhs.value;
 }
 
@@ -574,7 +569,7 @@ struct b_timestamp {
 ///
 /// @relatesalso bsoncxx::v_noabi::types::b_timestamp
 ///
-inline bool operator==(const b_timestamp& lhs, const b_timestamp& rhs) {
+inline bool operator==(b_timestamp const& lhs, b_timestamp const& rhs) {
     return lhs.increment == rhs.increment && lhs.timestamp == rhs.timestamp;
 }
 
@@ -599,7 +594,7 @@ struct b_int64 {
 ///
 /// @relatesalso bsoncxx::v_noabi::types::b_int64
 ///
-inline bool operator==(const b_int64& lhs, const b_int64& rhs) {
+inline bool operator==(b_int64 const& lhs, b_int64 const& rhs) {
     return lhs.value == rhs.value;
 }
 
@@ -626,7 +621,7 @@ struct b_decimal128 {
 ///
 /// @relatesalso bsoncxx::v_noabi::types::b_decimal128
 ///
-inline bool operator==(const b_decimal128& lhs, const b_decimal128& rhs) {
+inline bool operator==(b_decimal128 const& lhs, b_decimal128 const& rhs) {
     return lhs.value == rhs.value;
 }
 
@@ -642,7 +637,7 @@ struct b_minkey {
 ///
 /// @relatesalso bsoncxx::v_noabi::types::b_minkey
 ///
-inline bool operator==(const b_minkey&, const b_minkey&) {
+inline bool operator==(b_minkey const&, b_minkey const&) {
     return true;
 }
 
@@ -658,7 +653,7 @@ struct b_maxkey {
 ///
 /// @relatesalso bsoncxx::v_noabi::types::b_maxkey
 ///
-inline bool operator==(const b_maxkey&, const b_maxkey&) {
+inline bool operator==(b_maxkey const&, b_maxkey const&) {
     return true;
 }
 
@@ -667,7 +662,7 @@ inline bool operator==(const b_maxkey&, const b_maxkey&) {
 ///
 /// free function comparator for b_double
 ///
-inline bool operator!=(const b_double& lhs, const b_double& rhs) {
+inline bool operator!=(b_double const& lhs, b_double const& rhs) {
     return !(lhs == rhs);
 }
 
@@ -676,7 +671,7 @@ inline bool operator!=(const b_double& lhs, const b_double& rhs) {
 ///
 /// free function comparator for b_string
 ///
-inline bool operator!=(const b_string& lhs, const b_string& rhs) {
+inline bool operator!=(b_string const& lhs, b_string const& rhs) {
     return !(lhs == rhs);
 }
 
@@ -685,7 +680,7 @@ inline bool operator!=(const b_string& lhs, const b_string& rhs) {
 ///
 /// free function comparator for b_document
 ///
-inline bool operator!=(const b_document& lhs, const b_document& rhs) {
+inline bool operator!=(b_document const& lhs, b_document const& rhs) {
     return !(lhs == rhs);
 }
 
@@ -694,7 +689,7 @@ inline bool operator!=(const b_document& lhs, const b_document& rhs) {
 ///
 /// free function comparator for b_array
 ///
-inline bool operator!=(const b_array& lhs, const b_array& rhs) {
+inline bool operator!=(b_array const& lhs, b_array const& rhs) {
     return !(lhs == rhs);
 }
 
@@ -703,7 +698,7 @@ inline bool operator!=(const b_array& lhs, const b_array& rhs) {
 ///
 /// free function comparator for b_binary
 ///
-inline bool operator!=(const b_binary& lhs, const b_binary& rhs) {
+inline bool operator!=(b_binary const& lhs, b_binary const& rhs) {
     return !(lhs == rhs);
 }
 
@@ -712,7 +707,7 @@ inline bool operator!=(const b_binary& lhs, const b_binary& rhs) {
 ///
 /// free function comparator for b_undefined
 ///
-inline bool operator!=(const b_undefined& lhs, const b_undefined& rhs) {
+inline bool operator!=(b_undefined const& lhs, b_undefined const& rhs) {
     return !(lhs == rhs);
 }
 
@@ -721,7 +716,7 @@ inline bool operator!=(const b_undefined& lhs, const b_undefined& rhs) {
 ///
 /// free function comparator for b_oid
 ///
-inline bool operator!=(const b_oid& lhs, const b_oid& rhs) {
+inline bool operator!=(b_oid const& lhs, b_oid const& rhs) {
     return !(lhs == rhs);
 }
 
@@ -730,7 +725,7 @@ inline bool operator!=(const b_oid& lhs, const b_oid& rhs) {
 ///
 /// free function comparator for b_bool
 ///
-inline bool operator!=(const b_bool& lhs, const b_bool& rhs) {
+inline bool operator!=(b_bool const& lhs, b_bool const& rhs) {
     return !(lhs == rhs);
 }
 
@@ -739,7 +734,7 @@ inline bool operator!=(const b_bool& lhs, const b_bool& rhs) {
 ///
 /// free function comparator for b_date
 ///
-inline bool operator!=(const b_date& lhs, const b_date& rhs) {
+inline bool operator!=(b_date const& lhs, b_date const& rhs) {
     return !(lhs == rhs);
 }
 
@@ -748,7 +743,7 @@ inline bool operator!=(const b_date& lhs, const b_date& rhs) {
 ///
 /// free function comparator for b_null
 ///
-inline bool operator!=(const b_null& lhs, const b_null& rhs) {
+inline bool operator!=(b_null const& lhs, b_null const& rhs) {
     return !(lhs == rhs);
 }
 
@@ -757,7 +752,7 @@ inline bool operator!=(const b_null& lhs, const b_null& rhs) {
 ///
 /// free function comparator for b_regex
 ///
-inline bool operator!=(const b_regex& lhs, const b_regex& rhs) {
+inline bool operator!=(b_regex const& lhs, b_regex const& rhs) {
     return !(lhs == rhs);
 }
 
@@ -766,7 +761,7 @@ inline bool operator!=(const b_regex& lhs, const b_regex& rhs) {
 ///
 /// free function comparator for b_dbpointer
 ///
-inline bool operator!=(const b_dbpointer& lhs, const b_dbpointer& rhs) {
+inline bool operator!=(b_dbpointer const& lhs, b_dbpointer const& rhs) {
     return !(lhs == rhs);
 }
 
@@ -775,7 +770,7 @@ inline bool operator!=(const b_dbpointer& lhs, const b_dbpointer& rhs) {
 ///
 /// free function comparator for b_code
 ///
-inline bool operator!=(const b_code& lhs, const b_code& rhs) {
+inline bool operator!=(b_code const& lhs, b_code const& rhs) {
     return !(lhs == rhs);
 }
 
@@ -784,7 +779,7 @@ inline bool operator!=(const b_code& lhs, const b_code& rhs) {
 ///
 /// free function comparator for b_symbol
 ///
-inline bool operator!=(const b_symbol& lhs, const b_symbol& rhs) {
+inline bool operator!=(b_symbol const& lhs, b_symbol const& rhs) {
     return !(lhs == rhs);
 }
 
@@ -793,7 +788,7 @@ inline bool operator!=(const b_symbol& lhs, const b_symbol& rhs) {
 ///
 /// free function comparator for b_codewscope
 ///
-inline bool operator!=(const b_codewscope& lhs, const b_codewscope& rhs) {
+inline bool operator!=(b_codewscope const& lhs, b_codewscope const& rhs) {
     return !(lhs == rhs);
 }
 
@@ -802,7 +797,7 @@ inline bool operator!=(const b_codewscope& lhs, const b_codewscope& rhs) {
 ///
 /// free function comparator for b_int32
 ///
-inline bool operator!=(const b_int32& lhs, const b_int32& rhs) {
+inline bool operator!=(b_int32 const& lhs, b_int32 const& rhs) {
     return !(lhs == rhs);
 }
 
@@ -811,7 +806,7 @@ inline bool operator!=(const b_int32& lhs, const b_int32& rhs) {
 ///
 /// free function comparator for b_timestamp
 ///
-inline bool operator!=(const b_timestamp& lhs, const b_timestamp& rhs) {
+inline bool operator!=(b_timestamp const& lhs, b_timestamp const& rhs) {
     return !(lhs == rhs);
 }
 
@@ -820,7 +815,7 @@ inline bool operator!=(const b_timestamp& lhs, const b_timestamp& rhs) {
 ///
 /// free function comparator for b_int64
 ///
-inline bool operator!=(const b_int64& lhs, const b_int64& rhs) {
+inline bool operator!=(b_int64 const& lhs, b_int64 const& rhs) {
     return !(lhs == rhs);
 }
 
@@ -829,7 +824,7 @@ inline bool operator!=(const b_int64& lhs, const b_int64& rhs) {
 ///
 /// free function comparator for b_decimal128
 ///
-inline bool operator!=(const b_decimal128& lhs, const b_decimal128& rhs) {
+inline bool operator!=(b_decimal128 const& lhs, b_decimal128 const& rhs) {
     return !(lhs == rhs);
 }
 
@@ -838,7 +833,7 @@ inline bool operator!=(const b_decimal128& lhs, const b_decimal128& rhs) {
 ///
 /// free function comparator for b_minkey
 ///
-inline bool operator!=(const b_minkey& lhs, const b_minkey& rhs) {
+inline bool operator!=(b_minkey const& lhs, b_minkey const& rhs) {
     return !(lhs == rhs);
 }
 
@@ -847,21 +842,21 @@ inline bool operator!=(const b_minkey& lhs, const b_minkey& rhs) {
 ///
 /// free function comparator for b_maxkey
 ///
-inline bool operator!=(const b_maxkey& lhs, const b_maxkey& rhs) {
+inline bool operator!=(b_maxkey const& lhs, b_maxkey const& rhs) {
     return !(lhs == rhs);
 }
 
-}  // namespace types
-}  // namespace v_noabi
-}  // namespace bsoncxx
+} // namespace types
+} // namespace v_noabi
+} // namespace bsoncxx
 
-BSONCXX_POP_WARNINGS();
+BSONCXX_PRIVATE_WARNINGS_POP();
 
 namespace bsoncxx {
 
 using ::bsoncxx::v_noabi::to_string;
 
-}  // namespace bsoncxx
+} // namespace bsoncxx
 
 namespace bsoncxx {
 namespace types {
@@ -869,8 +864,8 @@ namespace types {
 using ::bsoncxx::v_noabi::types::operator==;
 using ::bsoncxx::v_noabi::types::operator!=;
 
-}  // namespace types
-}  // namespace bsoncxx
+} // namespace types
+} // namespace bsoncxx
 
 #include <bsoncxx/config/postlude.hpp>
 
@@ -878,147 +873,3 @@ using ::bsoncxx::v_noabi::types::operator!=;
 /// @file
 /// Provides entities used to represent BSON types.
 ///
-
-#if defined(BSONCXX_PRIVATE_DOXYGEN_PREPROCESSOR)
-
-namespace bsoncxx {
-
-/// @ref bsoncxx::v_noabi::to_string(v_noabi::type rhs)
-std::string to_string(v_noabi::type rhs);
-
-/// @ref bsoncxx::v_noabi::to_string(v_noabi::binary_sub_type rhs)
-std::string to_string(v_noabi::binary_sub_type rhs);
-
-namespace types {
-
-/// @ref bsoncxx::v_noabi::types::operator==(const v_noabi::types::b_double& lhs, const v_noabi::types::b_double& rhs)
-bool operator==(const v_noabi::types::b_double& lhs, const v_noabi::types::b_double& rhs);
-
-/// @ref bsoncxx::v_noabi::types::operator==(const v_noabi::types::b_string& lhs, const v_noabi::types::b_string& rhs)
-bool operator==(const v_noabi::types::b_string& lhs, const v_noabi::types::b_string& rhs);
-
-/// @ref bsoncxx::v_noabi::types::operator==(const v_noabi::types::b_document& lhs, const v_noabi::types::b_document& rhs)
-bool operator==(const v_noabi::types::b_document& lhs, const v_noabi::types::b_document& rhs);
-
-/// @ref bsoncxx::v_noabi::types::operator==(const v_noabi::types::b_array& lhs, const v_noabi::types::b_array& rhs)
-bool operator==(const v_noabi::types::b_array& lhs, const v_noabi::types::b_array& rhs);
-
-/// @ref bsoncxx::v_noabi::types::operator==(const v_noabi::types::b_binary& lhs, const v_noabi::types::b_binary& rhs)
-bool operator==(const v_noabi::types::b_binary& lhs, const v_noabi::types::b_binary& rhs);
-
-/// @ref bsoncxx::v_noabi::types::operator==(const v_noabi::types::b_undefined&, const v_noabi::types::b_undefined&)
-bool operator==(const v_noabi::types::b_undefined&, const v_noabi::types::b_undefined&);
-
-/// @ref bsoncxx::v_noabi::types::operator==(const v_noabi::types::b_oid& lhs, const v_noabi::types::b_oid& rhs)
-bool operator==(const v_noabi::types::b_oid& lhs, const v_noabi::types::b_oid& rhs);
-
-/// @ref bsoncxx::v_noabi::types::operator==(const v_noabi::types::b_bool& lhs, const v_noabi::types::b_bool& rhs)
-bool operator==(const v_noabi::types::b_bool& lhs, const v_noabi::types::b_bool& rhs);
-
-/// @ref bsoncxx::v_noabi::types::operator==(const v_noabi::types::b_date& lhs, const v_noabi::types::b_date& rhs)
-bool operator==(const v_noabi::types::b_date& lhs, const v_noabi::types::b_date& rhs);
-
-/// @ref bsoncxx::v_noabi::types::operator==(const v_noabi::types::b_null&, const v_noabi::types::b_null&)
-bool operator==(const v_noabi::types::b_null&, const v_noabi::types::b_null&);
-
-/// @ref bsoncxx::v_noabi::types::operator==(const v_noabi::types::b_regex& lhs, const v_noabi::types::b_regex& rhs)
-bool operator==(const v_noabi::types::b_regex& lhs, const v_noabi::types::b_regex& rhs);
-
-/// @ref bsoncxx::v_noabi::types::operator==(const v_noabi::types::b_dbpointer& lhs, const v_noabi::types::b_dbpointer& rhs)
-bool operator==(const v_noabi::types::b_dbpointer& lhs, const v_noabi::types::b_dbpointer& rhs);
-
-/// @ref bsoncxx::v_noabi::types::operator==(const v_noabi::types::b_code& lhs, const v_noabi::types::b_code& rhs)
-bool operator==(const v_noabi::types::b_code& lhs, const v_noabi::types::b_code& rhs);
-
-/// @ref bsoncxx::v_noabi::types::operator==(const v_noabi::types::b_symbol& lhs, const v_noabi::types::b_symbol& rhs)
-bool operator==(const v_noabi::types::b_symbol& lhs, const v_noabi::types::b_symbol& rhs);
-
-/// @ref bsoncxx::v_noabi::types::operator==(const v_noabi::types::b_codewscope& lhs, const v_noabi::types::b_codewscope& rhs)
-bool operator==(const v_noabi::types::b_codewscope& lhs, const v_noabi::types::b_codewscope& rhs);
-
-/// @ref bsoncxx::v_noabi::types::operator==(const v_noabi::types::b_int32& lhs, const v_noabi::types::b_int32& rhs)
-bool operator==(const v_noabi::types::b_int32& lhs, const v_noabi::types::b_int32& rhs);
-
-/// @ref bsoncxx::v_noabi::types::operator==(const v_noabi::types::b_timestamp& lhs, const v_noabi::types::b_timestamp& rhs)
-bool operator==(const v_noabi::types::b_timestamp& lhs, const v_noabi::types::b_timestamp& rhs);
-
-/// @ref bsoncxx::v_noabi::types::operator==(const v_noabi::types::b_int64& lhs, const v_noabi::types::b_int64& rhs)
-bool operator==(const v_noabi::types::b_int64& lhs, const v_noabi::types::b_int64& rhs);
-
-/// @ref bsoncxx::v_noabi::types::operator==(const v_noabi::types::b_decimal128& lhs, const v_noabi::types::b_decimal128& rhs)
-bool operator==(const v_noabi::types::b_decimal128& lhs, const v_noabi::types::b_decimal128& rhs);
-
-/// @ref bsoncxx::v_noabi::types::operator==(const v_noabi::types::b_minkey&, const v_noabi::types::b_minkey&)
-bool operator==(const v_noabi::types::b_minkey&, const v_noabi::types::b_minkey&);
-
-/// @ref bsoncxx::v_noabi::types::operator==(const v_noabi::types::b_maxkey&, const v_noabi::types::b_maxkey&)
-bool operator==(const v_noabi::types::b_maxkey&, const v_noabi::types::b_maxkey&);
-
-/// @ref bsoncxx::v_noabi::types::operator!=(const v_noabi::types::b_double& lhs, const v_noabi::types::b_double& rhs)
-bool operator!=(const v_noabi::types::b_double& lhs, const v_noabi::types::b_double& rhs);
-
-/// @ref bsoncxx::v_noabi::types::operator!=(const v_noabi::types::b_string& lhs, const v_noabi::types::b_string& rhs)
-bool operator!=(const v_noabi::types::b_string& lhs, const v_noabi::types::b_string& rhs);
-
-/// @ref bsoncxx::v_noabi::types::operator!=(const v_noabi::types::b_document& lhs, const v_noabi::types::b_document& rhs)
-bool operator!=(const v_noabi::types::b_document& lhs, const v_noabi::types::b_document& rhs);
-
-/// @ref bsoncxx::v_noabi::types::operator!=(const v_noabi::types::b_array& lhs, const v_noabi::types::b_array& rhs)
-bool operator!=(const v_noabi::types::b_array& lhs, const v_noabi::types::b_array& rhs);
-
-/// @ref bsoncxx::v_noabi::types::operator!=(const v_noabi::types::b_binary& lhs, const v_noabi::types::b_binary& rhs)
-bool operator!=(const v_noabi::types::b_binary& lhs, const v_noabi::types::b_binary& rhs);
-
-/// @ref bsoncxx::v_noabi::types::operator!=(const v_noabi::types::b_undefined& lhs, const v_noabi::types::b_undefined& rhs)
-bool operator!=(const v_noabi::types::b_undefined& lhs, const v_noabi::types::b_undefined& rhs);
-
-/// @ref bsoncxx::v_noabi::types::operator!=(const v_noabi::types::b_oid& lhs, const v_noabi::types::b_oid& rhs)
-bool operator!=(const v_noabi::types::b_oid& lhs, const v_noabi::types::b_oid& rhs);
-
-/// @ref bsoncxx::v_noabi::types::operator!=(const v_noabi::types::b_bool& lhs, const v_noabi::types::b_bool& rhs)
-bool operator!=(const v_noabi::types::b_bool& lhs, const v_noabi::types::b_bool& rhs);
-
-/// @ref bsoncxx::v_noabi::types::operator!=(const v_noabi::types::b_date& lhs, const v_noabi::types::b_date& rhs)
-bool operator!=(const v_noabi::types::b_date& lhs, const v_noabi::types::b_date& rhs);
-
-/// @ref bsoncxx::v_noabi::types::operator!=(const v_noabi::types::b_null& lhs, const v_noabi::types::b_null& rhs)
-bool operator!=(const v_noabi::types::b_null& lhs, const v_noabi::types::b_null& rhs);
-
-/// @ref bsoncxx::v_noabi::types::operator!=(const v_noabi::types::b_regex& lhs, const v_noabi::types::b_regex& rhs)
-bool operator!=(const v_noabi::types::b_regex& lhs, const v_noabi::types::b_regex& rhs);
-
-/// @ref bsoncxx::v_noabi::types::operator!=(const v_noabi::types::b_dbpointer& lhs, const v_noabi::types::b_dbpointer& rhs)
-bool operator!=(const v_noabi::types::b_dbpointer& lhs, const v_noabi::types::b_dbpointer& rhs);
-
-/// @ref bsoncxx::v_noabi::types::operator!=(const v_noabi::types::b_code& lhs, const v_noabi::types::b_code& rhs)
-bool operator!=(const v_noabi::types::b_code& lhs, const v_noabi::types::b_code& rhs);
-
-/// @ref bsoncxx::v_noabi::types::operator!=(const v_noabi::types::b_symbol& lhs, const v_noabi::types::b_symbol& rhs)
-bool operator!=(const v_noabi::types::b_symbol& lhs, const v_noabi::types::b_symbol& rhs);
-
-/// @ref bsoncxx::v_noabi::types::operator!=(const v_noabi::types::b_codewscope& lhs, const v_noabi::types::b_codewscope& rhs)
-bool operator!=(const v_noabi::types::b_codewscope& lhs, const v_noabi::types::b_codewscope& rhs);
-
-/// @ref bsoncxx::v_noabi::types::operator!=(const v_noabi::types::b_int32& lhs, const v_noabi::types::b_int32& rhs)
-bool operator!=(const v_noabi::types::b_int32& lhs, const v_noabi::types::b_int32& rhs);
-
-/// @ref bsoncxx::v_noabi::types::operator!=(const v_noabi::types::b_timestamp& lhs, const v_noabi::types::b_timestamp& rhs)
-bool operator!=(const v_noabi::types::b_timestamp& lhs, const v_noabi::types::b_timestamp& rhs);
-
-/// @ref bsoncxx::v_noabi::types::operator!=(const v_noabi::types::b_int64& lhs, const v_noabi::types::b_int64& rhs)
-bool operator!=(const v_noabi::types::b_int64& lhs, const v_noabi::types::b_int64& rhs);
-
-/// @ref bsoncxx::v_noabi::types::operator!=(const v_noabi::types::b_decimal128& lhs, const v_noabi::types::b_decimal128& rhs)
-bool operator!=(const v_noabi::types::b_decimal128& lhs, const v_noabi::types::b_decimal128& rhs);
-
-/// @ref bsoncxx::v_noabi::types::operator!=(const v_noabi::types::b_minkey& lhs, const v_noabi::types::b_minkey& rhs)
-bool operator!=(const v_noabi::types::b_minkey& lhs, const v_noabi::types::b_minkey& rhs);
-
-/// @ref bsoncxx::v_noabi::types::operator!=(const v_noabi::types::b_maxkey& lhs, const v_noabi::types::b_maxkey& rhs)
-bool operator!=(const v_noabi::types::b_maxkey& lhs, const v_noabi::types::b_maxkey& rhs);
-
-}  // namespace types
-
-}  // namespace bsoncxx
-
-#endif  // defined(BSONCXX_PRIVATE_DOXYGEN_PREPROCESSOR)
