@@ -31,21 +31,22 @@ namespace bsoncxx {
 namespace detail {
 
 template <typename T>
-using is_bson_view_compatible =
-    detail::conjunction<std::is_constructible<bsoncxx::v_noabi::types::bson_value::view, T>,
-                        detail::negation<detail::disjunction<
-                            detail::is_alike<T, bsoncxx::v_noabi::types::bson_value::view>,
-                            detail::is_alike<T, bsoncxx::v_noabi::types::bson_value::value>>>>;
+using is_bson_view_compatible = detail::conjunction<
+    std::is_constructible<bsoncxx::v_noabi::types::bson_value::view, T>,
+    detail::negation<detail::disjunction<
+        detail::is_alike<T, bsoncxx::v_noabi::types::bson_value::view>,
+        detail::is_alike<T, bsoncxx::v_noabi::types::bson_value::value>>>>;
 
-}  // namespace detail
-}  // namespace bsoncxx
+} // namespace detail
+} // namespace bsoncxx
 
 namespace bsoncxx {
 namespace v_noabi {
 namespace types {
 namespace bson_value {
+
 ///
-/// A view-only variant that can contain any BSON type.
+/// A non-owning variant that can contain any BSON type.
 ///
 /// @warning
 ///   Calling the wrong get_<type> method will cause an exception
@@ -87,8 +88,8 @@ class view {
     ///
     BSONCXX_ABI_EXPORT_CDECL() view() noexcept;
 
-    BSONCXX_ABI_EXPORT_CDECL() view(const view&) noexcept;
-    BSONCXX_ABI_EXPORT_CDECL(view&) operator=(const view&) noexcept;
+    BSONCXX_ABI_EXPORT_CDECL() view(view const&) noexcept;
+    BSONCXX_ABI_EXPORT_CDECL(view&) operator=(view const&) noexcept;
 
     BSONCXX_ABI_EXPORT_CDECL() ~view();
 
@@ -98,10 +99,8 @@ class view {
     /// Compare two bson_value::views for equality
     ///
     /// @{
-    friend BSONCXX_ABI_EXPORT_CDECL(bool) operator==(const bson_value::view&,
-                                                     const bson_value::view&);
-    friend BSONCXX_ABI_EXPORT_CDECL(bool) operator!=(const bson_value::view&,
-                                                     const bson_value::view&);
+    friend BSONCXX_ABI_EXPORT_CDECL(bool) operator==(bson_value::view const&, bson_value::view const&);
+    friend BSONCXX_ABI_EXPORT_CDECL(bool) operator!=(bson_value::view const&, bson_value::view const&);
     /// @}
     ///
 
@@ -116,7 +115,7 @@ class view {
     /// @warning
     ///   Calling the wrong get_<type> method will cause an exception to be thrown.
     ///
-    BSONCXX_ABI_EXPORT_CDECL(const b_double&) get_double() const;
+    BSONCXX_ABI_EXPORT_CDECL(b_double const&) get_double() const;
 
     ///
     /// Returns the underlying BSON UTF-8 string value.
@@ -124,7 +123,7 @@ class view {
     /// @warning
     ///   Calling the wrong get_<type> method will cause an exception to be thrown.
     ///
-    BSONCXX_ABI_EXPORT_CDECL(const b_string&) get_string() const;
+    BSONCXX_ABI_EXPORT_CDECL(b_string const&) get_string() const;
 
     ///
     /// Returns the underlying BSON document value.
@@ -132,7 +131,7 @@ class view {
     /// @warning
     ///   Calling the wrong get_<type> method will cause an exception to be thrown.
     ///
-    BSONCXX_ABI_EXPORT_CDECL(const b_document&) get_document() const;
+    BSONCXX_ABI_EXPORT_CDECL(b_document const&) get_document() const;
 
     ///
     /// Returns the underlying BSON array value.
@@ -140,7 +139,7 @@ class view {
     /// @warning
     ///   Calling the wrong get_<type> method will cause an exception to be thrown.
     ///
-    BSONCXX_ABI_EXPORT_CDECL(const b_array&) get_array() const;
+    BSONCXX_ABI_EXPORT_CDECL(b_array const&) get_array() const;
 
     ///
     /// Returns the underlying BSON binary data value.
@@ -148,7 +147,7 @@ class view {
     /// @warning
     ///   Calling the wrong get_<type> method will cause an exception to be thrown.
     ///
-    BSONCXX_ABI_EXPORT_CDECL(const b_binary&) get_binary() const;
+    BSONCXX_ABI_EXPORT_CDECL(b_binary const&) get_binary() const;
 
     ///
     /// Returns the underlying BSON undefined value.
@@ -156,7 +155,7 @@ class view {
     /// @warning
     ///   Calling the wrong get_<type> method will cause an exception to be thrown.
     ///
-    BSONCXX_ABI_EXPORT_CDECL(const b_undefined&) get_undefined() const;
+    BSONCXX_ABI_EXPORT_CDECL(b_undefined const&) get_undefined() const;
 
     ///
     /// Returns the underlying BSON ObjectId value.
@@ -164,7 +163,7 @@ class view {
     /// @warning
     ///   Calling the wrong get_<type> method will cause an exception to be thrown.
     ///
-    BSONCXX_ABI_EXPORT_CDECL(const b_oid&) get_oid() const;
+    BSONCXX_ABI_EXPORT_CDECL(b_oid const&) get_oid() const;
 
     ///
     /// Returns the underlying BSON boolean value.
@@ -172,7 +171,7 @@ class view {
     /// @warning
     ///   Calling the wrong get_<type> method will cause an exception to be thrown.
     ///
-    BSONCXX_ABI_EXPORT_CDECL(const b_bool&) get_bool() const;
+    BSONCXX_ABI_EXPORT_CDECL(b_bool const&) get_bool() const;
 
     ///
     /// Returns the underlying BSON date value.
@@ -180,7 +179,7 @@ class view {
     /// @warning
     ///   Calling the wrong get_<type> method will cause an exception to be thrown.
     ///
-    BSONCXX_ABI_EXPORT_CDECL(const b_date&) get_date() const;
+    BSONCXX_ABI_EXPORT_CDECL(b_date const&) get_date() const;
 
     ///
     /// Returns the underlying BSON null value.
@@ -188,7 +187,7 @@ class view {
     /// @warning
     ///   Calling the wrong get_<type> method will cause an exception to be thrown.
     ///
-    BSONCXX_ABI_EXPORT_CDECL(const b_null&) get_null() const;
+    BSONCXX_ABI_EXPORT_CDECL(b_null const&) get_null() const;
 
     ///
     /// Returns the underlying BSON regex value.
@@ -196,7 +195,7 @@ class view {
     /// @warning
     ///   Calling the wrong get_<type> method will cause an exception to be thrown.
     ///
-    BSONCXX_ABI_EXPORT_CDECL(const b_regex&) get_regex() const;
+    BSONCXX_ABI_EXPORT_CDECL(b_regex const&) get_regex() const;
 
     ///
     /// Returns the underlying BSON DBPointer value.
@@ -204,7 +203,7 @@ class view {
     /// @warning
     ///   Calling the wrong get_<type> method will cause an exception to be thrown.
     ///
-    BSONCXX_ABI_EXPORT_CDECL(const b_dbpointer&) get_dbpointer() const;
+    BSONCXX_ABI_EXPORT_CDECL(b_dbpointer const&) get_dbpointer() const;
 
     ///
     /// Returns the underlying BSON JavaScript code value.
@@ -212,7 +211,7 @@ class view {
     /// @warning
     ///   Calling the wrong get_<type> method will cause an exception to be thrown.
     ///
-    BSONCXX_ABI_EXPORT_CDECL(const b_code&) get_code() const;
+    BSONCXX_ABI_EXPORT_CDECL(b_code const&) get_code() const;
 
     ///
     /// Returns the underlying BSON symbol value.
@@ -220,7 +219,7 @@ class view {
     /// @warning
     ///   Calling the wrong get_<type> method will cause an exception to be thrown.
     ///
-    BSONCXX_ABI_EXPORT_CDECL(const b_symbol&) get_symbol() const;
+    BSONCXX_ABI_EXPORT_CDECL(b_symbol const&) get_symbol() const;
 
     ///
     /// Returns the underlying BSON JavaScript code with scope value.
@@ -228,7 +227,7 @@ class view {
     /// @warning
     ///   Calling the wrong get_<type> method will cause an exception to be thrown.
     ///
-    BSONCXX_ABI_EXPORT_CDECL(const b_codewscope&) get_codewscope() const;
+    BSONCXX_ABI_EXPORT_CDECL(b_codewscope const&) get_codewscope() const;
 
     ///
     /// Returns the underlying BSON 32-bit signed integer value.
@@ -236,7 +235,7 @@ class view {
     /// @warning
     ///   Calling the wrong get_<type> method will cause an exception to be thrown.
     ///
-    BSONCXX_ABI_EXPORT_CDECL(const b_int32&) get_int32() const;
+    BSONCXX_ABI_EXPORT_CDECL(b_int32 const&) get_int32() const;
 
     ///
     /// Returns the underlying BSON replication timestamp value.
@@ -244,7 +243,7 @@ class view {
     /// @warning
     ///   Calling the wrong get_<type> method will cause an exception to be thrown.
     ///
-    BSONCXX_ABI_EXPORT_CDECL(const b_timestamp&) get_timestamp() const;
+    BSONCXX_ABI_EXPORT_CDECL(b_timestamp const&) get_timestamp() const;
 
     ///
     /// Returns the underlying BSON 64-bit signed integer value.
@@ -252,7 +251,7 @@ class view {
     /// @warning
     ///   Calling the wrong get_<type> method will cause an exception to be thrown.
     ///
-    BSONCXX_ABI_EXPORT_CDECL(const b_int64&) get_int64() const;
+    BSONCXX_ABI_EXPORT_CDECL(b_int64 const&) get_int64() const;
 
     ///
     /// Returns the underlying BSON Decimal128 value.
@@ -260,7 +259,7 @@ class view {
     /// @warning
     ///   Calling the wrong get_<type> method will cause an exception to be thrown.
     ///
-    BSONCXX_ABI_EXPORT_CDECL(const b_decimal128&) get_decimal128() const;
+    BSONCXX_ABI_EXPORT_CDECL(b_decimal128 const&) get_decimal128() const;
 
     ///
     /// Returns the underlying BSON min-key value.
@@ -268,7 +267,7 @@ class view {
     /// @warning
     ///   Calling the wrong get_<type> method will cause an exception to be thrown.
     ///
-    BSONCXX_ABI_EXPORT_CDECL(const b_minkey&) get_minkey() const;
+    BSONCXX_ABI_EXPORT_CDECL(b_minkey const&) get_minkey() const;
 
     ///
     /// Returns the underlying BSON max-key value.
@@ -276,13 +275,13 @@ class view {
     /// @warning
     ///   Calling the wrong get_<type> method will cause an exception to be thrown.
     ///
-    BSONCXX_ABI_EXPORT_CDECL(const b_maxkey&) get_maxkey() const;
+    BSONCXX_ABI_EXPORT_CDECL(b_maxkey const&) get_maxkey() const;
 
    private:
     friend ::bsoncxx::v_noabi::types::bson_value::value;
     friend ::bsoncxx::v_noabi::document::element;
 
-    view(const std::uint8_t* raw, std::uint32_t length, std::uint32_t offset, std::uint32_t keylen);
+    view(std::uint8_t const* raw, std::uint32_t length, std::uint32_t offset, std::uint32_t keylen);
     view(void* internal_value) noexcept;
 
     void _init(void* internal_value) noexcept;
@@ -326,39 +325,35 @@ class view {
 
 /// @relatesalso bsoncxx::v_noabi::types::bson_value::view
 template <typename T>
-detail::requires_t<bool, detail::is_bson_view_compatible<T>>  //
-operator==(const bson_value::view& lhs, T&& rhs) {
+detail::requires_t<bool, detail::is_bson_view_compatible<T>> operator==(bson_value::view const& lhs, T&& rhs) {
     return lhs == bson_value::view{std::forward<T>(rhs)};
 }
 
 /// @relatesalso bsoncxx::v_noabi::types::bson_value::view
 template <typename T>
-detail::requires_t<bool, detail::is_bson_view_compatible<T>>  //
-operator==(T&& lhs, const bson_value::view& rhs) {
+detail::requires_t<bool, detail::is_bson_view_compatible<T>> operator==(T&& lhs, bson_value::view const& rhs) {
     return bson_value::view{std::forward<T>(lhs)} == rhs;
 }
 
 /// @relatesalso bsoncxx::v_noabi::types::bson_value::view
 template <typename T>
-detail::requires_t<bool, detail::is_bson_view_compatible<T>>  //
-operator!=(const bson_value::view& lhs, T&& rhs) {
+detail::requires_t<bool, detail::is_bson_view_compatible<T>> operator!=(bson_value::view const& lhs, T&& rhs) {
     return lhs != bson_value::view{std::forward<T>(rhs)};
 }
 
 /// @relatesalso bsoncxx::v_noabi::types::bson_value::view
 template <typename T>
-detail::requires_t<bool, detail::is_bson_view_compatible<T>>  //
-operator!=(T&& lhs, const bson_value::view& rhs) {
+detail::requires_t<bool, detail::is_bson_view_compatible<T>> operator!=(T&& lhs, bson_value::view const& rhs) {
     return bson_value::view{std::forward<T>(lhs)} != rhs;
 }
 
 /// @}
 ///
 
-}  // namespace bson_value
-}  // namespace types
-}  // namespace v_noabi
-}  // namespace bsoncxx
+} // namespace bson_value
+} // namespace types
+} // namespace v_noabi
+} // namespace bsoncxx
 
 namespace bsoncxx {
 namespace types {
@@ -367,9 +362,9 @@ namespace bson_value {
 using ::bsoncxx::v_noabi::types::bson_value::operator==;
 using ::bsoncxx::v_noabi::types::bson_value::operator!=;
 
-}  // namespace bson_value
-}  // namespace types
-}  // namespace bsoncxx
+} // namespace bson_value
+} // namespace types
+} // namespace bsoncxx
 
 #include <bsoncxx/config/postlude.hpp>
 
@@ -377,31 +372,3 @@ using ::bsoncxx::v_noabi::types::bson_value::operator!=;
 /// @file
 /// Provides @ref bsoncxx::v_noabi::types::bson_value::view.
 ///
-
-#if defined(BSONCXX_PRIVATE_DOXYGEN_PREPROCESSOR)
-
-namespace bsoncxx {
-namespace types {
-namespace bson_value {
-
-/// @ref bsoncxx::v_noabi::types::bson_value::operator==(const v_noabi::types::bson_value::view& lhs, T&& rhs)
-template <typename T>
-bool operator==(const v_noabi::types::bson_value::view& lhs, T&& rhs);
-
-/// @ref bsoncxx::v_noabi::types::bson_value::operator==(T&& lhs, const v_noabi::types::bson_value::view& rhs)
-template <typename T>
-bool operator==(T&& lhs, const v_noabi::types::bson_value::view& rhs);
-
-/// @ref bsoncxx::v_noabi::types::bson_value::operator!=(const v_noabi::types::bson_value::view& lhs, T&& rhs)
-template <typename T>
-bool operator!=(const v_noabi::types::bson_value::view& lhs, T&& rhs);
-
-/// @ref bsoncxx::v_noabi::types::bson_value::operator!=(T&& lhs, const v_noabi::types::bson_value::view& rhs)
-template <typename T>
-bool operator!=(T&& lhs, const v_noabi::types::bson_value::view& rhs);
-
-}  // namespace bson_value
-}  // namespace types
-}  // namespace bsoncxx
-
-#endif  // defined(BSONCXX_PRIVATE_DOXYGEN_PREPROCESSOR)
