@@ -1,4 +1,4 @@
-// Copyright 2014 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -12,22 +12,28 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-#include <cstdlib>
-
 #include <bsoncxx/document/element.hpp>
+
+//
+
+#include <bsoncxx/v1/detail/macros.hpp>
+
+#include <cstdlib>
+#include <string>
+
 #include <bsoncxx/exception/error_code.hpp>
 #include <bsoncxx/exception/exception.hpp>
-#include <bsoncxx/private/libbson.hh>
-#include <bsoncxx/private/suppress_deprecation_warnings.hh>
 #include <bsoncxx/types.hpp>
 #include <bsoncxx/types/bson_value/value.hpp>
 #include <bsoncxx/types/bson_value/view.hpp>
 
-#include <bsoncxx/config/private/prelude.hh>
+#include <bsoncxx/private/bson.hh>
+#include <bsoncxx/private/suppress_deprecation_warnings.hh>
 
-#define BSONCXX_CITER \
-    bson_iter_t iter; \
-    bson_iter_init_from_data_at_offset(&iter, _raw, _length, _offset, _keylen);
+#define BSONCXX_CITER                                                           \
+    bson_iter_t iter;                                                           \
+    bson_iter_init_from_data_at_offset(&iter, _raw, _length, _offset, _keylen); \
+    ((void)0)
 
 namespace bsoncxx {
 namespace v_noabi {
@@ -35,16 +41,12 @@ namespace document {
 
 element::element() : element(nullptr, 0, 0, 0) {}
 
-element::element(const std::uint8_t* raw,
-                 std::uint32_t length,
-                 std::uint32_t offset,
-                 std::uint32_t keylen)
+element::element(std::uint8_t const* raw, std::uint32_t length, std::uint32_t offset, std::uint32_t keylen)
     : _raw(raw), _length(length), _offset(offset), _keylen(keylen) {}
 
-element::element(const stdx::string_view key)
-    : _raw(nullptr), _length(0), _offset(0), _keylen(0), _key(key) {}
+element::element(stdx::string_view const key) : _raw(nullptr), _length(0), _offset(0), _keylen(0), _key(key) {}
 
-const std::uint8_t* element::raw() const {
+std::uint8_t const* element::raw() const {
     return _raw;
 }
 
@@ -81,38 +83,25 @@ stdx::string_view element::key() const {
 
     BSONCXX_CITER;
 
-    const char* key = bson_iter_key(&iter);
+    char const* key = bson_iter_key(&iter);
 
     return stdx::string_view{key};
 }
 
-#define BSONCXX_ENUM(name, val)                                                                 \
-    types::b_##name element::get_##name() const {                                               \
-        if (_raw == nullptr) {                                                                  \
-            throw bsoncxx::v_noabi::exception{                                                  \
-                error_code::k_unset_element,                                                    \
-                "cannot get " #name " from an uninitialized element" +                          \
-                    std::string(_key ? " with key \"" + std::string(_key.value().data()) + "\"" \
-                                     : "")};                                                    \
-        }                                                                                       \
-        types::bson_value::view v{_raw, _length, _offset, _keylen};                             \
-        return v.get_##name();                                                                  \
+#define BSONCXX_ENUM(name, val)                                                                         \
+    types::b_##name element::get_##name() const {                                                       \
+        if (_raw == nullptr) {                                                                          \
+            throw bsoncxx::v_noabi::exception{                                                          \
+                error_code::k_unset_element,                                                            \
+                "cannot get " #name " from an uninitialized element" +                                  \
+                    std::string(_key ? " with key \"" + std::string(_key.value().data()) + "\"" : "")}; \
+        }                                                                                               \
+        types::bson_value::view v{_raw, _length, _offset, _keylen};                                     \
+        return v.get_##name();                                                                          \
     }
 #include <bsoncxx/enums/type.hpp>
 #undef BSONCXX_ENUM
 
-types::b_string element::get_utf8() const {
-    if (_raw == nullptr) {
-        throw bsoncxx::v_noabi::exception{
-            error_code::k_unset_element,
-            "cannot get string from an uninitialized element" +
-                std::string(_key ? " with key \"" + std::string(_key.value().data()) + "\"" : "")};
-    }
-
-    types::bson_value::view v{_raw, _length, _offset, _keylen};
-    return v.get_string();
-}
-
 types::bson_value::view element::get_value() const {
     switch (static_cast<int>(type())) {
 #define BSONCXX_ENUM(type, val) \
@@ -122,7 +111,7 @@ types::bson_value::view element::get_value() const {
 #undef BSONCXX_ENUM
     }
 
-    BSONCXX_UNREACHABLE;
+    BSONCXX_PRIVATE_UNREACHABLE;
 }
 
 types::bson_value::value element::get_owning_value() const {
@@ -147,22 +136,22 @@ element::operator bool() const {
     return _raw != nullptr;
 }
 
-bool BSONCXX_CALL operator==(const element& elem, const types::bson_value::view& v) {
+bool operator==(element const& elem, types::bson_value::view const& v) {
     return elem.get_value() == v;
 }
 
-bool BSONCXX_CALL operator==(const types::bson_value::view& v, const element& elem) {
+bool operator==(types::bson_value::view const& v, element const& elem) {
     return elem == v;
 }
 
-bool BSONCXX_CALL operator!=(const element& elem, const types::bson_value::view& v) {
+bool operator!=(element const& elem, types::bson_value::view const& v) {
     return !(elem == v);
 }
 
-bool BSONCXX_CALL operator!=(const types::bson_value::view& v, const element& elem) {
+bool operator!=(types::bson_value::view const& v, element const& elem) {
     return !(elem == v);
 }
 
-}  // namespace document
-}  // namespace v_noabi
-}  // namespace bsoncxx
+} // namespace document
+} // namespace v_noabi
+} // namespace bsoncxx
