@@ -1,4 +1,4 @@
-// Copyright 2015 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -15,10 +15,8 @@
 #include <bsoncxx/string/to_string.hpp>
 #include <bsoncxx/string/view_or_value.hpp>
 
-#include <bsoncxx/config/private/prelude.hh>
-
 namespace bsoncxx {
-inline namespace v_noabi {
+namespace v_noabi {
 namespace string {
 
 view_or_value view_or_value::terminated() const {
@@ -32,10 +30,10 @@ view_or_value view_or_value::terminated() const {
     return {view()};
 }
 
-const char* view_or_value::data() const {
+char const* view_or_value::data() const {
     return view().data();
 }
 
-}  // namespace string
-}  // namespace v_noabi
-}  // namespace bsoncxx
+} // namespace string
+} // namespace v_noabi
+} // namespace bsoncxx
