@@ -34,23 +34,22 @@ struct Person {
     std::string last_name;
     int age;
 
-    bool operator==(const Person& rhs) const {
+    bool operator==(Person const& rhs) const {
         return (first_name == rhs.first_name) && (last_name == rhs.last_name) && (age == rhs.age);
     }
 };
 
-void to_bson(const Person& person, bsoncxx::document::value& bson_object) {
-    bson_object = make_document(kvp("first_name", person.first_name),
-                                kvp("last_name", person.last_name),
-                                kvp("age", person.age));
+void to_bson(Person const& person, bsoncxx::document::value& bson_object) {
+    bson_object =
+        make_document(kvp("first_name", person.first_name), kvp("last_name", person.last_name), kvp("age", person.age));
 }
 
-void from_bson(Person& person, const bsoncxx::document::view& bson_object) {
+void from_bson(Person& person, bsoncxx::document::view const& bson_object) {
     person.first_name = to_string(bson_object["first_name"].get_string().value);
     person.last_name = to_string(bson_object["last_name"].get_string().value);
     person.age = bson_object["age"].get_int32().value;
 }
-}  // namespace test
+} // namespace test
 
 TEST_CASE("Convert between Person struct and BSON object") {
     test::Person expected_person{
@@ -59,10 +58,10 @@ TEST_CASE("Convert between Person struct and BSON object") {
         18,
     };
 
-    bsoncxx::document::value expected_doc =
-        make_document(kvp("first_name", expected_person.first_name),
-                      kvp("last_name", expected_person.last_name),
-                      kvp("age", expected_person.age));
+    bsoncxx::document::value expected_doc = make_document(
+        kvp("first_name", expected_person.first_name),
+        kvp("last_name", expected_person.last_name),
+        kvp("age", expected_person.age));
 
     SECTION("Conversion from Person struct to document::value works") {
         bsoncxx::document::value test_value{expected_person};
@@ -76,9 +75,10 @@ TEST_CASE("Convert between Person struct and BSON object") {
 
     SECTION("Conversion from BSON object to Person using partially constructed object") {
         test::Person other_person{"Test", "Person", 99};
-        document::value other_doc = make_document(kvp("first_name", other_person.first_name),
-                                                  kvp("last_name", other_person.last_name),
-                                                  kvp("age", other_person.age));
+        document::value other_doc = make_document(
+            kvp("first_name", other_person.first_name),
+            kvp("last_name", other_person.last_name),
+            kvp("age", other_person.age));
 
         // Default-constructed person
         test::Person test_person;
@@ -89,4 +89,4 @@ TEST_CASE("Convert between Person struct and BSON object") {
         REQUIRE(test_person == other_person);
     }
 }
-}  // namespace
+} // namespace
