@@ -79,9 +79,9 @@ TEST_CASE("b_array", "[bsoncxx::type::b_array]") {
 }
 
 TEST_CASE("b_binary", "[bsoncxx::type::b_binary]") {
-    b_binary a{binary_sub_type::k_binary, 8, reinterpret_cast<const uint8_t*>("deadbeef")};
-    b_binary b{binary_sub_type::k_binary, 8, reinterpret_cast<const uint8_t*>("deadbeef")};
-    b_binary c{binary_sub_type::k_binary, 8, reinterpret_cast<const uint8_t*>("daedbeef")};
+    b_binary a{binary_sub_type::k_binary, 8, reinterpret_cast<uint8_t const*>("deadbeef")};
+    b_binary b{binary_sub_type::k_binary, 8, reinterpret_cast<uint8_t const*>("deadbeef")};
+    b_binary c{binary_sub_type::k_binary, 8, reinterpret_cast<uint8_t const*>("daedbeef")};
     REQUIRE(a == b);
     REQUIRE(!(a == c));
 }
@@ -228,7 +228,7 @@ TEST_CASE("bson_value::view with b_array", "[bsoncxx::types::bson_value::view]")
 }
 
 TEST_CASE("bson_value::view with b_binary", "[bsoncxx::types::bson_value::view]") {
-    b_binary binary_val{binary_sub_type::k_binary, 8, reinterpret_cast<const uint8_t*>("deadbeef")};
+    b_binary binary_val{binary_sub_type::k_binary, 8, reinterpret_cast<uint8_t const*>("deadbeef")};
     REQUIRE(bson_value::view{binary_val}.get_binary() == binary_val);
 }
 
@@ -332,40 +332,34 @@ TEST_CASE("bson_value::view with equality operator", "[bsoncxx::types::bson_valu
     REQUIRE(original == copy);
 }
 
-TEST_CASE("bson_value::view with equality for value and non-value",
-          "[bsoncxx::types::bson_value::view]") {
+TEST_CASE("bson_value::view with equality for value and non-value", "[bsoncxx::types::bson_value::view]") {
     b_int64 int64_val{100};
     REQUIRE(bson_value::view{int64_val} == int64_val);
 }
 
-TEST_CASE("bson_value::view with equality for non-value and value",
-          "[bsoncxx::types::bson_value::view]") {
+TEST_CASE("bson_value::view with equality for non-value and value", "[bsoncxx::types::bson_value::view]") {
     b_int64 int64_val{100};
     REQUIRE(int64_val == bson_value::view{int64_val});
 }
 
-TEST_CASE("bson_value::view with value inequality operator and same type",
-          "[bsoncxx::types::bson_value::view]") {
+TEST_CASE("bson_value::view with value inequality operator and same type", "[bsoncxx::types::bson_value::view]") {
     bson_value::view first{b_int32{10}};
     bson_value::view second{b_int32{5}};
     REQUIRE(first != second);
 }
 
-TEST_CASE("bson_value::view with value inequality operator and different type",
-          "[bsoncxx::types::bson_value::view]") {
+TEST_CASE("bson_value::view with value inequality operator and different type", "[bsoncxx::types::bson_value::view]") {
     bson_value::view first{b_int32{10}};
     bson_value::view second{b_int64{10}};
     REQUIRE(first != second);
 }
 
-TEST_CASE("bson_value::view with inequality for value and non-value",
-          "[bsoncxx::types::bson_value::view]") {
+TEST_CASE("bson_value::view with inequality for value and non-value", "[bsoncxx::types::bson_value::view]") {
     b_int64 int64_val{100};
     REQUIRE(bson_value::view{b_int64{200}} != int64_val);
 }
 
-TEST_CASE("bson_value::view with inequality for non-value and value",
-          "[bsoncxx::types::bson_value::view]") {
+TEST_CASE("bson_value::view with inequality for non-value and value", "[bsoncxx::types::bson_value::view]") {
     b_int64 int64_val{100};
     REQUIRE(int64_val != bson_value::view{b_int64{200}});
 }
@@ -375,26 +369,26 @@ TEST_CASE("document uninitialized element throws exceptions", "") {
     using bsoncxx::builder::basic::make_document;
     bsoncxx::document::value doc = make_document(kvp("foo", "bar"));
 
-    REQUIRE_THROWS_WITH(doc["doesnotexist"].get_string().value,
+    REQUIRE_THROWS_WITH(
+        doc["doesnotexist"].get_string().value,
 
-                        Catch::Matchers::ContainsSubstring(
-                            "cannot get string from an uninitialized element with key "
-                            "\"doesnotexist\": unset document::element"));
+        Catch::Matchers::ContainsSubstring("cannot get string from an uninitialized element with key "
+                                           "\"doesnotexist\": unset document::element"));
 
-    REQUIRE_THROWS_WITH(doc["alsodoesnotexist"].get_value(),
-                        Catch::Matchers::ContainsSubstring(
-                            "cannot return the type of uninitialized element with key "
-                            "\"alsodoesnotexist\": unset document::element"));
+    REQUIRE_THROWS_WITH(
+        doc["alsodoesnotexist"].get_value(),
+        Catch::Matchers::ContainsSubstring("cannot return the type of uninitialized element with key "
+                                           "\"alsodoesnotexist\": unset document::element"));
 
     // Ensure a non-existing element evaluates to false.
     REQUIRE(!doc["doesnotexist"]);
     // Ensure finding a non-existing element results in an end iterator.
     REQUIRE(doc.find("doesnotexist") == doc.cend());
     // Ensure getting a key from a non-existing element results in an exception.
-    REQUIRE_THROWS_WITH(doc["doesnotexist"].key(),
-                        Catch::Matchers::ContainsSubstring(
-                            "cannot return the key from an uninitialized element with key "
-                            "\"doesnotexist\": unset document::element"));
+    REQUIRE_THROWS_WITH(
+        doc["doesnotexist"].key(),
+        Catch::Matchers::ContainsSubstring("cannot return the key from an uninitialized element with key "
+                                           "\"doesnotexist\": unset document::element"));
 }
 
 TEST_CASE("array uninitialized element throws exceptions", "") {
@@ -402,18 +396,18 @@ TEST_CASE("array uninitialized element throws exceptions", "") {
     using bsoncxx::builder::basic::make_array;
     bsoncxx::array::value arr = make_array("a", "b", "c");
 
-    REQUIRE_THROWS_WITH(arr.view()[3].get_string().value,
-                        Catch::Matchers::ContainsSubstring(
-                            "cannot get string from an uninitialized element with key "
-                            "\"3\": unset document::element"));
+    REQUIRE_THROWS_WITH(
+        arr.view()[3].get_string().value,
+        Catch::Matchers::ContainsSubstring("cannot get string from an uninitialized element with key "
+                                           "\"3\": unset document::element"));
     // Ensure a non-existing element evaluates to false.
     REQUIRE(!arr.view()[3]);
     // Ensure finding a non-existing element results in an end iterator.
     REQUIRE(arr.view().find(3) == arr.view().cend());
     // Ensure getting a key from a non-existing element results in an exception.
-    REQUIRE_THROWS_WITH(arr.view()[3].key(),
-                        Catch::Matchers::ContainsSubstring(
-                            "cannot return the key from an uninitialized element with key "
-                            "\"3\": unset document::element"));
+    REQUIRE_THROWS_WITH(
+        arr.view()[3].key(),
+        Catch::Matchers::ContainsSubstring("cannot return the key from an uninitialized element with key "
+                                           "\"3\": unset document::element"));
 }
-}  // namespace
+} // namespace
