@@ -1,4 +1,4 @@
-// Copyright 2020 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -19,11 +19,12 @@
 #include <bsoncxx/builder/basic/document.hpp>
 #include <bsoncxx/builder/basic/kvp.hpp>
 #include <bsoncxx/document/view.hpp>
-#include <bsoncxx/test/catch.hh>
 #include <bsoncxx/types/bson_value/make_value.hpp>
 #include <bsoncxx/types/bson_value/value.hpp>
 #include <bsoncxx/types/bson_value/view.hpp>
 
+#include <bsoncxx/test/catch.hh>
+
 namespace {
 using namespace bsoncxx;
 
@@ -54,7 +55,7 @@ void coverting_construction_test(T actual, U expected) {
     REQUIRE(_static_cast == expected);
 }
 
-}  // namespace
+} // namespace
 
 TEST_CASE("types::bson_value::value", "[bsoncxx::types::bson_value::value]") {
     SECTION("can be constructed from") {
@@ -77,7 +78,7 @@ TEST_CASE("types::bson_value::value", "[bsoncxx::types::bson_value::value]") {
             coverting_construction_test(b_string{value}, test_doc);
             coverting_construction_test(stdx::string_view{value}, test_doc);
 
-            const char raw_data[]{'s', 'u', 'p', 'e', 'r', ' ', 'd', 'u', 'p', 'e', 'r'};
+            char const raw_data[]{'s', 'u', 'p', 'e', 'r', ' ', 'd', 'u', 'p', 'e', 'r'};
             coverting_construction_test(stdx::string_view{raw_data, 11}, test_doc);
 
             auto test_empty = bson_value::make_value("");
@@ -248,14 +249,14 @@ TEST_CASE("types::bson_value::value", "[bsoncxx::types::bson_value::value]") {
         SECTION("binary") {
             std::vector<uint8_t> bin{'d', 'e', 'a', 'd', 'b', 'e', 'e', 'f'};
             auto test_doc = bson_value::make_value(
-                b_binary{binary_sub_type::k_binary, (uint32_t)bin.size(), bin.data()});
+                b_binary{binary_sub_type::k_binary, static_cast<uint32_t>(bin.size()), bin.data()});
             value_construction_test(test_doc.view());
 
             coverting_construction_test(bin, test_doc);
-            REQUIRE(bson_value::value(b_binary{
-                        binary_sub_type::k_binary, (uint32_t)bin.size(), bin.data()}) == test_doc);
-            REQUIRE(bson_value::value(bin.data(), bin.size(), binary_sub_type::k_binary) ==
-                    test_doc);
+            REQUIRE(
+                bson_value::value(b_binary{binary_sub_type::k_binary, static_cast<uint32_t>(bin.size()), bin.data()}) ==
+                test_doc);
+            REQUIRE(bson_value::value(bin.data(), bin.size(), binary_sub_type::k_binary) == test_doc);
             REQUIRE(bson_value::value(bin.data(), bin.size()) == test_doc);
 
             auto empty = bson_value::make_value(b_binary{});
@@ -415,4 +416,4 @@ TEST_CASE("types::bson_value::value", "[bsoncxx::types::bson_value::value]") {
     }
 }
 
-}  // namespace
+} // namespace
