@@ -1,4 +1,4 @@
-// Copyright 2020 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -20,7 +20,9 @@
 #include <stdlib.h>
 
 #include <bsoncxx/oid.hpp>
-#include <bsoncxx/private/libbson.hh>
+
+#include <bsoncxx/private/bson.hh>
+
 #include <bsoncxx/test/catch.hh>
 
 using namespace bsoncxx;
@@ -33,7 +35,7 @@ struct parsed_oid {
     uint32_t counter;
 };
 
-parsed_oid parse_oid(const oid& oid) {
+parsed_oid parse_oid(oid const& oid) {
     parsed_oid parsed{};
 
     // Parse into component sections
@@ -57,7 +59,7 @@ parsed_oid parse_oid(const oid& oid) {
     return parsed;
 }
 
-void compare_string(const std::time_t& t, std::string time) {
+void compare_string(std::time_t const& t, std::string time) {
     char time_str[48];
 
     REQUIRE(0 != (strftime(time_str, sizeof(time_str), "%b %e, %Y %H:%M:%S UTC", std::gmtime(&t))));
@@ -120,4 +122,4 @@ TEST_CASE("oid", "[bsoncxx::oid]") {
     }
 }
 
-}  // namespace
+} // namespace
