@@ -1,4 +1,4 @@
-// Copyright 2014 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -17,12 +17,17 @@
 #include <memory>
 #include <string>
 
+#include <mongocxx/client-fwd.hpp>
+#include <mongocxx/client_encryption-fwd.hpp>
+#include <mongocxx/collection-fwd.hpp>
+#include <mongocxx/database-fwd.hpp>
+
 #include <bsoncxx/document/view_or_value.hpp>
 #include <bsoncxx/string/view_or_value.hpp>
+
 #include <mongocxx/client_session.hpp>
 #include <mongocxx/collection.hpp>
 #include <mongocxx/gridfs/bucket.hpp>
-#include <mongocxx/options/create_collection.hpp>
 #include <mongocxx/options/gridfs/bucket.hpp>
 #include <mongocxx/read_preference.hpp>
 #include <mongocxx/write_concern.hpp>
@@ -30,59 +35,54 @@
 #include <mongocxx/config/prelude.hpp>
 
 namespace mongocxx {
-inline namespace v_noabi {
-class client_encryption;
-class client;
-class collection;
+namespace v_noabi {
 
 ///
-/// Class representing a MongoDB database.
+/// A MongoDB database.
 ///
 /// Acts as a gateway for accessing collections that are contained within a database. It inherits
 /// all of its default settings from the client that creates it.
 ///
-class MONGOCXX_API database {
+class database {
    public:
     ///
     /// Default constructs a new database. The database is not valid for use and is equivalent
     /// to the state of a moved-from database. The only valid actions to take with a default
     /// constructed database are to assign to it, or destroy it.
     ///
-    database() noexcept;
+    MONGOCXX_ABI_EXPORT_CDECL() database() noexcept;
 
     ///
     /// Move constructs a database.
     ///
-    database(database&&) noexcept;
+    MONGOCXX_ABI_EXPORT_CDECL() database(database&&) noexcept;
 
     ///
     /// Move assigns a database.
     ///
-    database& operator=(database&&) noexcept;
+    MONGOCXX_ABI_EXPORT_CDECL(database&) operator=(database&&) noexcept;
 
     ///
     /// Copy constructs a database.
     ///
-    database(const database&);
+    MONGOCXX_ABI_EXPORT_CDECL() database(database const&);
 
     ///
     /// Copy assigns a database.
     ///
-    database& operator=(const database&);
+    MONGOCXX_ABI_EXPORT_CDECL(database&) operator=(database const&);
 
     ///
     /// Destroys a database.
     ///
-    ~database();
+    MONGOCXX_ABI_EXPORT_CDECL() ~database();
 
     ///
     /// Returns true if the client is valid, meaning it was not default constructed
     /// or moved from.
     ///
-    explicit operator bool() const noexcept;
+    explicit MONGOCXX_ABI_EXPORT_CDECL() operator bool() const noexcept;
 
-    ///
-    /// @{
     ///
     /// Runs an aggregation framework pipeline against this database for
     /// pipeline stages that do not require an underlying collection,
@@ -91,21 +91,22 @@ class MONGOCXX_API database {
     /// @param pipeline
     ///   The pipeline of aggregation operations to perform.
     /// @param options
-    ///   Optional arguments, see mongocxx::options::aggregate.
+    ///   Optional arguments, see mongocxx::v_noabi::options::aggregate.
     ///
-    /// @return A mongocxx::cursor with the results.  If the query fails,
-    /// the cursor throws mongocxx::query_exception when the returned cursor
+    /// @return A mongocxx::v_noabi::cursor with the results.  If the query fails,
+    /// the cursor throws mongocxx::v_noabi::query_exception when the returned cursor
     /// is iterated.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/aggregate/#dbcmd.aggregate
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/aggregate/#dbcmd.aggregate
     ///
     /// @note
     ///   In order to pass a read concern to this, you must use the
     ///   database level set read concern - database::read_concern(rc).
     ///   (Write concern supported only for MongoDB 3.4+).
     ///
-    cursor aggregate(const pipeline& pipeline,
-                     const options::aggregate& options = options::aggregate());
+    MONGOCXX_ABI_EXPORT_CDECL(cursor)
+    aggregate(pipeline const& pipeline, options::aggregate const& options = options::aggregate());
 
     ///
     /// Runs an aggregation framework pipeline against this database for
@@ -113,82 +114,79 @@ class MONGOCXX_API database {
     /// such as $currentOp and $listLocalSessions.
     ///
     /// @param session
-    ///   The mongocxx::client_session with which to perform the aggregation.
+    ///   The mongocxx::v_noabi::client_session with which to perform the aggregation.
     /// @param pipeline
     ///   The pipeline of aggregation operations to perform.
     /// @param options
-    ///   Optional arguments, see mongocxx::options::aggregate.
+    ///   Optional arguments, see mongocxx::v_noabi::options::aggregate.
     ///
-    /// @return A mongocxx::cursor with the results.  If the query fails,
-    /// the cursor throws mongocxx::query_exception when the returned cursor
+    /// @return A mongocxx::v_noabi::cursor with the results.  If the query fails,
+    /// the cursor throws mongocxx::v_noabi::query_exception when the returned cursor
     /// is iterated.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/aggregate/#dbcmd.aggregate
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/aggregate/#dbcmd.aggregate
     ///
     /// @note
     ///   In order to pass a read concern to this, you must use the
     ///   database level set read concern - database::read_concern(rc).
     ///   (Write concern supported only for MongoDB 3.4+).
     ///
-    cursor aggregate(const client_session& session,
-                     const pipeline& pipeline,
-                     const options::aggregate& options = options::aggregate());
-    ///
-    /// @}
-    ///
-
-    ///
-    /// @{
-    ///
-    /// Runs a command against this database.
-    ///
-    /// @see https://www.mongodb.com/docs/manual/reference/method/db.runCommand/
-    ///
-    /// @param command document representing the command to be run.
-    /// @return the result of executing the command.
-    ///
-    /// @throws mongocxx::operation_exception if the operation fails.
-    ///
-    bsoncxx::document::value run_command(bsoncxx::document::view_or_value command);
+    MONGOCXX_ABI_EXPORT_CDECL(cursor)
+    aggregate(
+        client_session const& session,
+        pipeline const& pipeline,
+        options::aggregate const& options = options::aggregate());
 
     ///
     /// Runs a command against this database.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/method/db.runCommand/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/method/db.runCommand/
     ///
-    /// @param session The mongocxx::client_session with which to run the command.
     /// @param command document representing the command to be run.
     /// @return the result of executing the command.
     ///
-    /// @throws mongocxx::operation_exception if the operation fails.
+    /// @throws mongocxx::v_noabi::operation_exception if the operation fails.
     ///
-    bsoncxx::document::value run_command(const client_session& session,
-                                         bsoncxx::document::view_or_value command);
+    MONGOCXX_ABI_EXPORT_CDECL(bsoncxx::v_noabi::document::value)
+    run_command(bsoncxx::v_noabi::document::view_or_value command);
+
+    ///
+    /// Runs a command against this database.
+    ///
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/method/db.runCommand/
+    ///
+    /// @param session The mongocxx::v_noabi::client_session with which to run the command.
+    /// @param command document representing the command to be run.
+    /// @return the result of executing the command.
+    ///
+    /// @throws mongocxx::v_noabi::operation_exception if the operation fails.
+    ///
+    MONGOCXX_ABI_EXPORT_CDECL(bsoncxx::v_noabi::document::value)
+    run_command(client_session const& session, bsoncxx::v_noabi::document::view_or_value command);
 
     ///
     /// Executes a command on a specific server using this database.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/method/db.runCommand/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/method/db.runCommand/
     ///
     /// @param command document representing the command to be run.
     /// @param server_id specifying which server to use.
     /// @return the result of executing the command.
     ///
-    /// @throws mongocxx::operation_exception if the operation fails.
-    ///
-    bsoncxx::document::value run_command(bsoncxx::document::view_or_value command,
-                                         uint32_t server_id);
-    ///
-    /// @}
+    /// @throws mongocxx::v_noabi::operation_exception if the operation fails.
     ///
+    MONGOCXX_ABI_EXPORT_CDECL(bsoncxx::v_noabi::document::value)
+    run_command(bsoncxx::v_noabi::document::view_or_value command, uint32_t server_id);
 
-    ///
-    /// @{
     ///
     /// Explicitly creates a collection in this database with the specified options.
     ///
     /// @see
-    ///   https://www.mongodb.com/docs/manual/reference/command/create/
+    /// - https://www.mongodb.com/docs/manual/reference/command/create/
     ///
     /// @note This function can also be used to create a Time Series Collection. See:
     /// https://www.mongodb.com/docs/manual/core/timeseries-collections/
@@ -202,23 +200,25 @@ class MONGOCXX_API database {
     ///   set write concern if none passed here.
     ///
     /// @exception
-    ///   mongocxx::operation_exception if the operation fails.
+    ///   mongocxx::v_noabi::operation_exception if the operation fails.
     ///
-    class collection create_collection(stdx::string_view name,
-                                       bsoncxx::document::view_or_value collection_options = {},
-                                       const stdx::optional<write_concern>& write_concern = {});
+    MONGOCXX_ABI_EXPORT_CDECL(mongocxx::v_noabi::collection)
+    create_collection(
+        bsoncxx::v_noabi::stdx::string_view name,
+        bsoncxx::v_noabi::document::view_or_value collection_options = {},
+        bsoncxx::v_noabi::stdx::optional<write_concern> const& write_concern = {});
 
     ///
     /// Explicitly creates a collection in this database with the specified options.
     ///
     /// @see
-    ///   https://www.mongodb.com/docs/manual/reference/command/create/
+    /// - https://www.mongodb.com/docs/manual/reference/command/create/
     ///
     /// @note This function can also be used to create a Time Series Collection. See:
     /// https://www.mongodb.com/docs/manual/core/timeseries-collections/
     ///
     /// @param session
-    ///   The mongocxx::client_session with which to perform the create operation.
+    ///   The mongocxx::v_noabi::client_session with which to perform the create operation.
     /// @param name
     ///   the new collection's name.
     /// @param collection_options
@@ -228,112 +228,15 @@ class MONGOCXX_API database {
     ///   set write concern if none passed here.
     ///
     /// @exception
-    ///   mongocxx::operation_exception if the operation fails.
+    ///   mongocxx::v_noabi::operation_exception if the operation fails.
     ///
-    class collection create_collection(const client_session& session,
-                                       stdx::string_view name,
-                                       bsoncxx::document::view_or_value collection_options = {},
-                                       const stdx::optional<write_concern>& write_concern = {});
+    MONGOCXX_ABI_EXPORT_CDECL(mongocxx::v_noabi::collection)
+    create_collection(
+        client_session const& session,
+        bsoncxx::v_noabi::stdx::string_view name,
+        bsoncxx::v_noabi::document::view_or_value collection_options = {},
+        bsoncxx::v_noabi::stdx::optional<write_concern> const& write_concern = {});
 
-    ///
-    /// Explicitly creates a collection in this database with the specified options.
-    ///
-    /// @deprecated
-    ///   This overload is deprecated. Call database::create_collection with a
-    ///   bsoncxx::document::view_or_value collection_options instead.
-    ///
-    /// @see
-    ///   https://www.mongodb.com/docs/manual/reference/command/create/
-    ///
-    /// @param name
-    ///   the new collection's name.
-    /// @param collection_options
-    ///   the options for the new collection.
-    /// @param write_concern
-    ///   the write concern to use for this operation. Will default to database
-    ///   set write concern if none passed here.
-    ///
-    /// @exception
-    ///   mongocxx::operation_exception if the operation fails.
-    ///
-    MONGOCXX_DEPRECATED class collection create_collection(
-        bsoncxx::string::view_or_value name,
-        const options::create_collection_deprecated& collection_options,
-        const stdx::optional<write_concern>& write_concern = {}) {
-        return create_collection_deprecated(name, collection_options, write_concern);
-    }
-
-    class collection create_collection_deprecated(
-        bsoncxx::string::view_or_value name,
-        const options::create_collection_deprecated& collection_options,
-        const stdx::optional<write_concern>& write_concern = {});
-
-    ///
-    /// Explicitly creates a collection in this database with the specified options.
-    ///
-    /// @deprecated
-    ///   This overload is deprecated. Call database::create_collection with a
-    ///   bsoncxx::document::view_or_value collection_options instead.
-    ///
-    /// @see
-    ///   https://www.mongodb.com/docs/manual/reference/command/create/
-    ///
-    /// @param session
-    ///   The mongocxx::client_session with which to perform the create operation.
-    /// @param name
-    ///   the new collection's name.
-    /// @param collection_options
-    ///   the options for the new collection.
-    /// @param write_concern
-    ///   the write concern to use for this operation. Will default to database
-    ///   set write concern if none passed here.
-    ///
-    /// @exception
-    ///   mongocxx::operation_exception if the operation fails.
-    ///
-    MONGOCXX_DEPRECATED class collection create_collection(
-        const client_session& session,
-        bsoncxx::string::view_or_value name,
-        const options::create_collection_deprecated& collection_options,
-        const stdx::optional<write_concern>& write_concern = {}) {
-        return create_collection_deprecated(session, name, collection_options, write_concern);
-    }
-
-    ///
-    /// Explicitly creates a collection in this database with the specified options.
-    ///
-    /// @deprecated
-    ///   This overload is deprecated. Call database::create_collection with a
-    ///   bsoncxx::document::view_or_value collection_options instead.
-    ///
-    /// @see
-    ///   https://www.mongodb.com/docs/manual/reference/command/create/
-    ///
-    /// @param session
-    ///   The mongocxx::client_session with which to perform the create operation.
-    /// @param name
-    ///   the new collection's name.
-    /// @param collection_options
-    ///   the options for the new collection.
-    /// @param write_concern
-    ///   the write concern to use for this operation. Will default to database
-    ///   set write concern if none passed here.
-    ///
-    /// @exception
-    ///   mongocxx::operation_exception if the operation fails.
-    ///
-    class collection create_collection_deprecated(
-        const client_session& session,
-        bsoncxx::string::view_or_value name,
-        const options::create_collection_deprecated& collection_options,
-        const stdx::optional<write_concern>& write_concern = {});
-
-    ///
-    /// @}
-    ///
-
-    ///
-    /// @{
     ///
     /// Drops the database and all its collections.
     ///
@@ -342,33 +245,33 @@ class MONGOCXX_API database {
     ///   set on the database will be used.
     ///
     /// @exception
-    ///   mongocxx::operation_exception if the operation fails.
+    ///   mongocxx::v_noabi::operation_exception if the operation fails.
     ///
     /// @see
-    ///   https://www.mongodb.com/docs/manual/reference/command/dropDatabase/
+    /// - https://www.mongodb.com/docs/manual/reference/command/dropDatabase/
     ///
-    void drop(const bsoncxx::stdx::optional<mongocxx::write_concern>& write_concern = {});
+    MONGOCXX_ABI_EXPORT_CDECL(void)
+    drop(bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::write_concern> const& write_concern = {});
 
     ///
     /// Drops the database and all its collections.
     ///
     /// @param session
-    ///   The mongocxx::client_session with which to perform the aggregation.
+    ///   The mongocxx::v_noabi::client_session with which to perform the aggregation.
     /// @param write_concern (optional)
     ///   The write concern to be used for this operation. If not passed here, the write concern
     ///   set on the database will be used.
     ///
     /// @exception
-    ///   mongocxx::operation_exception if the operation fails.
+    ///   mongocxx::v_noabi::operation_exception if the operation fails.
     ///
     /// @see
-    ///   https://www.mongodb.com/docs/manual/reference/command/dropDatabase/
-    ///
-    void drop(const client_session& session,
-              const bsoncxx::stdx::optional<mongocxx::write_concern>& write_concern = {});
-    ///
-    /// @}
+    /// - https://www.mongodb.com/docs/manual/reference/command/dropDatabase/
     ///
+    MONGOCXX_ABI_EXPORT_CDECL(void)
+    drop(
+        client_session const& session,
+        bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::write_concern> const& write_concern = {});
 
     ///
     /// Checks whether this database contains a collection having the given name.
@@ -377,39 +280,41 @@ class MONGOCXX_API database {
     ///
     /// @return bool whether the collection exists in this database.
     ///
-    /// @throws mongocxx::operation_exception if the underlying 'listCollections'
+    /// @throws mongocxx::v_noabi::operation_exception if the underlying 'listCollections'
     /// command fails.
     ///
-    bool has_collection(bsoncxx::string::view_or_value name) const;
+    MONGOCXX_ABI_EXPORT_CDECL(bool)
+    has_collection(bsoncxx::v_noabi::string::view_or_value name) const;
 
-    ///
-    /// @{
     ///
     /// Enumerates the collections in this database.
     ///
     /// @param filter
     ///   An optional query expression to filter the returned collections.
     ///
-    /// @return mongocxx::cursor containing the collection information.
+    /// @return mongocxx::v_noabi::cursor containing the collection information.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/listCollections/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/listCollections/
     ///
-    cursor list_collections(bsoncxx::document::view_or_value filter = {});
+    MONGOCXX_ABI_EXPORT_CDECL(cursor)
+    list_collections(bsoncxx::v_noabi::document::view_or_value filter = {});
 
     ///
     /// Enumerates the collections in this database.
     ///
     /// @param session
-    ///   The mongocxx::client_session with which to perform the aggregation.
+    ///   The mongocxx::v_noabi::client_session with which to perform the aggregation.
     /// @param filter
     ///   An optional query expression to filter the returned collections.
     ///
-    /// @return mongocxx::cursor containing the collection information.
+    /// @return mongocxx::v_noabi::cursor containing the collection information.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/listCollections/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/listCollections/
     ///
-    cursor list_collections(const client_session& session,
-                            bsoncxx::document::view_or_value filter = {});
+    MONGOCXX_ABI_EXPORT_CDECL(cursor)
+    list_collections(client_session const& session, bsoncxx::v_noabi::document::view_or_value filter = {});
 
     ///
     /// Enumerates the collection names in this database.
@@ -419,41 +324,40 @@ class MONGOCXX_API database {
     ///
     /// @return std::vector<std::string> containing the collection names.
     ///
-    /// @throws mongocxx::operation_exception if the underlying 'listCollections'
+    /// @throws mongocxx::v_noabi::operation_exception if the underlying 'listCollections'
     /// command fails.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/listCollections/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/listCollections/
     ///
-    std::vector<std::string> list_collection_names(bsoncxx::document::view_or_value filter = {});
+    MONGOCXX_ABI_EXPORT_CDECL(std::vector<std::string>)
+    list_collection_names(bsoncxx::v_noabi::document::view_or_value filter = {});
 
     ///
     /// Enumerates the collection names in this database.
     ///
     /// @param session
-    ///   The mongocxx::client_session with which to perform the aggregation.
+    ///   The mongocxx::v_noabi::client_session with which to perform the aggregation.
     /// @param filter
     ///   An optional query expression to filter the returned collection names.
     ///
     /// @return std::vector<std::string> containing the collection names.
     ///
-    /// @throws mongocxx::operation_exception if the underlying 'listCollections'
+    /// @throws mongocxx::v_noabi::operation_exception if the underlying 'listCollections'
     /// command fails.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/listCollections/
-    ///
-    std::vector<std::string> list_collection_names(const client_session& session,
-                                                   bsoncxx::document::view_or_value filter = {});
-
-    ///
-    /// @}
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/listCollections/
     ///
+    MONGOCXX_ABI_EXPORT_CDECL(std::vector<std::string>)
+    list_collection_names(client_session const& session, bsoncxx::v_noabi::document::view_or_value filter = {});
 
     ///
     /// Get the name of this database.
     ///
     /// @return the name of this database.
     ///
-    stdx::string_view name() const;
+    MONGOCXX_ABI_EXPORT_CDECL(bsoncxx::v_noabi::stdx::string_view) name() const;
 
     ///
     /// Sets the read_concern for this database.
@@ -465,9 +369,10 @@ class MONGOCXX_API database {
     /// @param rc
     ///   The new @c read_concern
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/read-concern/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/read-concern/
     ///
-    void read_concern(class read_concern rc);
+    MONGOCXX_ABI_EXPORT_CDECL(void) read_concern(mongocxx::v_noabi::read_concern rc);
 
     ///
     /// The current read concern for this database.
@@ -477,7 +382,7 @@ class MONGOCXX_API database {
     ///
     /// @return the current read_concern
     ///
-    class read_concern read_concern() const;
+    MONGOCXX_ABI_EXPORT_CDECL(mongocxx::v_noabi::read_concern) read_concern() const;
 
     ///
     /// Sets the read_preference for this database.
@@ -486,20 +391,22 @@ class MONGOCXX_API database {
     /// from this database, but do affect new ones. New collections will receive a copy of the
     /// new read_preference for this database upon instantiation.
     ///
-    /// @see https://www.mongodb.com/docs/manual/core/read-preference/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/core/read-preference/
     ///
     /// @param rp the new read_preference.
     ///
-    void read_preference(class read_preference rp);
+    MONGOCXX_ABI_EXPORT_CDECL(void) read_preference(mongocxx::v_noabi::read_preference rp);
 
     ///
     /// The current read preference for this database.
     ///
-    /// @see https://www.mongodb.com/docs/manual/core/read-preference/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/core/read-preference/
     ///
     /// @return the current read_preference
     ///
-    class read_preference read_preference() const;
+    MONGOCXX_ABI_EXPORT_CDECL(mongocxx::v_noabi::read_preference) read_preference() const;
 
     ///
     /// Sets the write_concern for this database.
@@ -508,14 +415,14 @@ class MONGOCXX_API database {
     /// from this database, but do affect new ones as new collections will receive a copy of the
     /// write_concern of this database upon instantiation.
     ///
-    void write_concern(class write_concern wc);
+    MONGOCXX_ABI_EXPORT_CDECL(void) write_concern(mongocxx::v_noabi::write_concern wc);
 
     ///
     /// The current write_concern for this database.
     ///
     /// @return the current write_concern
     ///
-    class write_concern write_concern() const;
+    MONGOCXX_ABI_EXPORT_CDECL(mongocxx::v_noabi::write_concern) write_concern() const;
 
     ///
     /// Access a collection (logical grouping of documents) within this database.
@@ -524,7 +431,8 @@ class MONGOCXX_API database {
     ///
     /// @return the collection.
     ///
-    class collection collection(bsoncxx::string::view_or_value name) const;
+    MONGOCXX_ABI_EXPORT_CDECL(mongocxx::v_noabi::collection)
+    collection(bsoncxx::v_noabi::string::view_or_value name) const;
 
     ///
     /// Allows the db["collection_name"] syntax to be used to access a collection within this
@@ -534,7 +442,9 @@ class MONGOCXX_API database {
     ///
     /// @return the collection.
     ///
-    MONGOCXX_INLINE class collection operator[](bsoncxx::string::view_or_value name) const;
+    mongocxx::v_noabi::collection operator[](bsoncxx::v_noabi::string::view_or_value name) const {
+        return collection(name);
+    }
 
     ///
     /// Access a GridFS bucket within this database.
@@ -548,13 +458,11 @@ class MONGOCXX_API database {
     /// @note
     ///   See the class comment for `gridfs::bucket` for more information about GridFS.
     ///
-    /// @throws mongocxx::logic_error if `options` are invalid.
+    /// @throws mongocxx::v_noabi::logic_error if `options` are invalid.
     ///
-    class gridfs::bucket gridfs_bucket(
-        const options::gridfs::bucket& options = options::gridfs::bucket()) const;
+    MONGOCXX_ABI_EXPORT_CDECL(gridfs::bucket)
+    gridfs_bucket(options::gridfs::bucket const& options = options::gridfs::bucket()) const;
 
-    ///
-    /// @{
     ///
     /// Gets a change stream on this database with an empty pipeline.
     /// Change streams are only supported with a "majority" read concern or no read concern.
@@ -565,22 +473,25 @@ class MONGOCXX_API database {
     /// @return
     ///  A change stream on this database.
     ///
-    /// @see https://www.mongodb.com/docs/manual/changeStreams/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/changeStreams/
     ///
-    change_stream watch(const options::change_stream& options = {});
+    MONGOCXX_ABI_EXPORT_CDECL(change_stream) watch(options::change_stream const& options = {});
 
     ///
     /// @param session
-    ///   The mongocxx::client_session with which to perform the watch operation.
+    ///   The mongocxx::v_noabi::client_session with which to perform the watch operation.
     /// @param options
     ///   The options to use when creating the change stream.
     ///
     /// @return
     ///  A change stream on this database.
     ///
-    /// @see https://www.mongodb.com/docs/manual/changeStreams/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/changeStreams/
     ///
-    change_stream watch(const client_session& session, const options::change_stream& options = {});
+    MONGOCXX_ABI_EXPORT_CDECL(change_stream)
+    watch(client_session const& session, options::change_stream const& options = {});
 
     ///
     /// Gets a change stream on this database.
@@ -596,15 +507,17 @@ class MONGOCXX_API database {
     /// @return
     ///  A change stream on this database.
     ///
-    /// @see https://www.mongodb.com/docs/manual/changeStreams/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/changeStreams/
     ///
-    change_stream watch(const pipeline& pipe, const options::change_stream& options = {});
+    MONGOCXX_ABI_EXPORT_CDECL(change_stream)
+    watch(pipeline const& pipe, options::change_stream const& options = {});
 
     ///
     /// Gets a change stream on this database.
     ///
     /// @param session
-    ///   The mongocxx::client_session with which to perform the watch operation.
+    ///   The mongocxx::v_noabi::client_session with which to perform the watch operation.
     /// @param pipe
     ///   The aggregation pipeline to be used on the change notifications.
     /// @param options
@@ -613,69 +526,57 @@ class MONGOCXX_API database {
     /// @return
     ///  A change stream on this database.
     ///
-    /// @see https://www.mongodb.com/docs/manual/changeStreams/
-    ///
-    change_stream watch(const client_session& session,
-                        const pipeline& pipe,
-                        const options::change_stream& options = {});
-
-    ///
-    /// @}
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/changeStreams/
     ///
+    MONGOCXX_ABI_EXPORT_CDECL(change_stream)
+    watch(client_session const& session, pipeline const& pipe, options::change_stream const& options = {});
 
    private:
-    friend class client_encryption;
-    friend class client;
-    friend class collection;
+    friend ::mongocxx::v_noabi::client_encryption;
+    friend ::mongocxx::v_noabi::client;
+    friend ::mongocxx::v_noabi::collection;
 
-    MONGOCXX_PRIVATE database(const class client& client, bsoncxx::string::view_or_value name);
+    database(mongocxx::v_noabi::client const& client, bsoncxx::v_noabi::string::view_or_value name);
 
-    MONGOCXX_PRIVATE cursor _aggregate(const client_session* session,
-                                       const pipeline& pipeline,
-                                       const options::aggregate& options);
+    cursor _aggregate(client_session const* session, pipeline const& pipeline, options::aggregate const& options);
 
-    MONGOCXX_PRIVATE bsoncxx::document::value _run_command(
-        const client_session* session, bsoncxx::document::view_or_value command);
+    bsoncxx::v_noabi::document::value _run_command(
+        client_session const* session,
+        bsoncxx::v_noabi::document::view_or_value command);
 
-    MONGOCXX_PRIVATE class collection _create_collection(
-        const client_session* session,
-        stdx::string_view name,
-        bsoncxx::document::view_or_value collection_options,
-        const stdx::optional<class write_concern>& write_concern);
+    mongocxx::v_noabi::collection _create_collection(
+        client_session const* session,
+        bsoncxx::v_noabi::stdx::string_view name,
+        bsoncxx::v_noabi::document::view_or_value collection_options,
+        bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::write_concern> const& write_concern);
 
-    MONGOCXX_PRIVATE class collection _create_collection_deprecated(
-        const client_session* session,
-        bsoncxx::string::view_or_value name,
-        const options::create_collection_deprecated& collection_options,
-        const stdx::optional<class write_concern>& write_concern);
+    cursor _list_collections(client_session const* session, bsoncxx::v_noabi::document::view_or_value filter);
 
-    MONGOCXX_PRIVATE cursor _list_collections(const client_session* session,
-                                              bsoncxx::document::view_or_value filter);
+    std::vector<std::string> _list_collection_names(
+        client_session const* session,
+        bsoncxx::v_noabi::document::view_or_value filter);
 
-    MONGOCXX_PRIVATE std::vector<std::string> _list_collection_names(
-        const client_session* session, bsoncxx::document::view_or_value filter);
+    void _drop(
+        client_session const* session,
+        bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::write_concern> const& write_concern);
 
-    MONGOCXX_PRIVATE void _drop(
-        const client_session* session,
-        const bsoncxx::stdx::optional<mongocxx::write_concern>& write_concern);
+    change_stream _watch(client_session const* session, pipeline const& pipe, options::change_stream const& options);
 
-    MONGOCXX_PRIVATE change_stream _watch(const client_session* session,
-                                          const pipeline& pipe,
-                                          const options::change_stream& options);
+    class impl;
 
-    class MONGOCXX_PRIVATE impl;
-
-    MONGOCXX_PRIVATE impl& _get_impl();
-    MONGOCXX_PRIVATE const impl& _get_impl() const;
+    impl& _get_impl();
+    impl const& _get_impl() const;
 
     std::unique_ptr<impl> _impl;
 };
 
-MONGOCXX_INLINE collection database::operator[](bsoncxx::string::view_or_value name) const {
-    return collection(name);
-}
-
-}  // namespace v_noabi
-}  // namespace mongocxx
+} // namespace v_noabi
+} // namespace mongocxx
 
 #include <mongocxx/config/postlude.hpp>
+
+///
+/// @file
+/// Provides @ref mongocxx::v_noabi::database.
+///
