@@ -29,14 +29,14 @@ namespace v_noabi {
 namespace events {
 
 ///
-/// An event notification sent when the driver begins executing a MongoDB command.
+/// The start of the execution of a MongoDB command.
 ///
 /// @see
-/// - "CommandStartedEvent" in https://github.com/mongodb/specifications/blob/master/source/command-logging-and-monitoring/command-logging-and-monitoring.md
+/// - [Command Logging and Monitoring (MongoDB Specifications)](https://specifications.readthedocs.io/en/latest/command-logging-and-monitoring/command-logging-and-monitoring/)
 ///
 class command_started_event {
    public:
-    explicit command_started_event(const void* event);
+    explicit command_started_event(void const* event);
 
     ///
     /// Destroys a command_started_event.
@@ -46,8 +46,8 @@ class command_started_event {
     command_started_event(command_started_event&&) = default;
     command_started_event& operator=(command_started_event&&) = default;
 
-    command_started_event(const command_started_event&) = default;
-    command_started_event& operator=(const command_started_event&) = default;
+    command_started_event(command_started_event const&) = default;
+    command_started_event& operator=(command_started_event const&) = default;
 
     ///
     /// Returns the command that has been started.
@@ -107,12 +107,12 @@ class command_started_event {
     MONGOCXX_ABI_EXPORT_CDECL(std::uint16_t) port() const;
 
    private:
-    const void* _started_event;
+    void const* _started_event;
 };
 
-}  // namespace events
-}  // namespace v_noabi
-}  // namespace mongocxx
+} // namespace events
+} // namespace v_noabi
+} // namespace mongocxx
 
 #include <mongocxx/config/postlude.hpp>
 
