@@ -22,17 +22,17 @@ namespace events {
 
 class server_closed_event;
 
-}  // namespace events
-}  // namespace v_noabi
-}  // namespace mongocxx
+} // namespace events
+} // namespace v_noabi
+} // namespace mongocxx
 
 namespace mongocxx {
 namespace events {
 
 using ::mongocxx::v_noabi::events::server_closed_event;
 
-}  // namespace events
-}  // namespace mongocxx
+} // namespace events
+} // namespace mongocxx
 
 #include <mongocxx/config/postlude.hpp>
 
@@ -40,16 +40,3 @@ using ::mongocxx::v_noabi::events::server_closed_event;
 /// @file
 /// Declares @ref mongocxx::v_noabi::events::server_closed_event.
 ///
-
-#if defined(MONGOCXX_PRIVATE_DOXYGEN_PREPROCESSOR)
-
-namespace mongocxx {
-namespace events {
-
-/// @ref mongocxx::v_noabi::events::server_closed_event
-class server_closed_event {};
-
-}  // namespace events
-}  // namespace mongocxx
-
-#endif  // defined(MONGOCXX_PRIVATE_DOXYGEN_PREPROCESSOR)
