@@ -30,8 +30,10 @@ namespace v_noabi {
 namespace events {
 
 ///
-/// Class representing what the driver knows about a topology of MongoDB servers: either a
-/// standalone, a replica set, or a sharded cluster.
+/// A description of the topology of one or more connected MongoDB servers.
+///
+/// @see
+/// - mongocxx::v_noabi::events::topology_changed_event
 ///
 class topology_description {
    public:
@@ -53,8 +55,8 @@ class topology_description {
         ///
         MONGOCXX_ABI_EXPORT_CDECL(server_descriptions&) operator=(server_descriptions&&) noexcept;
 
-        server_descriptions(const server_descriptions&) = delete;
-        server_descriptions& operator=(const server_descriptions&) = delete;
+        server_descriptions(server_descriptions const&) = delete;
+        server_descriptions& operator=(server_descriptions const&) = delete;
 
         ///
         /// Destroys a server_descriptions array.
@@ -115,8 +117,8 @@ class topology_description {
     topology_description(topology_description&&) = default;
     topology_description& operator=(topology_description&&) = default;
 
-    topology_description(const topology_description&) = default;
-    topology_description& operator=(const topology_description&) = default;
+    topology_description(topology_description const&) = default;
+    topology_description& operator=(topology_description const&) = default;
 
     ///
     /// The topology type: "Unknown", "Sharded", "ReplicaSetNoPrimary", "ReplicaSetWithPrimary", or
@@ -136,7 +138,7 @@ class topology_description {
     /// @return Whether there is a readable server available.
     ///
     MONGOCXX_ABI_EXPORT_CDECL(bool)
-    has_readable_server(const mongocxx::v_noabi::read_preference& pref) const;
+    has_readable_server(mongocxx::v_noabi::read_preference const& pref) const;
 
     ///
     /// Determines if the topology has a writable server available, such as a
@@ -161,9 +163,9 @@ class topology_description {
     void* _td;
 };
 
-}  // namespace events
-}  // namespace v_noabi
-}  // namespace mongocxx
+} // namespace events
+} // namespace v_noabi
+} // namespace mongocxx
 
 #include <mongocxx/config/postlude.hpp>
 
