@@ -25,7 +25,9 @@ namespace mongocxx {
 namespace v_noabi {
 
 ///
-/// Enum representing the various error types that can occur during driver usage.
+/// Errors which may occur during mongocxx library usage.
+///
+/// @note `std::is_error_code_enum` is specialized for this type.
 ///
 enum class error_code : std::int32_t {
     /// More than one mongocxx::v_noabi::instance has been created.
@@ -119,7 +121,7 @@ enum class error_code : std::int32_t {
 ///
 /// @return The mongocxx error_category
 ///
-MONGOCXX_ABI_EXPORT_CDECL(const std::error_category&) error_category();
+MONGOCXX_ABI_EXPORT_CDECL(std::error_category const&) error_category();
 
 ///
 /// Translate a mongocxx::v_noabi::error_code into a std::error_code.
@@ -132,44 +134,28 @@ inline std::error_code make_error_code(error_code error) {
     return {static_cast<int>(error), error_category()};
 }
 
-}  // namespace v_noabi
-}  // namespace mongocxx
+} // namespace v_noabi
+} // namespace mongocxx
 
 namespace mongocxx {
 
 using ::mongocxx::v_noabi::error_category;
 using ::mongocxx::v_noabi::make_error_code;
 
-}  // namespace mongocxx
+} // namespace mongocxx
 
 #include <mongocxx/config/postlude.hpp>
 
 namespace std {
 
-///
-/// Indicates @ref mongocxx::v_noabi::error_code is eligible for `std::error_code` implicit
-/// conversions.
-///
+// @cond DOXYGEN_DISABLE
 template <>
 struct is_error_code_enum<::mongocxx::v_noabi::error_code> : std::true_type {};
+// @endcond
 
-}  // namespace std
+} // namespace std
 
 ///
 /// @file
 /// Provides @ref mongocxx::v_noabi::error_code.
 ///
-
-#if defined(MONGOCXX_PRIVATE_DOXYGEN_PREPROCESSOR)
-
-namespace mongocxx {
-
-/// @ref mongocxx::v_noabi::error_category()
-const std::error_category& error_category();
-
-/// @ref mongocxx::v_noabi::make_error_code(v_noabi::error_code error)
-inline std::error_code make_error_code(v_noabi::error_code error);
-
-}  // namespace mongocxx
-
-#endif  // defined(MONGOCXX_PRIVATE_DOXYGEN_PREPROCESSOR)
