@@ -1,4 +1,4 @@
-// Copyright 2014 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -14,23 +14,39 @@
 
 #pragma once
 
+#include <mongocxx/exception/logic_error-fwd.hpp>
+
 #include <mongocxx/exception/exception.hpp>
 
 #include <mongocxx/config/prelude.hpp>
 
 namespace mongocxx {
-inline namespace v_noabi {
+namespace v_noabi {
+
 ///
-/// Class representing an exception caused by using the mongocxx API improperly.
+/// An exception thrown due to incorrect use of mongocxx interfaces.
 ///
-/// @see mongocxx::exception
+/// @see
+/// - @ref mongocxx::v_noabi::exception
 ///
-class MONGOCXX_API logic_error : public exception {
+class logic_error : public exception {
    public:
+    ~logic_error() override;
+
+    logic_error(logic_error&&) = default;
+    logic_error& operator=(logic_error&&) = default;
+    logic_error(logic_error const&) = default;
+    logic_error& operator=(logic_error const&) = default;
+
     using exception::exception;
 };
 
-}  // namespace v_noabi
-}  // namespace mongocxx
+} // namespace v_noabi
+} // namespace mongocxx
 
 #include <mongocxx/config/postlude.hpp>
+
+///
+/// @file
+/// Provides @ref mongocxx::v_noabi::logic_error.
+///
