@@ -24,7 +24,7 @@ namespace mongocxx {
 namespace v_noabi {
 
 ///
-/// Class representing an exception during a query operation.
+/// An exception thrown during a query operation.
 ///
 /// @see
 /// - @ref mongocxx::v_noabi::operation_exception
@@ -35,14 +35,14 @@ class query_exception : public operation_exception {
 
     query_exception(query_exception&&) = default;
     query_exception& operator=(query_exception&&) = default;
-    query_exception(const query_exception&) = default;
-    query_exception& operator=(const query_exception&) = default;
+    query_exception(query_exception const&) = default;
+    query_exception& operator=(query_exception const&) = default;
 
     using operation_exception::operation_exception;
 };
 
-}  // namespace v_noabi
-}  // namespace mongocxx
+} // namespace v_noabi
+} // namespace mongocxx
 
 #include <mongocxx/config/postlude.hpp>
 
