@@ -27,7 +27,7 @@ namespace mongocxx {
 namespace v_noabi {
 
 ///
-/// Class representing an index on a MongoDB server.
+/// Used by @ref mongocxx::v_noabi::index_view.
 ///
 class index_model {
    public:
@@ -35,8 +35,9 @@ class index_model {
     /// Initializes a new index_model over a mongocxx::v_noabi::collection.
     ///
     MONGOCXX_ABI_EXPORT_CDECL()
-    index_model(const bsoncxx::v_noabi::document::view_or_value& keys,
-                const bsoncxx::v_noabi::document::view_or_value& options = {});
+    index_model(
+        bsoncxx::v_noabi::document::view_or_value const& keys,
+        bsoncxx::v_noabi::document::view_or_value const& options = {});
 
     index_model() = delete;
 
@@ -53,12 +54,12 @@ class index_model {
     ///
     /// Copy constructs an index_model.
     ///
-    MONGOCXX_ABI_EXPORT_CDECL() index_model(const index_model&);
+    MONGOCXX_ABI_EXPORT_CDECL() index_model(index_model const&);
 
     ///
     /// Copy assigns an index_model.
     ///
-    index_model& operator=(const index_model&) = default;
+    index_model& operator=(index_model const&) = default;
 
     ///
     /// Destroys an index_model.
@@ -80,8 +81,8 @@ class index_model {
     bsoncxx::v_noabi::document::value _options;
 };
 
-}  // namespace v_noabi
-}  // namespace mongocxx
+} // namespace v_noabi
+} // namespace mongocxx
 
 #include <mongocxx/config/postlude.hpp>
 
