@@ -34,7 +34,10 @@ namespace mongocxx {
 namespace v_noabi {
 
 ///
-/// Class representing a MongoDB index view.
+/// A MongoDB index.
+///
+/// @note Not to be confused with a MongoDB Atlas Search Index (@ref
+/// mongocxx::v_noabi::search_index_view).
 ///
 class index_view {
    public:
@@ -43,8 +46,8 @@ class index_view {
 
     MONGOCXX_ABI_EXPORT_CDECL() ~index_view();
 
-    index_view(const index_view&) = delete;
-    MONGOCXX_ABI_EXPORT_CDECL(index_view&) operator=(const index_view&) = delete;
+    index_view(index_view const&) = delete;
+    MONGOCXX_ABI_EXPORT_CDECL(index_view&) operator=(index_view const&) = delete;
 
     ///
     /// Returns a cursor over all the indexes.
@@ -57,7 +60,7 @@ class index_view {
     /// @param session
     ///   The mongocxx::v_noabi::client_session with which to perform the list operation.
     ///
-    MONGOCXX_ABI_EXPORT_CDECL(cursor) list(const client_session& session);
+    MONGOCXX_ABI_EXPORT_CDECL(cursor) list(client_session const& session);
 
     ///
     /// Creates an index. A convenience method that calls create_many.
@@ -82,9 +85,10 @@ class index_view {
     /// - https://www.mongodb.com/docs/manual/reference/method/db.collection.createIndex/
     ///
     MONGOCXX_ABI_EXPORT_CDECL(bsoncxx::v_noabi::stdx::optional<std::string>)
-    create_one(const bsoncxx::v_noabi::document::view_or_value& keys,
-               const bsoncxx::v_noabi::document::view_or_value& index_options = {},
-               const options::index_view& options = options::index_view{});
+    create_one(
+        bsoncxx::v_noabi::document::view_or_value const& keys,
+        bsoncxx::v_noabi::document::view_or_value const& index_options = {},
+        options::index_view const& options = options::index_view{});
 
     ///
     /// Creates an index. A convenience method that calls create_many.
@@ -111,10 +115,11 @@ class index_view {
     /// - https://www.mongodb.com/docs/manual/reference/method/db.collection.createIndex/
     ///
     MONGOCXX_ABI_EXPORT_CDECL(bsoncxx::v_noabi::stdx::optional<std::string>)
-    create_one(const client_session& session,
-               const bsoncxx::v_noabi::document::view_or_value& keys,
-               const bsoncxx::v_noabi::document::view_or_value& index_options = {},
-               const options::index_view& options = options::index_view{});
+    create_one(
+        client_session const& session,
+        bsoncxx::v_noabi::document::view_or_value const& keys,
+        bsoncxx::v_noabi::document::view_or_value const& index_options = {},
+        options::index_view const& options = options::index_view{});
 
     ///
     /// Creates an index. A convenience method that calls create_many.
@@ -136,8 +141,7 @@ class index_view {
     /// - https://www.mongodb.com/docs/manual/reference/method/cursor.maxTimeMS/
     ///
     MONGOCXX_ABI_EXPORT_CDECL(bsoncxx::v_noabi::stdx::optional<std::string>)
-    create_one(const index_model& index,
-               const options::index_view& options = options::index_view{});
+    create_one(index_model const& index, options::index_view const& options = options::index_view{});
 
     ///
     /// Creates an index. A convenience method that calls create_many.
@@ -161,9 +165,10 @@ class index_view {
     /// - https://www.mongodb.com/docs/manual/reference/method/cursor.maxTimeMS/
     ///
     MONGOCXX_ABI_EXPORT_CDECL(bsoncxx::v_noabi::stdx::optional<std::string>)
-    create_one(const client_session& session,
-               const index_model& index,
-               const options::index_view& options = options::index_view{});
+    create_one(
+        client_session const& session,
+        index_model const& index,
+        options::index_view const& options = options::index_view{});
 
     ///
     /// Adds a container of indexes to the collection.
@@ -185,8 +190,7 @@ class index_view {
     /// - https://www.mongodb.com/docs/manual/reference/method/cursor.maxTimeMS/
     ///
     MONGOCXX_ABI_EXPORT_CDECL(bsoncxx::v_noabi::document::value)
-    create_many(const std::vector<index_model>& indexes,
-                const options::index_view& options = options::index_view{});
+    create_many(std::vector<index_model> const& indexes, options::index_view const& options = options::index_view{});
 
     ///
     /// Adds a container of indexes to the collection.
@@ -210,9 +214,10 @@ class index_view {
     /// - https://www.mongodb.com/docs/manual/reference/method/cursor.maxTimeMS/
     ///
     MONGOCXX_ABI_EXPORT_CDECL(bsoncxx::v_noabi::document::value)
-    create_many(const client_session& session,
-                const std::vector<index_model>& indexes,
-                const options::index_view& options = options::index_view{});
+    create_many(
+        client_session const& session,
+        std::vector<index_model> const& indexes,
+        options::index_view const& options = options::index_view{});
 
     ///
     /// Drops a single index by name.
@@ -232,8 +237,7 @@ class index_view {
     /// - https://www.mongodb.com/docs/manual/reference/method/cursor.maxTimeMS/
     ///
     MONGOCXX_ABI_EXPORT_CDECL(void)
-    drop_one(bsoncxx::v_noabi::stdx::string_view name,
-             const options::index_view& options = options::index_view{});
+    drop_one(bsoncxx::v_noabi::stdx::string_view name, options::index_view const& options = options::index_view{});
 
     ///
     /// Drops a single index by name.
@@ -255,9 +259,10 @@ class index_view {
     /// - https://www.mongodb.com/docs/manual/reference/method/cursor.maxTimeMS/
     ///
     MONGOCXX_ABI_EXPORT_CDECL(void)
-    drop_one(const client_session& session,
-             bsoncxx::v_noabi::stdx::string_view name,
-             const options::index_view& options = options::index_view{});
+    drop_one(
+        client_session const& session,
+        bsoncxx::v_noabi::stdx::string_view name,
+        options::index_view const& options = options::index_view{});
 
     ///
     /// Attempts to drop a single index from the collection given the keys and options.
@@ -284,9 +289,10 @@ class index_view {
     /// - https://www.mongodb.com/docs/manual/reference/method/cursor.maxTimeMS/
     ///
     MONGOCXX_ABI_EXPORT_CDECL(void)
-    drop_one(const bsoncxx::v_noabi::document::view_or_value& keys,
-             const bsoncxx::v_noabi::document::view_or_value& index_options = {},
-             const options::index_view& options = options::index_view{});
+    drop_one(
+        bsoncxx::v_noabi::document::view_or_value const& keys,
+        bsoncxx::v_noabi::document::view_or_value const& index_options = {},
+        options::index_view const& options = options::index_view{});
 
     ///
     /// Attempts to drop a single index from the collection given the keys and options.
@@ -315,10 +321,11 @@ class index_view {
     /// - https://www.mongodb.com/docs/manual/reference/method/cursor.maxTimeMS/
     ///
     MONGOCXX_ABI_EXPORT_CDECL(void)
-    drop_one(const client_session& session,
-             const bsoncxx::v_noabi::document::view_or_value& keys,
-             const bsoncxx::v_noabi::document::view_or_value& index_options = {},
-             const options::index_view& options = options::index_view{});
+    drop_one(
+        client_session const& session,
+        bsoncxx::v_noabi::document::view_or_value const& keys,
+        bsoncxx::v_noabi::document::view_or_value const& index_options = {},
+        options::index_view const& options = options::index_view{});
 
     ///
     /// Attempts to drop a single index from the collection given an index model.
@@ -341,7 +348,7 @@ class index_view {
     /// - https://www.mongodb.com/docs/manual/reference/method/cursor.maxTimeMS/
     ///
     MONGOCXX_ABI_EXPORT_CDECL(void)
-    drop_one(const index_model& index, const options::index_view& options = options::index_view{});
+    drop_one(index_model const& index, options::index_view const& options = options::index_view{});
 
     ///
     /// Attempts to drop a single index from the collection given an index model.
@@ -366,9 +373,10 @@ class index_view {
     /// - https://www.mongodb.com/docs/manual/reference/method/cursor.maxTimeMS/
     ///
     MONGOCXX_ABI_EXPORT_CDECL(void)
-    drop_one(const client_session& session,
-             const index_model& index,
-             const options::index_view& options = options::index_view{});
+    drop_one(
+        client_session const& session,
+        index_model const& index,
+        options::index_view const& options = options::index_view{});
 
     ///
     /// Drops all indexes in the collection.
@@ -384,7 +392,7 @@ class index_view {
     /// - https://www.mongodb.com/docs/manual/reference/method/cursor.maxTimeMS/
     ///
     MONGOCXX_ABI_EXPORT_CDECL(void)
-    drop_all(const options::index_view& options = options::index_view{});
+    drop_all(options::index_view const& options = options::index_view{});
 
     ///
     /// Drops all indexes in the collection.
@@ -402,8 +410,7 @@ class index_view {
     /// - https://www.mongodb.com/docs/manual/reference/method/cursor.maxTimeMS/
     ///
     MONGOCXX_ABI_EXPORT_CDECL(void)
-    drop_all(const client_session& session,
-             const options::index_view& options = options::index_view{});
+    drop_all(client_session const& session, options::index_view const& options = options::index_view{});
 
    private:
     friend ::mongocxx::v_noabi::collection;
@@ -417,8 +424,8 @@ class index_view {
     std::unique_ptr<impl> _impl;
 };
 
-}  // namespace v_noabi
-}  // namespace mongocxx
+} // namespace v_noabi
+} // namespace mongocxx
 
 #include <mongocxx/config/postlude.hpp>
 
