@@ -1,4 +1,4 @@
-// Copyright 2014 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -14,18 +14,20 @@
 
 #pragma once
 
+#include <mongocxx/model/insert_one-fwd.hpp>
+
 #include <bsoncxx/document/view_or_value.hpp>
 
 #include <mongocxx/config/prelude.hpp>
 
 namespace mongocxx {
-inline namespace v_noabi {
+namespace v_noabi {
 namespace model {
 
 ///
-/// Class representing a MongoDB insert operation that creates a single document.
+/// A MongoDB insert operation that creates a single document.
 ///
-class MONGOCXX_API insert_one {
+class insert_one {
    public:
     ///
     /// Constructs an insert operation that will create a single document.
@@ -33,21 +35,26 @@ class MONGOCXX_API insert_one {
     /// @param document
     ///   The document to insert.
     ///
-    insert_one(bsoncxx::document::view_or_value document);
+    MONGOCXX_ABI_EXPORT_CDECL() insert_one(bsoncxx::v_noabi::document::view_or_value document);
 
     ///
     /// Gets the document to be inserted.
     ///
     /// @return The document to be inserted.
     ///
-    const bsoncxx::document::view_or_value& document() const;
+    MONGOCXX_ABI_EXPORT_CDECL(bsoncxx::v_noabi::document::view_or_value const&) document() const;
 
    private:
-    bsoncxx::document::view_or_value _document;
+    bsoncxx::v_noabi::document::view_or_value _document;
 };
 
-}  // namespace model
-}  // namespace v_noabi
-}  // namespace mongocxx
+} // namespace model
+} // namespace v_noabi
+} // namespace mongocxx
 
 #include <mongocxx/config/postlude.hpp>
+
+///
+/// @file
+/// Provides @ref mongocxx::v_noabi::model::insert_one.
+///
