@@ -1,4 +1,4 @@
-// Copyright 2014 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -21,20 +21,27 @@
 #include <mongocxx/config/prelude.hpp>
 
 namespace mongocxx {
-inline namespace v_noabi {
+namespace v_noabi {
 namespace options {
 
 ///
-/// Class representing the optional arguments to a MongoDB driver client (SSL)
+/// Equivalent to @ref mongocxx::v_noabi::options::tls.
 ///
-/// This class has been renamed to options::tls.
+/// To be removed in an upcoming major release.
 ///
-/// @deprecated use the tls options class instead.
+/// @deprecated Use @ref mongocxx::v_noabi::options::tls instead.
 ///
 MONGOCXX_DEPRECATED typedef tls ssl;
 
-}  // namespace options
-}  // namespace v_noabi
-}  // namespace mongocxx
+} // namespace options
+} // namespace v_noabi
+} // namespace mongocxx
 
 #include <mongocxx/config/postlude.hpp>
+
+///
+/// @file
+/// Provides @ref mongocxx::v_noabi::options::ssl.
+///
+/// @deprecated Use @ref mongocxx/v_noabi/mongocxx/options/tls.hpp instead.
+///
