@@ -1,4 +1,4 @@
-// Copyright 2019 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -20,7 +20,6 @@
 
 #include <bsoncxx/stdx/optional.hpp>
 #include <bsoncxx/string/view_or_value.hpp>
-#include <mongocxx/stdx.hpp>
 
 #include <mongocxx/config/prelude.hpp>
 
@@ -29,7 +28,7 @@ namespace v_noabi {
 namespace options {
 
 ///
-/// Class representing the optional arguments to a MongoDB driver client (TLS)
+/// Used by @ref mongocxx::v_noabi::options::client::tls_opts.
 ///
 class tls {
    public:
@@ -44,14 +43,15 @@ class tls {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    tls& pem_file(bsoncxx::v_noabi::string::view_or_value pem_file);
+    MONGOCXX_ABI_EXPORT_CDECL(tls&) pem_file(bsoncxx::v_noabi::string::view_or_value pem_file);
 
     ///
     /// Retrieves the current path to the .pem file.
     ///
     /// @return The path to the .pem file.
     ///
-    const stdx::optional<bsoncxx::v_noabi::string::view_or_value>& pem_file() const;
+    MONGOCXX_ABI_EXPORT_CDECL(bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::string::view_or_value> const&)
+    pem_file() const;
 
     ///
     /// The pass phrase used to decrypt an encrypted PEM file.
@@ -63,14 +63,16 @@ class tls {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    tls& pem_password(bsoncxx::v_noabi::string::view_or_value pem_password);
+    MONGOCXX_ABI_EXPORT_CDECL(tls&)
+    pem_password(bsoncxx::v_noabi::string::view_or_value pem_password);
 
     ///
     /// Retrieves the current decryption pass phrase.
     ///
     /// @return The pass phrase.
     ///
-    const stdx::optional<bsoncxx::v_noabi::string::view_or_value>& pem_password() const;
+    MONGOCXX_ABI_EXPORT_CDECL(bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::string::view_or_value> const&)
+    pem_password() const;
 
     ///
     /// The path to the .pem file that contains the root certificate chain from the Certificate
@@ -83,14 +85,15 @@ class tls {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    tls& ca_file(bsoncxx::v_noabi::string::view_or_value ca_file);
+    MONGOCXX_ABI_EXPORT_CDECL(tls&) ca_file(bsoncxx::v_noabi::string::view_or_value ca_file);
 
     ///
     /// Retrieves the current path to the CA file.
     ///
     /// @return The path to the CA file.
     ///
-    const stdx::optional<bsoncxx::v_noabi::string::view_or_value>& ca_file() const;
+    MONGOCXX_ABI_EXPORT_CDECL(bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::string::view_or_value> const&)
+    ca_file() const;
 
     ///
     /// The path to the Certificate Authority directory.
@@ -102,14 +105,15 @@ class tls {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    tls& ca_dir(bsoncxx::v_noabi::string::view_or_value ca_dir);
+    MONGOCXX_ABI_EXPORT_CDECL(tls&) ca_dir(bsoncxx::v_noabi::string::view_or_value ca_dir);
 
     ///
     /// Retrieves the current path to the CA directory.
     ///
     /// @return The path to the CA directory.
     ///
-    const stdx::optional<bsoncxx::v_noabi::string::view_or_value>& ca_dir() const;
+    MONGOCXX_ABI_EXPORT_CDECL(bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::string::view_or_value> const&)
+    ca_dir() const;
 
     ///
     /// The path to the .pem file that contains revoked certificates.
@@ -121,14 +125,15 @@ class tls {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    tls& crl_file(bsoncxx::v_noabi::string::view_or_value crl_file);
+    MONGOCXX_ABI_EXPORT_CDECL(tls&) crl_file(bsoncxx::v_noabi::string::view_or_value crl_file);
 
     ///
     /// Retrieves the current path to the .pem file that contains revoked certificates.
     ///
     /// @return The path to the revoked certificates file.
     ///
-    const stdx::optional<bsoncxx::v_noabi::string::view_or_value>& crl_file() const;
+    MONGOCXX_ABI_EXPORT_CDECL(bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::string::view_or_value> const&)
+    crl_file() const;
 
     ///
     /// If true, the driver will not verify the server's CA file.
@@ -140,26 +145,32 @@ class tls {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    tls& allow_invalid_certificates(bool allow_invalid_certificates);
+    MONGOCXX_ABI_EXPORT_CDECL(tls&) allow_invalid_certificates(bool allow_invalid_certificates);
 
     ///
     /// Retrieves whether or not the driver will check the server's CA file.
     ///
     /// @return Whether or not the driver will check the server's CA file.
     ///
-    const stdx::optional<bool>& allow_invalid_certificates() const;
+    MONGOCXX_ABI_EXPORT_CDECL(bsoncxx::v_noabi::stdx::optional<bool> const&)
+    allow_invalid_certificates() const;
 
    private:
-    stdx::optional<bsoncxx::v_noabi::string::view_or_value> _pem_file;
-    stdx::optional<bsoncxx::v_noabi::string::view_or_value> _pem_password;
-    stdx::optional<bsoncxx::v_noabi::string::view_or_value> _ca_file;
-    stdx::optional<bsoncxx::v_noabi::string::view_or_value> _ca_dir;
-    stdx::optional<bsoncxx::v_noabi::string::view_or_value> _crl_file;
-    stdx::optional<bool> _allow_invalid_certificates;
+    bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::string::view_or_value> _pem_file;
+    bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::string::view_or_value> _pem_password;
+    bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::string::view_or_value> _ca_file;
+    bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::string::view_or_value> _ca_dir;
+    bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::string::view_or_value> _crl_file;
+    bsoncxx::v_noabi::stdx::optional<bool> _allow_invalid_certificates;
 };
 
-}  // namespace options
-}  // namespace v_noabi
-}  // namespace mongocxx
+} // namespace options
+} // namespace v_noabi
+} // namespace mongocxx
 
 #include <mongocxx/config/postlude.hpp>
+
+///
+/// @file
+/// Provides @ref mongocxx::v_noabi::options::tls.
+///
