@@ -34,7 +34,7 @@ namespace mongocxx {
 namespace v_noabi {
 
 ///
-/// Class representing a MongoDB aggregation pipeline.
+/// A MongoDB aggregation pipeline.
 ///
 class pipeline {
    public:
@@ -61,8 +61,8 @@ class pipeline {
     ///
     MONGOCXX_ABI_EXPORT_CDECL() ~pipeline();
 
-    pipeline(const pipeline&) = delete;
-    MONGOCXX_ABI_EXPORT_CDECL(pipeline&) operator=(const pipeline&) = delete;
+    pipeline(pipeline const&) = delete;
+    MONGOCXX_ABI_EXPORT_CDECL(pipeline&) operator=(pipeline const&) = delete;
 
     ///
     /// Adds new fields to documents.
@@ -134,8 +134,7 @@ class pipeline {
     ///   method chaining.
     ///
     MONGOCXX_ABI_EXPORT_CDECL(pipeline&)
-    coll_stats(bsoncxx::v_noabi::document::view_or_value coll_stats_args =
-                   bsoncxx::v_noabi::document::view{});
+    coll_stats(bsoncxx::v_noabi::document::view_or_value coll_stats_args = bsoncxx::v_noabi::document::view{});
 
     ///
     /// Returns a document containing a count of the number of documents input to the stage.
@@ -605,8 +604,8 @@ class pipeline {
     std::unique_ptr<impl> _impl;
 };
 
-}  // namespace v_noabi
-}  // namespace mongocxx
+} // namespace v_noabi
+} // namespace mongocxx
 
 #include <mongocxx/config/postlude.hpp>
 
