@@ -35,21 +35,12 @@ namespace mongocxx {
 namespace v_noabi {
 
 ///
-/// A class to represent the read concern. Read concern can be set at the client, database, or
-/// collection level. The read concern can also be provided via connection string, and will be
-/// parsed and set on the client constructed for the URI.
+/// Controls the consistency and isolation properties of data read from replica sets and sharded
+/// clusters.
 ///
-/// For the WiredTiger storage engine, MongoDB 3.2 introduced the readConcern option for replica
-/// sets and replica set shards. The readConcern option allows clients to choose a level of
-/// isolation for their reads. You can specify a readConcern of "majority" to read data that has
-/// been written to a majority of nodes and thus cannot be rolled back. By default, MongoDB uses a
-/// readConcern of "local" which does not guarantee that the read data would not be rolled back.
-///
-/// MongoDB 3.4 introduces a read concern level of "linearizable" to read data that has been written
-/// to a majority of nodes (i.e. cannot be rolled back) @b and is not stale. Linearizable read
-/// concern is available for all MongoDB supported storage engines and applies to read operations on
-/// a single document. Note that writes must be made with majority write concern in order for reads
-/// to be linearizable.
+/// Read concern can be set at the client, database, or collection level. The read concern can also
+/// be provided via connection string, and will be parsed and set on the client constructed for the
+/// URI.
 ///
 /// @see
 /// - [Read Concern (MongoDB Manual)](https://www.mongodb.com/docs/manual/reference/read-concern/)
@@ -64,13 +55,13 @@ class read_concern {
     /// - [Default MongoDB Read Concerns/Write Concerns (MongoDB Manual)](https://www.mongodb.com/docs/manual/reference/mongodb-defaults/#read-concern)
     ///
     enum class level {
-        k_local,           ///< Represent read concern level "local".
-        k_majority,        ///< Represent read concern level "majority".
-        k_linearizable,    ///< Represent read concern level "linearizable".
-        k_server_default,  ///< Represent the server's default read concern level.
-        k_unknown,         ///< Represent an unknown read concern level.
-        k_available,       ///< Represent read concern level "available".
-        k_snapshot         ///< Represent read concern level "snapshot".
+        k_local,          ///< Represent read concern level "local".
+        k_majority,       ///< Represent read concern level "majority".
+        k_linearizable,   ///< Represent read concern level "linearizable".
+        k_server_default, ///< Represent the server's default read concern level.
+        k_unknown,        ///< Represent an unknown read concern level.
+        k_available,      ///< Represent read concern level "available".
+        k_snapshot        ///< Represent read concern level "snapshot".
     };
 
     ///
@@ -85,12 +76,12 @@ class read_concern {
     ///
     /// Copy constructs a read_concern.
     ///
-    MONGOCXX_ABI_EXPORT_CDECL() read_concern(const read_concern&);
+    MONGOCXX_ABI_EXPORT_CDECL() read_concern(read_concern const&);
 
     ///
     /// Copy assigns a read_concern.
     ///
-    MONGOCXX_ABI_EXPORT_CDECL(read_concern&) operator=(const read_concern&);
+    MONGOCXX_ABI_EXPORT_CDECL(read_concern&) operator=(read_concern const&);
 
     ///
     /// Move constructs a read_concern.
@@ -165,8 +156,8 @@ class read_concern {
     /// Compares two read_concern objects for (in)-equality.
     ///
     /// @{
-    friend MONGOCXX_ABI_EXPORT_CDECL(bool) operator==(const read_concern&, const read_concern&);
-    friend MONGOCXX_ABI_EXPORT_CDECL(bool) operator!=(const read_concern&, const read_concern&);
+    friend MONGOCXX_ABI_EXPORT_CDECL(bool) operator==(read_concern const&, read_concern const&);
+    friend MONGOCXX_ABI_EXPORT_CDECL(bool) operator!=(read_concern const&, read_concern const&);
     /// @}
     ///
 
@@ -184,8 +175,8 @@ class read_concern {
     std::unique_ptr<impl> _impl;
 };
 
-}  // namespace v_noabi
-}  // namespace mongocxx
+} // namespace v_noabi
+} // namespace mongocxx
 
 #include <mongocxx/config/postlude.hpp>
 
