@@ -31,7 +31,7 @@ namespace v_noabi {
 namespace result {
 
 ///
-/// Class representing the result of a MongoDB bulk write operation.
+/// The result of a MongoDB bulk write operation.
 ///
 class bulk_write {
    public:
@@ -85,8 +85,8 @@ class bulk_write {
     ///
     MONGOCXX_ABI_EXPORT_CDECL(id_map) upserted_ids() const;
 
-    friend MONGOCXX_ABI_EXPORT_CDECL(bool) operator==(const bulk_write&, const bulk_write&);
-    friend MONGOCXX_ABI_EXPORT_CDECL(bool) operator!=(const bulk_write&, const bulk_write&);
+    friend MONGOCXX_ABI_EXPORT_CDECL(bool) operator==(bulk_write const&, bulk_write const&);
+    friend MONGOCXX_ABI_EXPORT_CDECL(bool) operator!=(bulk_write const&, bulk_write const&);
 
    private:
     bsoncxx::v_noabi::document::view view() const;
@@ -94,9 +94,9 @@ class bulk_write {
     bsoncxx::v_noabi::document::value _response;
 };
 
-}  // namespace result
-}  // namespace v_noabi
-}  // namespace mongocxx
+} // namespace result
+} // namespace v_noabi
+} // namespace mongocxx
 
 #include <mongocxx/config/postlude.hpp>
 
