@@ -23,10 +23,10 @@ namespace gridfs {
 
 class upload;
 
-}  // namespace gridfs
-}  // namespace result
-}  // namespace v_noabi
-}  // namespace mongocxx
+} // namespace gridfs
+} // namespace result
+} // namespace v_noabi
+} // namespace mongocxx
 
 namespace mongocxx {
 namespace result {
@@ -34,9 +34,9 @@ namespace gridfs {
 
 using ::mongocxx::v_noabi::result::gridfs::upload;
 
-}  // namespace gridfs
-}  // namespace result
-}  // namespace mongocxx
+} // namespace gridfs
+} // namespace result
+} // namespace mongocxx
 
 #include <mongocxx/config/postlude.hpp>
 
@@ -44,18 +44,3 @@ using ::mongocxx::v_noabi::result::gridfs::upload;
 /// @file
 /// Declares @ref mongocxx::v_noabi::result::gridfs::upload.
 ///
-
-#if defined(MONGOCXX_PRIVATE_DOXYGEN_PREPROCESSOR)
-
-namespace mongocxx {
-namespace result {
-namespace gridfs {
-
-/// @ref mongocxx::v_noabi::result::gridfs::upload
-class upload {};
-
-}  // namespace gridfs
-}  // namespace result
-}  // namespace mongocxx
-
-#endif  // defined(MONGOCXX_PRIVATE_DOXYGEN_PREPROCESSOR)
