@@ -1,4 +1,4 @@
-// Copyright 2017 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -26,17 +26,20 @@ namespace v_noabi {
 namespace result {
 namespace gridfs {
 
-/// Class representing the result of a GridFS upload operation.
+/// The result of a GridFS upload operation.
 class upload {
    public:
-    upload(bsoncxx::v_noabi::types::bson_value::view id);
+    MONGOCXX_ABI_EXPORT_CDECL() upload(bsoncxx::v_noabi::types::bson_value::view id);
 
     ///
     /// Gets the id of the uploaded GridFS file.
     ///
     /// @return The id of the uploaded file.
     ///
-    const bsoncxx::v_noabi::types::bson_value::view& id() const;
+    MONGOCXX_ABI_EXPORT_CDECL(bsoncxx::v_noabi::types::bson_value::view const&) id() const;
+
+    friend MONGOCXX_ABI_EXPORT_CDECL(bool) operator==(upload const&, upload const&);
+    friend MONGOCXX_ABI_EXPORT_CDECL(bool) operator!=(upload const&, upload const&);
 
    private:
     // Array with a single element, containing the value of the _id field for the inserted files
@@ -45,14 +48,16 @@ class upload {
 
     // Points into _id_owned.
     bsoncxx::v_noabi::types::bson_value::view _id;
-
-    friend MONGOCXX_API bool MONGOCXX_CALL operator==(const upload&, const upload&);
-    friend MONGOCXX_API bool MONGOCXX_CALL operator!=(const upload&, const upload&);
 };
 
-}  // namespace gridfs
-}  // namespace result
-}  // namespace v_noabi
-}  // namespace mongocxx
+} // namespace gridfs
+} // namespace result
+} // namespace v_noabi
+} // namespace mongocxx
 
 #include <mongocxx/config/postlude.hpp>
+
+///
+/// @file
+/// Provides @ref mongocxx::v_noabi::result::gridfs::upload.
+///
