@@ -29,7 +29,9 @@ namespace mongocxx {
 namespace v_noabi {
 namespace result {
 
-/// Class representing the result of a MongoDB replace_one operation.
+///
+/// The result of a MongoDB replaceOne operation.
+///
 class replace_one {
    public:
     // This constructor is public for testing purposes only
@@ -40,7 +42,7 @@ class replace_one {
     ///
     /// @return The raw bulk write result.
     ///
-    MONGOCXX_ABI_EXPORT_CDECL(const result::bulk_write&) result() const;
+    MONGOCXX_ABI_EXPORT_CDECL(result::bulk_write const&) result() const;
 
     ///
     /// Gets the number of documents that were matched during this operation.
@@ -64,16 +66,16 @@ class replace_one {
     MONGOCXX_ABI_EXPORT_CDECL(bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::element>)
     upserted_id() const;
 
-    friend MONGOCXX_ABI_EXPORT_CDECL(bool) operator==(const replace_one&, const replace_one&);
-    friend MONGOCXX_ABI_EXPORT_CDECL(bool) operator!=(const replace_one&, const replace_one&);
+    friend MONGOCXX_ABI_EXPORT_CDECL(bool) operator==(replace_one const&, replace_one const&);
+    friend MONGOCXX_ABI_EXPORT_CDECL(bool) operator!=(replace_one const&, replace_one const&);
 
    private:
     result::bulk_write _result;
 };
 
-}  // namespace result
-}  // namespace v_noabi
-}  // namespace mongocxx
+} // namespace result
+} // namespace v_noabi
+} // namespace mongocxx
 
 #include <mongocxx/config/postlude.hpp>
 
