@@ -29,7 +29,9 @@ namespace mongocxx {
 namespace v_noabi {
 namespace result {
 
-/// Class representing the result of a MongoDB update operation.
+///
+/// The result of a MongoDB update operation.
+///
 class update {
    public:
     // This constructor is public for testing purposes only
@@ -40,7 +42,7 @@ class update {
     ///
     /// @return The raw bulk write result.
     ///
-    MONGOCXX_ABI_EXPORT_CDECL(const result::bulk_write&) result() const;
+    MONGOCXX_ABI_EXPORT_CDECL(result::bulk_write const&) result() const;
 
     ///
     /// Gets the number of documents that were matched during this operation.
@@ -69,16 +71,16 @@ class update {
     MONGOCXX_ABI_EXPORT_CDECL(bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::element>)
     upserted_id() const;
 
-    friend MONGOCXX_ABI_EXPORT_CDECL(bool) operator==(const update&, const update&);
-    friend MONGOCXX_ABI_EXPORT_CDECL(bool) operator!=(const update&, const update&);
+    friend MONGOCXX_ABI_EXPORT_CDECL(bool) operator==(update const&, update const&);
+    friend MONGOCXX_ABI_EXPORT_CDECL(bool) operator!=(update const&, update const&);
 
    private:
     result::bulk_write _result;
 };
 
-}  // namespace result
-}  // namespace v_noabi
-}  // namespace mongocxx
+} // namespace result
+} // namespace v_noabi
+} // namespace mongocxx
 
 #include <mongocxx/config/postlude.hpp>
 
