@@ -19,15 +19,17 @@ namespace mongocxx {
 namespace v_noabi {
 
 ///
-/// Class representing a MongoDB search index view.
+/// A MongoDB Atlas Search Index.
+///
+/// @note Not to be confused with a MongoDB index (@ref mongocxx::v_noabi::index_view).
 ///
 class search_index_view {
    public:
     MONGOCXX_ABI_EXPORT_CDECL() search_index_view(search_index_view&&) noexcept;
     MONGOCXX_ABI_EXPORT_CDECL(search_index_view&) operator=(search_index_view&&) noexcept;
 
-    MONGOCXX_ABI_EXPORT_CDECL() search_index_view(const search_index_view&);
-    MONGOCXX_ABI_EXPORT_CDECL(search_index_view&) operator=(const search_index_view&);
+    MONGOCXX_ABI_EXPORT_CDECL() search_index_view(search_index_view const&);
+    MONGOCXX_ABI_EXPORT_CDECL(search_index_view&) operator=(search_index_view const&);
 
     MONGOCXX_ABI_EXPORT_CDECL() ~search_index_view();
 
@@ -40,7 +42,7 @@ class search_index_view {
     /// @return A cursor to the list of the search indexes returned.
     ///
     MONGOCXX_ABI_EXPORT_CDECL(cursor)
-    list(const options::aggregate& options = options::aggregate());
+    list(options::aggregate const& options = options::aggregate());
 
     ///
     /// Returns a cursor over all the search indexes.
@@ -53,7 +55,7 @@ class search_index_view {
     /// @return A cursor to the list of the search indexes returned.
     ///
     MONGOCXX_ABI_EXPORT_CDECL(cursor)
-    list(const client_session& session, const options::aggregate& options = options::aggregate());
+    list(client_session const& session, options::aggregate const& options = options::aggregate());
 
     ///
     /// Returns a cursor over all the search indexes.
@@ -66,8 +68,7 @@ class search_index_view {
     /// @return A cursor to the list of the search indexes returned.
     ///
     MONGOCXX_ABI_EXPORT_CDECL(cursor)
-    list(bsoncxx::v_noabi::string::view_or_value name,
-         const options::aggregate& options = options::aggregate());
+    list(bsoncxx::v_noabi::string::view_or_value name, options::aggregate const& options = options::aggregate());
 
     ///
     /// Returns a cursor over all the search indexes.
@@ -82,9 +83,10 @@ class search_index_view {
     /// @return A cursor to the list of the search indexes returned.
     ///
     MONGOCXX_ABI_EXPORT_CDECL(cursor)
-    list(const client_session& session,
-         bsoncxx::v_noabi::string::view_or_value name,
-         const options::aggregate& options = options::aggregate());
+    list(
+        client_session const& session,
+        bsoncxx::v_noabi::string::view_or_value name,
+        options::aggregate const& options = options::aggregate());
 
     ///
     /// This is a convenience method for creating a single search index with a default name.
@@ -108,7 +110,7 @@ class search_index_view {
     /// @return The name of the created search index.
     ///
     MONGOCXX_ABI_EXPORT_CDECL(std::string)
-    create_one(const client_session& session, bsoncxx::v_noabi::document::view_or_value definition);
+    create_one(client_session const& session, bsoncxx::v_noabi::document::view_or_value definition);
 
     ///
     /// This is a convenience method for creating a single search index.
@@ -121,8 +123,7 @@ class search_index_view {
     /// @return The name of the created search index.
     ///
     MONGOCXX_ABI_EXPORT_CDECL(std::string)
-    create_one(bsoncxx::v_noabi::string::view_or_value name,
-               bsoncxx::v_noabi::document::view_or_value definition);
+    create_one(bsoncxx::v_noabi::string::view_or_value name, bsoncxx::v_noabi::document::view_or_value definition);
 
     ///
     /// This is a convenience method for creating a single search index.
@@ -137,9 +138,10 @@ class search_index_view {
     /// @return The name of the created search index.
     ///
     MONGOCXX_ABI_EXPORT_CDECL(std::string)
-    create_one(const client_session& session,
-               bsoncxx::v_noabi::string::view_or_value name,
-               bsoncxx::v_noabi::document::view_or_value definition);
+    create_one(
+        client_session const& session,
+        bsoncxx::v_noabi::string::view_or_value name,
+        bsoncxx::v_noabi::document::view_or_value definition);
 
     ///
     /// This is a convenience method for creating a single search index.
@@ -149,7 +151,7 @@ class search_index_view {
     ///
     /// @return The name of the created index.
     ///
-    MONGOCXX_ABI_EXPORT_CDECL(std::string) create_one(const search_index_model& model);
+    MONGOCXX_ABI_EXPORT_CDECL(std::string) create_one(search_index_model const& model);
 
     ///
     /// This is a convenience method for creating a single search index.
@@ -162,7 +164,7 @@ class search_index_view {
     /// @return The name of the created index.
     ///
     MONGOCXX_ABI_EXPORT_CDECL(std::string)
-    create_one(const client_session& session, const search_index_model& model);
+    create_one(client_session const& session, search_index_model const& model);
 
     ///
     /// Creates multiple search indexes in the collection.
@@ -173,7 +175,7 @@ class search_index_view {
     /// @return The names of the created indexes.
     ///
     MONGOCXX_ABI_EXPORT_CDECL(std::vector<std::string>)
-    create_many(const std::vector<search_index_model>& models);
+    create_many(std::vector<search_index_model> const& models);
 
     ///
     /// Creates multiple search indexes in the collection.
@@ -186,7 +188,7 @@ class search_index_view {
     /// @return The names of the created indexes.
     ///
     MONGOCXX_ABI_EXPORT_CDECL(std::vector<std::string>)
-    create_many(const client_session& session, const std::vector<search_index_model>& models);
+    create_many(client_session const& session, std::vector<search_index_model> const& models);
 
     ///
     /// Drops a single search index from the collection by the index name.
@@ -205,7 +207,7 @@ class search_index_view {
     ///   The name of the search index to drop.
     ///
     MONGOCXX_ABI_EXPORT_CDECL(void)
-    drop_one(const client_session& session, bsoncxx::v_noabi::string::view_or_value name);
+    drop_one(client_session const& session, bsoncxx::v_noabi::string::view_or_value name);
 
     ///
     /// Updates a single search index from the collection by the search index name.
@@ -216,8 +218,7 @@ class search_index_view {
     ///   The definition to update the search index to.
     ///
     MONGOCXX_ABI_EXPORT_CDECL(void)
-    update_one(bsoncxx::v_noabi::string::view_or_value name,
-               bsoncxx::v_noabi::document::view_or_value definition);
+    update_one(bsoncxx::v_noabi::string::view_or_value name, bsoncxx::v_noabi::document::view_or_value definition);
 
     ///
     /// Updates a single search index from the collection by the search index name.
@@ -230,9 +231,10 @@ class search_index_view {
     ///   The definition to update the search index to.
     ///
     MONGOCXX_ABI_EXPORT_CDECL(void)
-    update_one(const client_session& session,
-               bsoncxx::v_noabi::string::view_or_value name,
-               bsoncxx::v_noabi::document::view_or_value definition);
+    update_one(
+        client_session const& session,
+        bsoncxx::v_noabi::string::view_or_value name,
+        bsoncxx::v_noabi::document::view_or_value definition);
 
    private:
     friend ::mongocxx::v_noabi::collection;
@@ -243,7 +245,7 @@ class search_index_view {
 
     std::vector<std::string> _create_many_helper(bsoncxx::v_noabi::array::view created_indexes);
 
-    const impl& _get_impl() const;
+    impl const& _get_impl() const;
 
     impl& _get_impl();
 
@@ -251,8 +253,8 @@ class search_index_view {
     std::unique_ptr<impl> _impl;
 };
 
-}  // namespace v_noabi
-}  // namespace mongocxx
+} // namespace v_noabi
+} // namespace mongocxx
 
 #include <mongocxx/config/postlude.hpp>
 
