@@ -1,4 +1,4 @@
-// Copyright 2018-present MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -12,51 +12,50 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-#include <bsoncxx/private/helpers.hh>
-#include <bsoncxx/stdx/make_unique.hpp>
 #include <mongocxx/events/command_succeeded_event.hpp>
-#include <mongocxx/private/libmongoc.hh>
 
-#include <mongocxx/config/private/prelude.hh>
+#include <bsoncxx/private/helpers.hh>
+#include <bsoncxx/private/make_unique.hh>
+
+#include <mongocxx/private/mongoc.hh>
 
 namespace mongocxx {
 namespace v_noabi {
 namespace events {
 
-command_succeeded_event::command_succeeded_event(const void* event) : _succeeded_event(event) {}
+command_succeeded_event::command_succeeded_event(void const* event) : _succeeded_event(event) {}
 
 command_succeeded_event::~command_succeeded_event() = default;
 
 bsoncxx::v_noabi::document::view command_succeeded_event::reply() const {
-    auto reply = libmongoc::apm_command_succeeded_get_reply(
-        static_cast<const mongoc_apm_command_succeeded_t*>(_succeeded_event));
+    bson_t const* const reply = libmongoc::apm_command_succeeded_get_reply(
+        static_cast<mongoc_apm_command_succeeded_t const*>(_succeeded_event));
     return {bson_get_data(reply), reply->len};
 }
 
 bsoncxx::v_noabi::stdx::string_view command_succeeded_event::command_name() const {
     return libmongoc::apm_command_succeeded_get_command_name(
-        static_cast<const mongoc_apm_command_succeeded_t*>(_succeeded_event));
+        static_cast<mongoc_apm_command_succeeded_t const*>(_succeeded_event));
 }
 
 std::int64_t command_succeeded_event::duration() const {
     return libmongoc::apm_command_succeeded_get_duration(
-        static_cast<const mongoc_apm_command_succeeded_t*>(_succeeded_event));
+        static_cast<mongoc_apm_command_succeeded_t const*>(_succeeded_event));
 }
 
 std::int64_t command_succeeded_event::request_id() const {
     return libmongoc::apm_command_succeeded_get_request_id(
-        static_cast<const mongoc_apm_command_succeeded_t*>(_succeeded_event));
+        static_cast<mongoc_apm_command_succeeded_t const*>(_succeeded_event));
 }
 
 std::int64_t command_succeeded_event::operation_id() const {
     return libmongoc::apm_command_succeeded_get_operation_id(
-        static_cast<const mongoc_apm_command_succeeded_t*>(_succeeded_event));
+        static_cast<mongoc_apm_command_succeeded_t const*>(_succeeded_event));
 }
 
-bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::oid> command_succeeded_event::service_id()
-    const {
-    const bson_oid_t* bson_oid = libmongoc::apm_command_succeeded_get_service_id(
-        static_cast<const mongoc_apm_command_succeeded_t*>(_succeeded_event));
+bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::oid> command_succeeded_event::service_id() const {
+    bson_oid_t const* bson_oid = libmongoc::apm_command_succeeded_get_service_id(
+        static_cast<mongoc_apm_command_succeeded_t const*>(_succeeded_event));
 
     if (nullptr == bson_oid)
         return {bsoncxx::v_noabi::stdx::nullopt};
@@ -66,16 +65,16 @@ bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::oid> command_succeeded_event:
 
 bsoncxx::v_noabi::stdx::string_view command_succeeded_event::host() const {
     return libmongoc::apm_command_succeeded_get_host(
-               static_cast<const mongoc_apm_command_succeeded_t*>(_succeeded_event))
+               static_cast<mongoc_apm_command_succeeded_t const*>(_succeeded_event))
         ->host;
 }
 
 std::uint16_t command_succeeded_event::port() const {
     return libmongoc::apm_command_succeeded_get_host(
-               static_cast<const mongoc_apm_command_succeeded_t*>(_succeeded_event))
+               static_cast<mongoc_apm_command_succeeded_t const*>(_succeeded_event))
         ->port;
 }
 
-}  // namespace events
-}  // namespace v_noabi
-}  // namespace mongocxx
+} // namespace events
+} // namespace v_noabi
+} // namespace mongocxx
