@@ -13,25 +13,23 @@
 // limitations under the License.
 
 #include <mongocxx/events/topology_closed_event.hpp>
-#include <mongocxx/private/libmongoc.hh>
 
-#include <mongocxx/config/private/prelude.hh>
+#include <mongocxx/private/mongoc.hh>
 
 namespace mongocxx {
 namespace v_noabi {
 namespace events {
 
-topology_closed_event::topology_closed_event(const void* event) : _event(event) {}
+topology_closed_event::topology_closed_event(void const* event) : _event(event) {}
 
 topology_closed_event::~topology_closed_event() = default;
 
 bsoncxx::v_noabi::oid topology_closed_event::topology_id() const {
     bson_oid_t boid;
-    libmongoc::apm_topology_closed_get_topology_id(
-        static_cast<const mongoc_apm_topology_closed_t*>(_event), &boid);
-    return bsoncxx::v_noabi::oid(reinterpret_cast<const char*>(boid.bytes), sizeof(boid.bytes));
+    libmongoc::apm_topology_closed_get_topology_id(static_cast<mongoc_apm_topology_closed_t const*>(_event), &boid);
+    return bsoncxx::v_noabi::oid(reinterpret_cast<char const*>(boid.bytes), sizeof(boid.bytes));
 }
 
-}  // namespace events
-}  // namespace v_noabi
-}  // namespace mongocxx
+} // namespace events
+} // namespace v_noabi
+} // namespace mongocxx
