@@ -1,4 +1,4 @@
-// Copyright 2018-present MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -13,25 +13,23 @@
 // limitations under the License.
 
 #include <mongocxx/events/topology_opening_event.hpp>
-#include <mongocxx/private/libmongoc.hh>
 
-#include <mongocxx/config/private/prelude.hh>
+#include <mongocxx/private/mongoc.hh>
 
 namespace mongocxx {
-inline namespace v_noabi {
+namespace v_noabi {
 namespace events {
 
-topology_opening_event::topology_opening_event(const void* event) : _event(event) {}
+topology_opening_event::topology_opening_event(void const* event) : _event(event) {}
 
 topology_opening_event::~topology_opening_event() = default;
 
-bsoncxx::oid topology_opening_event::topology_id() const {
+bsoncxx::v_noabi::oid topology_opening_event::topology_id() const {
     bson_oid_t boid;
-    libmongoc::apm_topology_opening_get_topology_id(
-        static_cast<const mongoc_apm_topology_opening_t*>(_event), &boid);
-    return bsoncxx::oid(reinterpret_cast<const char*>(boid.bytes), sizeof(boid.bytes));
+    libmongoc::apm_topology_opening_get_topology_id(static_cast<mongoc_apm_topology_opening_t const*>(_event), &boid);
+    return bsoncxx::v_noabi::oid(reinterpret_cast<char const*>(boid.bytes), sizeof(boid.bytes));
 }
 
-}  // namespace events
-}  // namespace v_noabi
-}  // namespace mongocxx
+} // namespace events
+} // namespace v_noabi
+} // namespace mongocxx
