@@ -18,28 +18,27 @@
 #include <bsoncxx/string/to_string.hpp>
 
 #include <mongocxx/exception/operation_exception.hpp>
-#include <mongocxx/private/libbson.hh>
-#include <mongocxx/private/libmongoc.hh>
 
-#include <mongocxx/config/private/prelude.hh>
+#include <mongocxx/private/bson.hh>
+#include <mongocxx/private/mongoc.hh>
 
 namespace mongocxx {
 namespace v_noabi {
 
 operation_exception::~operation_exception() = default;
 
-operation_exception::operation_exception(std::error_code ec,
-                                         bsoncxx::v_noabi::document::value&& raw_server_error,
-                                         std::string what_arg)
+operation_exception::operation_exception(
+    std::error_code ec,
+    bsoncxx::v_noabi::document::value&& raw_server_error,
+    std::string what_arg)
     : exception(ec, what_arg), _raw_server_error{std::move(raw_server_error)} {}
 
-const bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::value>&
-operation_exception::raw_server_error() const {
+bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::value> const& operation_exception::raw_server_error()
+    const {
     return _raw_server_error;
 }
 
-bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::value>&
-operation_exception::raw_server_error() {
+bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::value>& operation_exception::raw_server_error() {
     return _raw_server_error;
 }
 
@@ -53,5 +52,5 @@ bool operation_exception::has_error_label(bsoncxx::v_noabi::stdx::string_view la
     return libmongoc::error_has_label(error.bson(), label_str.c_str());
 }
 
-}  // namespace v_noabi
-}  // namespace mongocxx
+} // namespace v_noabi
+} // namespace mongocxx
