@@ -1,4 +1,4 @@
-// Copyright 2017 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -12,6 +12,8 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
+#include <mongocxx/v1/detail/macros.hpp>
+
 #include <ios>
 #include <sstream>
 #include <string>
@@ -19,20 +21,21 @@
 #include <bsoncxx/builder/basic/document.hpp>
 #include <bsoncxx/builder/basic/kvp.hpp>
 #include <bsoncxx/oid.hpp>
-#include <bsoncxx/stdx/make_unique.hpp>
 #include <bsoncxx/stdx/optional.hpp>
+
 #include <mongocxx/database.hpp>
 #include <mongocxx/exception/error_code.hpp>
 #include <mongocxx/exception/gridfs_exception.hpp>
 #include <mongocxx/exception/logic_error.hpp>
 #include <mongocxx/gridfs/bucket.hpp>
-#include <mongocxx/gridfs/private/bucket.hh>
 #include <mongocxx/options/delete.hpp>
 #include <mongocxx/options/index.hpp>
-#include <mongocxx/private/numeric_casting.hh>
-#include <mongocxx/stdx.hpp>
 
-#include <mongocxx/config/private/prelude.hh>
+#include <mongocxx/gridfs/bucket.hh>
+
+#include <bsoncxx/private/make_unique.hh>
+
+#include <mongocxx/private/numeric_casting.hh>
 
 namespace mongocxx {
 namespace v_noabi {
@@ -41,15 +44,16 @@ namespace gridfs {
 namespace {
 
 std::int32_t read_chunk_size_from_files_document(bsoncxx::v_noabi::document::view files_doc) {
-    const std::int64_t k_max_document_size = 16 * 1024 * 1024;
+    std::int64_t const k_max_document_size = 16 * 1024 * 1024;
     std::int64_t chunk_size;
 
     auto chunk_size_ele = files_doc["chunkSize"];
 
     if (!chunk_size_ele) {
-        throw gridfs_exception{error_code::k_gridfs_file_corrupted,
-                               "expected files document to contain field \"chunkSize\" with type "
-                               "k_int32 or k_int64"};
+        throw gridfs_exception{
+            error_code::k_gridfs_file_corrupted,
+            "expected files document to contain field \"chunkSize\" with type "
+            "k_int32 or k_int64"};
     }
 
     if (chunk_size_ele.type() == bsoncxx::v_noabi::type::k_int64) {
@@ -57,9 +61,10 @@ std::int32_t read_chunk_size_from_files_document(bsoncxx::v_noabi::document::vie
     } else if (chunk_size_ele.type() == bsoncxx::v_noabi::type::k_int32) {
         chunk_size = chunk_size_ele.get_int32().value;
     } else {
-        throw gridfs_exception{error_code::k_gridfs_file_corrupted,
-                               "expected files document to contain field \"chunkSize\" with type "
-                               "k_int32 or k_int64"};
+        throw gridfs_exception{
+            error_code::k_gridfs_file_corrupted,
+            "expected files document to contain field \"chunkSize\" with type "
+            "k_int32 or k_int64"};
     }
 
     // Each chunk needs to be able to fit in a single document.
@@ -70,22 +75,22 @@ std::int32_t read_chunk_size_from_files_document(bsoncxx::v_noabi::document::vie
         throw gridfs_exception{error_code::k_gridfs_file_corrupted, err.str()};
     } else if (chunk_size <= 0) {
         std::ostringstream err;
-        err << "files document contains unexpected chunk size: " << chunk_size
-            << "; value must be positive";
+        err << "files document contains unexpected chunk size: " << chunk_size << "; value must be positive";
         throw gridfs_exception{error_code::k_gridfs_file_corrupted, err.str()};
     }
 
     return static_cast<std::int32_t>(chunk_size);
 }
 
-std::int64_t read_length_from_files_document(const bsoncxx::v_noabi::document::view files_doc) {
+std::int64_t read_length_from_files_document(bsoncxx::v_noabi::document::view const files_doc) {
     auto length_ele = files_doc["length"];
     std::int64_t length;
 
     if (!length_ele) {
-        throw gridfs_exception{error_code::k_gridfs_file_corrupted,
-                               "expected files document to contain field \"length\" with type "
-                               "k_int32 or k_int64"};
+        throw gridfs_exception{
+            error_code::k_gridfs_file_corrupted,
+            "expected files document to contain field \"length\" with type "
+            "k_int32 or k_int64"};
     }
 
     if (length_ele.type() == bsoncxx::v_noabi::type::k_int64) {
@@ -93,9 +98,10 @@ std::int64_t read_length_from_files_document(const bsoncxx::v_noabi::document::v
     } else if (length_ele.type() == bsoncxx::v_noabi::type::k_int32) {
         length = length_ele.get_int32().value;
     } else {
-        throw gridfs_exception{error_code::k_gridfs_file_corrupted,
-                               "expected files document to contain field \"length\" with type "
-                               "k_int32 or k_int64"};
+        throw gridfs_exception{
+            error_code::k_gridfs_file_corrupted,
+            "expected files document to contain field \"length\" with type "
+            "k_int32 or k_int64"};
     }
 
     if (length < 0) {
@@ -107,9 +113,9 @@ std::int64_t read_length_from_files_document(const bsoncxx::v_noabi::document::v
     return length;
 }
 
-}  // namespace
+} // namespace
 
-bucket::bucket(const database& db, const options::gridfs::bucket& options) {
+bucket::bucket(database const& db, options::gridfs::bucket const& options) {
     std::string bucket_name = "fs";
     if (auto name = options.bucket_name()) {
         bucket_name = *name;
@@ -125,14 +131,13 @@ bucket::bucket(const database& db, const options::gridfs::bucket& options) {
     }
 
     if (default_chunk_size_bytes <= 0) {
-        throw logic_error{error_code::k_invalid_parameter,
-                          "positive value for chunk_size_bytes required"};
+        throw logic_error{error_code::k_invalid_parameter, "positive value for chunk_size_bytes required"};
     }
 
     collection chunks = db[bucket_name + ".chunks"];
     collection files = db[bucket_name + ".files"];
 
-    _impl = stdx::make_unique<impl>(
+    _impl = bsoncxx::make_unique<impl>(
         std::move(bucket_name), default_chunk_size_bytes, std::move(chunks), std::move(files));
 
     if (auto read_concern = options.read_concern()) {
@@ -160,40 +165,43 @@ bucket::operator bool() const noexcept {
     return static_cast<bool>(_impl);
 }
 
-bucket::bucket(const bucket& b) {
+bucket::bucket(bucket const& b) {
     if (b) {
-        _impl = stdx::make_unique<impl>(b._get_impl());
+        _impl = bsoncxx::make_unique<impl>(b._get_impl());
     }
 }
 
-bucket& bucket::operator=(const bucket& b) {
+bucket& bucket::operator=(bucket const& b) {
     if (!b) {
         _impl.reset();
     } else if (!*this) {
-        _impl = stdx::make_unique<impl>(b._get_impl());
+        _impl = bsoncxx::make_unique<impl>(b._get_impl());
     } else {
         *_impl = b._get_impl();
     }
     return *this;
 }
 
-uploader bucket::open_upload_stream(stdx::string_view filename,
-                                    const options::gridfs::upload& options) {
+uploader bucket::open_upload_stream(
+    bsoncxx::v_noabi::stdx::string_view filename,
+    options::gridfs::upload const& options) {
     auto id = bsoncxx::v_noabi::types::bson_value::view{bsoncxx::v_noabi::types::b_oid{}};
     return open_upload_stream_with_id(id, filename, options);
 }
 
-uploader bucket::open_upload_stream(const client_session& session,
-                                    stdx::string_view filename,
-                                    const options::gridfs::upload& options) {
+uploader bucket::open_upload_stream(
+    client_session const& session,
+    bsoncxx::v_noabi::stdx::string_view filename,
+    options::gridfs::upload const& options) {
     auto id = bsoncxx::v_noabi::types::bson_value::view{bsoncxx::v_noabi::types::b_oid{}};
     return open_upload_stream_with_id(session, id, filename, options);
 }
 
-uploader bucket::_open_upload_stream_with_id(const client_session* session,
-                                             bsoncxx::v_noabi::types::bson_value::view id,
-                                             stdx::string_view filename,
-                                             const options::gridfs::upload& options) {
+uploader bucket::_open_upload_stream_with_id(
+    client_session const* session,
+    bsoncxx::v_noabi::types::bson_value::view id,
+    bsoncxx::v_noabi::stdx::string_view filename,
+    options::gridfs::upload const& options) {
     std::int32_t chunk_size_bytes = _get_impl().default_chunk_size_bytes;
 
     if (auto chunk_size = options.chunk_size_bytes()) {
@@ -208,58 +216,55 @@ uploader bucket::_open_upload_stream_with_id(const client_session* session,
 
     create_indexes_if_nonexistent(session);
 
-    return uploader{session,
-                    id,
-                    filename,
-                    _get_impl().files,
-                    _get_impl().chunks,
-                    chunk_size_bytes,
-                    std::move(options.metadata())};
+    return uploader{session, id, filename, _get_impl().files, _get_impl().chunks, chunk_size_bytes, options.metadata()};
 }
 
-uploader bucket::open_upload_stream_with_id(bsoncxx::v_noabi::types::bson_value::view id,
-                                            stdx::string_view filename,
-                                            const options::gridfs::upload& options) {
+uploader bucket::open_upload_stream_with_id(
+    bsoncxx::v_noabi::types::bson_value::view id,
+    bsoncxx::v_noabi::stdx::string_view filename,
+    options::gridfs::upload const& options) {
     return _open_upload_stream_with_id(nullptr, id, filename, options);
 }
 
-uploader bucket::open_upload_stream_with_id(const client_session& session,
-                                            bsoncxx::v_noabi::types::bson_value::view id,
-                                            stdx::string_view filename,
-                                            const options::gridfs::upload& options) {
+uploader bucket::open_upload_stream_with_id(
+    client_session const& session,
+    bsoncxx::v_noabi::types::bson_value::view id,
+    bsoncxx::v_noabi::stdx::string_view filename,
+    options::gridfs::upload const& options) {
     return _open_upload_stream_with_id(&session, id, filename, options);
 }
 
-result::gridfs::upload bucket::upload_from_stream(stdx::string_view filename,
-                                                  std::istream* source,
-                                                  const options::gridfs::upload& options) {
+result::gridfs::upload bucket::upload_from_stream(
+    bsoncxx::v_noabi::stdx::string_view filename,
+    std::istream* source,
+    options::gridfs::upload const& options) {
     auto id = bsoncxx::v_noabi::types::bson_value::view{bsoncxx::v_noabi::types::b_oid{}};
     upload_from_stream_with_id(id, filename, source, options);
     return id;
 }
 
-result::gridfs::upload bucket::upload_from_stream(const client_session& session,
-                                                  stdx::string_view filename,
-                                                  std::istream* source,
-                                                  const options::gridfs::upload& options) {
+result::gridfs::upload bucket::upload_from_stream(
+    client_session const& session,
+    bsoncxx::v_noabi::stdx::string_view filename,
+    std::istream* source,
+    options::gridfs::upload const& options) {
     auto id = bsoncxx::v_noabi::types::bson_value::view{bsoncxx::v_noabi::types::b_oid{}};
     upload_from_stream_with_id(session, id, filename, source, options);
     return id;
 }
 
-void bucket::_upload_from_stream_with_id(const client_session* session,
-                                         bsoncxx::v_noabi::types::bson_value::view id,
-                                         stdx::string_view filename,
-                                         std::istream* source,
-                                         const options::gridfs::upload& options) {
+void bucket::_upload_from_stream_with_id(
+    client_session const* session,
+    bsoncxx::v_noabi::types::bson_value::view id,
+    bsoncxx::v_noabi::stdx::string_view filename,
+    std::istream* source,
+    options::gridfs::upload const& options) {
     uploader upload_stream = _open_upload_stream_with_id(session, id, filename, options);
     std::int32_t chunk_size = upload_stream.chunk_size();
-    std::unique_ptr<std::uint8_t[]> buffer =
-        stdx::make_unique<std::uint8_t[]>(static_cast<std::size_t>(chunk_size));
+    std::unique_ptr<std::uint8_t[]> buffer = bsoncxx::make_unique<std::uint8_t[]>(static_cast<std::size_t>(chunk_size));
 
     do {
-        source->read(reinterpret_cast<char*>(buffer.get()),
-                     static_cast<std::streamsize>(chunk_size));
+        source->read(reinterpret_cast<char*>(buffer.get()), static_cast<std::streamsize>(chunk_size));
         upload_stream.write(buffer.get(), static_cast<std::size_t>(source->gcount()));
     } while (*source);
 
@@ -267,31 +272,34 @@ void bucket::_upload_from_stream_with_id(const client_session* session,
     if (source->bad() || (source->fail() && !source->eof())) {
         upload_stream.abort();
         source->exceptions(std::ios::failbit | std::ios::badbit);
-        MONGOCXX_UNREACHABLE;
+        MONGOCXX_PRIVATE_UNREACHABLE;
     }
 
     upload_stream.close();
 }
 
-void bucket::upload_from_stream_with_id(bsoncxx::v_noabi::types::bson_value::view id,
-                                        stdx::string_view filename,
-                                        std::istream* source,
-                                        const options::gridfs::upload& options) {
+void bucket::upload_from_stream_with_id(
+    bsoncxx::v_noabi::types::bson_value::view id,
+    bsoncxx::v_noabi::stdx::string_view filename,
+    std::istream* source,
+    options::gridfs::upload const& options) {
     return _upload_from_stream_with_id(nullptr, id, filename, source, options);
 }
 
-void bucket::upload_from_stream_with_id(const client_session& session,
-                                        bsoncxx::v_noabi::types::bson_value::view id,
-                                        stdx::string_view filename,
-                                        std::istream* source,
-                                        const options::gridfs::upload& options) {
+void bucket::upload_from_stream_with_id(
+    client_session const& session,
+    bsoncxx::v_noabi::types::bson_value::view id,
+    bsoncxx::v_noabi::stdx::string_view filename,
+    std::istream* source,
+    options::gridfs::upload const& options) {
     return _upload_from_stream_with_id(&session, id, filename, source, options);
 }
 
-downloader bucket::_open_download_stream(const client_session* session,
-                                         bsoncxx::v_noabi::types::bson_value::view id,
-                                         stdx::optional<std::size_t> start,
-                                         stdx::optional<std::size_t> end) {
+downloader bucket::_open_download_stream(
+    client_session const* session,
+    bsoncxx::v_noabi::types::bson_value::view id,
+    bsoncxx::v_noabi::stdx::optional<std::size_t> start,
+    bsoncxx::v_noabi::stdx::optional<std::size_t> end) {
     using namespace bsoncxx;
 
     builder::basic::document files_filter;
@@ -306,21 +314,22 @@ downloader bucket::_open_download_stream(const client_session* session,
 
     auto files_doc_view = files_doc->view();
 
-    if (!files_doc_view["length"] || (files_doc_view["length"].type() != type::k_int64 &&
-                                      files_doc_view["length"].type() != type::k_int32)) {
-        throw gridfs_exception{error_code::k_gridfs_file_corrupted,
-                               "expected files document to contain field \"length\" with type "
-                               "k_int32 or k_int64"};
+    if (!files_doc_view["length"] ||
+        (files_doc_view["length"].type() != type::k_int64 && files_doc_view["length"].type() != type::k_int32)) {
+        throw gridfs_exception{
+            error_code::k_gridfs_file_corrupted,
+            "expected files document to contain field \"length\" with type "
+            "k_int32 or k_int64"};
     }
 
-    const auto chunk_size = read_chunk_size_from_files_document(*files_doc);
-    const auto file_len = read_length_from_files_document(*files_doc);
+    auto const chunk_size = read_chunk_size_from_files_document(*files_doc);
+    auto const file_len = read_length_from_files_document(*files_doc);
     chunks_and_bytes_offset start_offset;
     auto length = files_doc_view["length"];
 
     if ((length.type() == type::k_int64 && !length.get_int64().value) ||
         (length.type() == type::k_int32 && !length.get_int32().value)) {
-        return downloader{stdx::nullopt, start_offset, chunk_size, file_len, *files_doc};
+        return downloader{bsoncxx::v_noabi::stdx::nullopt, start_offset, chunk_size, file_len, *files_doc};
     }
 
     builder::basic::document chunks_filter;
@@ -334,30 +343,26 @@ downloader bucket::_open_download_stream(const client_session* session,
 
     if (start && end) {
         if (*start > *end) {
-            throw gridfs_exception{error_code::k_invalid_parameter,
-                                   "expected end to be greater than start"};
+            throw gridfs_exception{error_code::k_invalid_parameter, "expected end to be greater than start"};
         }
     }
 
     int64_t start_i64 = 0;
     if (start && *start > 0) {
         if (!size_t_to_int64_safe(*start, start_i64)) {
-            throw gridfs_exception{error_code::k_invalid_parameter,
-                                   "expected start to not be greater than max int64"};
+            throw gridfs_exception{error_code::k_invalid_parameter, "expected start to not be greater than max int64"};
         }
         if (file_len >= 0 && start_i64 > file_len) {
-            throw gridfs_exception{error_code::k_invalid_parameter,
-                                   "expected start to not be greater than the file length"};
+            throw gridfs_exception{
+                error_code::k_invalid_parameter, "expected start to not be greater than the file length"};
         }
         auto start_offset_div = std::lldiv(start_i64, chunk_size);
         if (!int64_to_int32_safe(start_offset_div.quot, start_offset.chunks_offset)) {
-            throw gridfs_exception{error_code::k_invalid_parameter,
-                                   "expected chunk offset to be in bounds of int32"};
+            throw gridfs_exception{error_code::k_invalid_parameter, "expected chunk offset to be in bounds of int32"};
         }
 
         if (!int64_to_int32_safe(start_offset_div.rem, start_offset.bytes_offset)) {
-            throw gridfs_exception{error_code::k_invalid_parameter,
-                                   "expected bytes offset to be in bounds of int32"};
+            throw gridfs_exception{error_code::k_invalid_parameter, "expected bytes offset to be in bounds of int32"};
         }
         chunks_options.skip(start_offset.chunks_offset);
     }
@@ -365,48 +370,45 @@ downloader bucket::_open_download_stream(const client_session* session,
     if (end) {
         int64_t end_i64;
         if (!size_t_to_int64_safe(*end, end_i64)) {
-            throw gridfs_exception{error_code::k_invalid_parameter,
-                                   "expected end to not be greater than max int64"};
+            throw gridfs_exception{error_code::k_invalid_parameter, "expected end to not be greater than max int64"};
         }
 
         if (file_len >= 0 && end_i64 > file_len) {
-            throw gridfs_exception{error_code::k_invalid_parameter,
-                                   "expected end to not be greater than the file length"};
+            throw gridfs_exception{
+                error_code::k_invalid_parameter, "expected end to not be greater than the file length"};
         }
         if (file_len >= 0 && end_i64 < file_len) {
-            const int64_t num_chunks = (end_i64 / static_cast<int64_t>(chunk_size)) -
-                                       (start_i64 / static_cast<int64_t>(chunk_size)) + 1;
+            int64_t const num_chunks =
+                (end_i64 / static_cast<int64_t>(chunk_size)) - (start_i64 / static_cast<int64_t>(chunk_size)) + 1;
             chunks_options.limit(num_chunks);
         }
     }
 
-    auto cursor = session
-                      ? _get_impl().chunks.find(*session, chunks_filter.extract(), chunks_options)
-                      : _get_impl().chunks.find(chunks_filter.extract(), chunks_options);
+    auto cursor = session ? _get_impl().chunks.find(*session, chunks_filter.extract(), chunks_options)
+                          : _get_impl().chunks.find(chunks_filter.extract(), chunks_options);
 
     return downloader{std::move(cursor), start_offset, chunk_size, file_len, *files_doc};
 }
 
 downloader bucket::open_download_stream(bsoncxx::v_noabi::types::bson_value::view id) {
-    return _open_download_stream(nullptr, id, stdx::nullopt, stdx::nullopt);
+    return _open_download_stream(nullptr, id, bsoncxx::v_noabi::stdx::nullopt, bsoncxx::v_noabi::stdx::nullopt);
 }
 
-downloader bucket::open_download_stream(const client_session& session,
-                                        bsoncxx::v_noabi::types::bson_value::view id) {
-    return _open_download_stream(&session, id, stdx::nullopt, stdx::nullopt);
+downloader bucket::open_download_stream(client_session const& session, bsoncxx::v_noabi::types::bson_value::view id) {
+    return _open_download_stream(&session, id, bsoncxx::v_noabi::stdx::nullopt, bsoncxx::v_noabi::stdx::nullopt);
 }
 
-void bucket::_download_to_stream(const client_session* session,
-                                 bsoncxx::v_noabi::types::bson_value::view id,
-                                 std::ostream* destination,
-                                 stdx::optional<std::size_t> start,
-                                 stdx::optional<std::size_t> end) {
+void bucket::_download_to_stream(
+    client_session const* session,
+    bsoncxx::v_noabi::types::bson_value::view id,
+    std::ostream* destination,
+    bsoncxx::v_noabi::stdx::optional<std::size_t> start,
+    bsoncxx::v_noabi::stdx::optional<std::size_t> end) {
     downloader download_stream = _open_download_stream(session, id, start, end);
 
     std::size_t chunk_size;
     if (!int32_to_size_t_safe(download_stream.chunk_size(), chunk_size)) {
-        throw gridfs_exception{error_code::k_invalid_parameter,
-                               "expected chunk size to be in bounds of size_t"};
+        throw gridfs_exception{error_code::k_invalid_parameter, "expected chunk size to be in bounds of size_t"};
     }
     if (!start) {
         start.emplace<std::size_t>(0);
@@ -414,54 +416,52 @@ void bucket::_download_to_stream(const client_session* session,
     if (!end) {
         std::size_t file_length_sz;
         if (!int64_to_size_t_safe(download_stream.file_length(), file_length_sz)) {
-            throw gridfs_exception{error_code::k_invalid_parameter,
-                                   "expected file length to be in bounds of int64"};
+            throw gridfs_exception{error_code::k_invalid_parameter, "expected file length to be in bounds of int64"};
         }
         end = file_length_sz;
     }
     auto bytes_expected = *end - *start;
-    std::unique_ptr<std::uint8_t[]> buffer =
-        stdx::make_unique<std::uint8_t[]>(static_cast<std::size_t>(chunk_size));
+    std::unique_ptr<std::uint8_t[]> buffer = bsoncxx::make_unique<std::uint8_t[]>(static_cast<std::size_t>(chunk_size));
 
     while (bytes_expected > 0) {
-        const std::size_t bytes_read = download_stream.read(
-            buffer.get(), static_cast<std::size_t>(std::min(bytes_expected, chunk_size)));
-        destination->write(reinterpret_cast<char*>(buffer.get()),
-                           static_cast<std::streamsize>(bytes_read));
+        std::size_t const bytes_read =
+            download_stream.read(buffer.get(), static_cast<std::size_t>(std::min(bytes_expected, chunk_size)));
+        destination->write(reinterpret_cast<char*>(buffer.get()), static_cast<std::streamsize>(bytes_read));
         bytes_expected -= bytes_read;
     }
 
     download_stream.close();
 }
 
-void bucket::download_to_stream(bsoncxx::v_noabi::types::bson_value::view id,
-                                std::ostream* destination) {
-    _download_to_stream(nullptr, id, destination, stdx::nullopt, stdx::nullopt);
+void bucket::download_to_stream(bsoncxx::v_noabi::types::bson_value::view id, std::ostream* destination) {
+    _download_to_stream(nullptr, id, destination, bsoncxx::v_noabi::stdx::nullopt, bsoncxx::v_noabi::stdx::nullopt);
 }
 
-void bucket::download_to_stream(bsoncxx::v_noabi::types::bson_value::view id,
-                                std::ostream* destination,
-                                std::size_t start,
-                                std::size_t end) {
+void bucket::download_to_stream(
+    bsoncxx::v_noabi::types::bson_value::view id,
+    std::ostream* destination,
+    std::size_t start,
+    std::size_t end) {
     _download_to_stream(nullptr, id, destination, start, end);
 }
 
-void bucket::download_to_stream(const client_session& session,
-                                bsoncxx::v_noabi::types::bson_value::view id,
-                                std::ostream* destination) {
-    _download_to_stream(&session, id, destination, stdx::nullopt, stdx::nullopt);
+void bucket::download_to_stream(
+    client_session const& session,
+    bsoncxx::v_noabi::types::bson_value::view id,
+    std::ostream* destination) {
+    _download_to_stream(&session, id, destination, bsoncxx::v_noabi::stdx::nullopt, bsoncxx::v_noabi::stdx::nullopt);
 }
 
-void bucket::download_to_stream(const client_session& session,
-                                bsoncxx::v_noabi::types::bson_value::view id,
-                                std::ostream* destination,
-                                std::size_t start,
-                                std::size_t end) {
+void bucket::download_to_stream(
+    client_session const& session,
+    bsoncxx::v_noabi::types::bson_value::view id,
+    std::ostream* destination,
+    std::size_t start,
+    std::size_t end) {
     _download_to_stream(&session, id, destination, start, end);
 }
 
-void bucket::_delete_file(const client_session* session,
-                          bsoncxx::v_noabi::types::bson_value::view id) {
+void bucket::_delete_file(client_session const* session, bsoncxx::v_noabi::types::bson_value::view id) {
     using namespace bsoncxx;
 
     builder::basic::document files_builder;
@@ -490,27 +490,26 @@ void bucket::delete_file(bsoncxx::v_noabi::types::bson_value::view id) {
     _delete_file(nullptr, id);
 }
 
-void bucket::delete_file(const client_session& session,
-                         bsoncxx::v_noabi::types::bson_value::view id) {
+void bucket::delete_file(client_session const& session, bsoncxx::v_noabi::types::bson_value::view id) {
     _delete_file(&session, id);
 }
 
-cursor bucket::find(bsoncxx::v_noabi::document::view_or_value filter,
-                    const options::find& options) {
+cursor bucket::find(bsoncxx::v_noabi::document::view_or_value filter, options::find const& options) {
     return _get_impl().files.find(filter, options);
 }
 
-cursor bucket::find(const client_session& session,
-                    bsoncxx::v_noabi::document::view_or_value filter,
-                    const options::find& options) {
+cursor bucket::find(
+    client_session const& session,
+    bsoncxx::v_noabi::document::view_or_value filter,
+    options::find const& options) {
     return _get_impl().files.find(session, filter, options);
 }
 
-stdx::string_view bucket::bucket_name() const {
+bsoncxx::v_noabi::stdx::string_view bucket::bucket_name() const {
     return _get_impl().bucket_name;
 }
 
-void bucket::create_indexes_if_nonexistent(const client_session* session) {
+void bucket::create_indexes_if_nonexistent(client_session const* session) {
     if (_get_impl().indexes_created) {
         return;
     }
@@ -518,8 +517,7 @@ void bucket::create_indexes_if_nonexistent(const client_session* session) {
     bsoncxx::v_noabi::builder::basic::document filter;
     filter.append(bsoncxx::v_noabi::builder::basic::kvp("_id", 1));
 
-    auto find_options =
-        options::find{}.projection(filter.view()).read_preference(read_preference{});
+    auto find_options = options::find{}.projection(filter.view()).read_preference(read_preference{});
 
     if (session) {
         if (_get_impl().files.find_one(*session, {}, find_options)) {
@@ -555,7 +553,7 @@ void bucket::create_indexes_if_nonexistent(const client_session* session) {
     _get_impl().indexes_created = true;
 }
 
-const bucket::impl& bucket::_get_impl() const {
+bucket::impl const& bucket::_get_impl() const {
     if (!_impl) {
         throw logic_error{error_code::k_invalid_gridfs_bucket_object};
     }
@@ -563,10 +561,10 @@ const bucket::impl& bucket::_get_impl() const {
 }
 
 bucket::impl& bucket::_get_impl() {
-    auto cthis = const_cast<const bucket*>(this);
+    auto cthis = const_cast<bucket const*>(this);
     return const_cast<bucket::impl&>(cthis->_get_impl());
 }
 
-}  // namespace gridfs
-}  // namespace v_noabi
-}  // namespace mongocxx
+} // namespace gridfs
+} // namespace v_noabi
+} // namespace mongocxx
