@@ -14,20 +14,19 @@
 
 #include <mongocxx/index_model.hpp>
 
-#include <mongocxx/config/private/prelude.hh>
-
 namespace mongocxx {
 namespace v_noabi {
 
-index_model::index_model(const bsoncxx::v_noabi::document::view_or_value& keys,
-                         const bsoncxx::v_noabi::document::view_or_value& options)
+index_model::index_model(
+    bsoncxx::v_noabi::document::view_or_value const& keys,
+    bsoncxx::v_noabi::document::view_or_value const& options)
     : _keys{keys.view()}, _options{options.view()} {}
 
 index_model::index_model(index_model&&) noexcept = default;
 
 index_model& index_model::operator=(index_model&&) noexcept = default;
 
-index_model::index_model(const index_model&) = default;
+index_model::index_model(index_model const&) = default;
 
 index_model::~index_model() = default;
 
@@ -39,5 +38,5 @@ bsoncxx::v_noabi::document::view index_model::options() const {
     return _options.view();
 }
 
-}  // namespace v_noabi
-}  // namespace mongocxx
+} // namespace v_noabi
+} // namespace mongocxx
