@@ -1,4 +1,4 @@
-// Copyright 2015 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -14,11 +14,10 @@
 
 #include <mongocxx/logger.hpp>
 
-#include <mongocxx/config/private/prelude.hh>
-
 namespace mongocxx {
-inline namespace v_noabi {
-stdx::string_view MONGOCXX_CALL to_string(log_level level) {
+namespace v_noabi {
+
+bsoncxx::v_noabi::stdx::string_view to_string(log_level level) {
     switch (level) {
         case log_level::k_error:
             return "error";
@@ -42,5 +41,5 @@ stdx::string_view MONGOCXX_CALL to_string(log_level level) {
 logger::logger() = default;
 logger::~logger() = default;
 
-}  // namespace v_noabi
-}  // namespace mongocxx
+} // namespace v_noabi
+} // namespace mongocxx
