@@ -1,4 +1,4 @@
-// Copyright 2014 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -14,36 +14,34 @@
 
 #include <mongocxx/model/delete_many.hpp>
 
-#include <mongocxx/config/private/prelude.hh>
-
 namespace mongocxx {
-inline namespace v_noabi {
+namespace v_noabi {
 namespace model {
 
-delete_many::delete_many(bsoncxx::document::view_or_value filter) : _filter(std::move(filter)) {}
+delete_many::delete_many(bsoncxx::v_noabi::document::view_or_value filter) : _filter(std::move(filter)) {}
 
-const bsoncxx::document::view_or_value& delete_many::filter() const {
+bsoncxx::v_noabi::document::view_or_value const& delete_many::filter() const {
     return _filter;
 }
 
-delete_many& delete_many::collation(bsoncxx::document::view_or_value collation) {
+delete_many& delete_many::collation(bsoncxx::v_noabi::document::view_or_value collation) {
     _collation = collation;
     return *this;
 }
 
-delete_many& delete_many::hint(class hint index_hint) {
+delete_many& delete_many::hint(mongocxx::v_noabi::hint index_hint) {
     _hint = std::move(index_hint);
     return *this;
 }
 
-const stdx::optional<class hint>& delete_many::hint() const {
+bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::hint> const& delete_many::hint() const {
     return _hint;
 }
 
-const stdx::optional<bsoncxx::document::view_or_value>& delete_many::collation() const {
+bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::view_or_value> const& delete_many::collation() const {
     return _collation;
 }
 
-}  // namespace model
-}  // namespace v_noabi
-}  // namespace mongocxx
+} // namespace model
+} // namespace v_noabi
+} // namespace mongocxx
