@@ -14,19 +14,16 @@
 
 #include <mongocxx/model/insert_one.hpp>
 
-#include <mongocxx/config/private/prelude.hh>
-
 namespace mongocxx {
 namespace v_noabi {
 namespace model {
 
-insert_one::insert_one(bsoncxx::v_noabi::document::view_or_value document)
-    : _document(std::move(document)) {}
+insert_one::insert_one(bsoncxx::v_noabi::document::view_or_value document) : _document(std::move(document)) {}
 
-const bsoncxx::v_noabi::document::view_or_value& insert_one::document() const {
+bsoncxx::v_noabi::document::view_or_value const& insert_one::document() const {
     return _document;
 }
 
-}  // namespace model
-}  // namespace v_noabi
-}  // namespace mongocxx
+} // namespace model
+} // namespace v_noabi
+} // namespace mongocxx
