@@ -1,4 +1,4 @@
-// Copyright 2014 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -13,30 +13,29 @@
 // limitations under the License.
 
 #include <bsoncxx/array/view_or_value.hpp>
-#include <mongocxx/model/update_one.hpp>
 
-#include <mongocxx/config/private/prelude.hh>
+#include <mongocxx/model/update_one.hpp>
 
 namespace mongocxx {
 namespace v_noabi {
 namespace model {
 
-update_one::update_one(bsoncxx::v_noabi::document::view_or_value filter,
-                       bsoncxx::v_noabi::document::view_or_value update)
+update_one::update_one(
+    bsoncxx::v_noabi::document::view_or_value filter,
+    bsoncxx::v_noabi::document::view_or_value update)
     : _filter(std::move(filter)), _update(std::move(update)) {}
 
-update_one::update_one(bsoncxx::v_noabi::document::view_or_value filter, const pipeline& update)
+update_one::update_one(bsoncxx::v_noabi::document::view_or_value filter, pipeline const& update)
     : _filter(std::move(filter)), _update(bsoncxx::v_noabi::document::value(update.view_array())) {}
 
-update_one::update_one(bsoncxx::v_noabi::document::view_or_value filter,
-                       std::initializer_list<_empty_doc_tag>)
+update_one::update_one(bsoncxx::v_noabi::document::view_or_value filter, std::initializer_list<_empty_doc_tag>)
     : _filter(std::move(filter)), _update() {}
 
-const bsoncxx::v_noabi::document::view_or_value& update_one::filter() const {
+bsoncxx::v_noabi::document::view_or_value const& update_one::filter() const {
     return _filter;
 }
 
-const bsoncxx::v_noabi::document::view_or_value& update_one::update() const {
+bsoncxx::v_noabi::document::view_or_value const& update_one::update() const {
     return _update;
 }
 
@@ -45,7 +44,7 @@ update_one& update_one::collation(bsoncxx::v_noabi::document::view_or_value coll
     return *this;
 }
 
-const stdx::optional<bsoncxx::v_noabi::document::view_or_value>& update_one::collation() const {
+bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::view_or_value> const& update_one::collation() const {
     return _collation;
 }
 
@@ -54,16 +53,25 @@ update_one& update_one::hint(mongocxx::v_noabi::hint index_hint) {
     return *this;
 }
 
-const stdx::optional<mongocxx::v_noabi::hint>& update_one::hint() const {
+bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::hint> const& update_one::hint() const {
     return _hint;
 }
 
+update_one& update_one::sort(bsoncxx::v_noabi::document::view_or_value sort) {
+    _sort = std::move(sort);
+    return *this;
+}
+
+bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::view_or_value> const& update_one::sort() const {
+    return _sort;
+}
+
 update_one& update_one::upsert(bool upsert) {
     _upsert = upsert;
     return *this;
 }
 
-const stdx::optional<bool>& update_one::upsert() const {
+bsoncxx::v_noabi::stdx::optional<bool> const& update_one::upsert() const {
     return _upsert;
 }
 
@@ -72,10 +80,10 @@ update_one& update_one::array_filters(bsoncxx::v_noabi::array::view_or_value arr
     return *this;
 }
 
-const stdx::optional<bsoncxx::v_noabi::array::view_or_value>& update_one::array_filters() const {
+bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::array::view_or_value> const& update_one::array_filters() const {
     return _array_filters;
 }
 
-}  // namespace model
-}  // namespace v_noabi
-}  // namespace mongocxx
+} // namespace model
+} // namespace v_noabi
+} // namespace mongocxx
