@@ -1,4 +1,4 @@
-// Copyright 2017-present MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -14,8 +14,6 @@
 
 #include <mongocxx/options/client_session.hpp>
 
-#include <mongocxx/config/private/prelude.hh>
-
 namespace mongocxx {
 namespace v_noabi {
 namespace options {
@@ -47,10 +45,10 @@ client_session& client_session::default_transaction_opts(transaction default_tra
     return *this;
 }
 
-const stdx::optional<transaction>& client_session::default_transaction_opts() const {
+bsoncxx::v_noabi::stdx::optional<transaction> const& client_session::default_transaction_opts() const {
     return _default_transaction_opts;
 }
 
-}  // namespace options
-}  // namespace v_noabi
-}  // namespace mongocxx
+} // namespace options
+} // namespace v_noabi
+} // namespace mongocxx
