@@ -19,8 +19,6 @@
 #include <mongocxx/read_preference.hpp>
 #include <mongocxx/write_concern.hpp>
 
-#include <mongocxx/config/private/prelude.hh>
-
 namespace mongocxx {
 namespace v_noabi {
 namespace options {
@@ -31,7 +29,7 @@ bucket& bucket::bucket_name(std::string bucket_name) {
     return *this;
 }
 
-const bsoncxx::v_noabi::stdx::optional<std::string>& bucket::bucket_name() const {
+bsoncxx::v_noabi::stdx::optional<std::string> const& bucket::bucket_name() const {
     return _bucket_name;
 }
 
@@ -40,7 +38,7 @@ bucket& bucket::chunk_size_bytes(std::int32_t chunk_size_bytes) {
     return *this;
 }
 
-const bsoncxx::v_noabi::stdx::optional<std::int32_t>& bucket::chunk_size_bytes() const {
+bsoncxx::v_noabi::stdx::optional<std::int32_t> const& bucket::chunk_size_bytes() const {
     return _chunk_size_bytes;
 }
 
@@ -49,8 +47,7 @@ bucket& bucket::read_concern(mongocxx::v_noabi::read_concern read_concern) {
     return *this;
 }
 
-const bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::read_concern>& bucket::read_concern()
-    const {
+bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::read_concern> const& bucket::read_concern() const {
     return _read_concern;
 }
 
@@ -59,8 +56,7 @@ bucket& bucket::read_preference(mongocxx::v_noabi::read_preference read_preferen
     return *this;
 }
 
-const bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::read_preference>&
-bucket::read_preference() const {
+bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::read_preference> const& bucket::read_preference() const {
     return _read_preference;
 }
 
@@ -69,12 +65,11 @@ bucket& bucket::write_concern(mongocxx::v_noabi::write_concern write_concern) {
     return *this;
 }
 
-const bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::write_concern>& bucket::write_concern()
-    const {
+bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::write_concern> const& bucket::write_concern() const {
     return _write_concern;
 }
 
-}  // namespace gridfs
-}  // namespace options
-}  // namespace v_noabi
-}  // namespace mongocxx
+} // namespace gridfs
+} // namespace options
+} // namespace v_noabi
+} // namespace mongocxx
