@@ -16,8 +16,6 @@
 
 #include <mongocxx/options/gridfs/upload.hpp>
 
-#include <mongocxx/config/private/prelude.hh>
-
 namespace mongocxx {
 namespace v_noabi {
 namespace options {
@@ -28,7 +26,7 @@ upload& upload::chunk_size_bytes(std::int32_t chunk_size_bytes) {
     return *this;
 }
 
-const bsoncxx::v_noabi::stdx::optional<std::int32_t>& upload::chunk_size_bytes() const {
+bsoncxx::v_noabi::stdx::optional<std::int32_t> const& upload::chunk_size_bytes() const {
     return _chunk_size_bytes;
 }
 
@@ -37,12 +35,11 @@ upload& upload::metadata(bsoncxx::v_noabi::document::view_or_value metadata) {
     return *this;
 }
 
-const bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::view_or_value>&
-upload::metadata() const {
+bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::view_or_value> const& upload::metadata() const {
     return _metadata;
 }
 
-}  // namespace gridfs
-}  // namespace options
-}  // namespace v_noabi
-}  // namespace mongocxx
+} // namespace gridfs
+} // namespace options
+} // namespace v_noabi
+} // namespace mongocxx
