@@ -1,4 +1,4 @@
-// Copyright 2023 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -14,8 +14,6 @@
 
 #include <mongocxx/options/range.hpp>
 
-#include <mongocxx/config/prelude.hpp>
-
 namespace mongocxx {
 namespace v_noabi {
 namespace options {
@@ -25,7 +23,7 @@ range& range::min(bsoncxx::v_noabi::types::bson_value::view_or_value value) {
     return *this;
 }
 
-const stdx::optional<bsoncxx::v_noabi::types::bson_value::view_or_value>& range::min() const {
+bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::types::bson_value::view_or_value> const& range::min() const {
     return _min;
 }
 
@@ -34,7 +32,7 @@ range& range::max(bsoncxx::v_noabi::types::bson_value::view_or_value value) {
     return *this;
 }
 
-const stdx::optional<bsoncxx::v_noabi::types::bson_value::view_or_value>& range::max() const {
+bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::types::bson_value::view_or_value> const& range::max() const {
     return _max;
 }
 
@@ -43,19 +41,28 @@ range& range::sparsity(std::int64_t value) {
     return *this;
 }
 
-const stdx::optional<std::int64_t>& range::sparsity() const {
+range& range::trim_factor(std::int32_t value) {
+    _trim_factor = value;
+    return *this;
+}
+
+bsoncxx::v_noabi::stdx::optional<std::int64_t> const& range::sparsity() const {
     return _sparsity;
 }
 
+bsoncxx::v_noabi::stdx::optional<std::int32_t> const& range::trim_factor() const {
+    return _trim_factor;
+}
+
 range& range::precision(std::int32_t value) {
     _precision = value;
     return *this;
 }
 
-const stdx::optional<std::int32_t>& range::precision() const {
+bsoncxx::v_noabi::stdx::optional<std::int32_t> const& range::precision() const {
     return _precision;
 }
 
-}  // namespace options
-}  // namespace v_noabi
-}  // namespace mongocxx
+} // namespace options
+} // namespace v_noabi
+} // namespace mongocxx
