@@ -1,4 +1,4 @@
-// Copyright 2018-present MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -13,9 +13,8 @@
 // limitations under the License.
 
 #include <bsoncxx/document/view_or_value.hpp>
-#include <mongocxx/options/replace.hpp>
 
-#include <mongocxx/config/private/prelude.hh>
+#include <mongocxx/options/replace.hpp>
 
 namespace mongocxx {
 namespace v_noabi {
@@ -36,6 +35,11 @@ replace& replace::let(bsoncxx::v_noabi::document::view_or_value let) {
     return *this;
 }
 
+replace& replace::sort(bsoncxx::v_noabi::document::view_or_value sort) {
+    _sort = std::move(sort);
+    return *this;
+}
+
 replace& replace::comment(bsoncxx::v_noabi::types::bson_value::view_or_value comment) {
     _comment = std::move(comment);
     return *this;
@@ -56,34 +60,38 @@ replace& replace::write_concern(mongocxx::v_noabi::write_concern wc) {
     return *this;
 }
 
-const stdx::optional<mongocxx::v_noabi::hint>& replace::hint() const {
+bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::hint> const& replace::hint() const {
     return _hint;
 }
 
-const stdx::optional<bsoncxx::v_noabi::document::view_or_value> replace::let() const {
+bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::view_or_value> const replace::let() const {
     return _let;
 }
 
-const stdx::optional<bsoncxx::v_noabi::types::bson_value::view_or_value> replace::comment() const {
+bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::view_or_value> const& replace::sort() const {
+    return _sort;
+}
+
+bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::types::bson_value::view_or_value> const replace::comment() const {
     return _comment;
 }
 
-const stdx::optional<bool>& replace::bypass_document_validation() const {
+bsoncxx::v_noabi::stdx::optional<bool> const& replace::bypass_document_validation() const {
     return _bypass_document_validation;
 }
 
-const stdx::optional<bsoncxx::v_noabi::document::view_or_value>& replace::collation() const {
+bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::view_or_value> const& replace::collation() const {
     return _collation;
 }
 
-const stdx::optional<bool>& replace::upsert() const {
+bsoncxx::v_noabi::stdx::optional<bool> const& replace::upsert() const {
     return _upsert;
 }
 
-const stdx::optional<mongocxx::v_noabi::write_concern>& replace::write_concern() const {
+bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::write_concern> const& replace::write_concern() const {
     return _write_concern;
 }
 
-}  // namespace options
-}  // namespace v_noabi
-}  // namespace mongocxx
+} // namespace options
+} // namespace v_noabi
+} // namespace mongocxx
