@@ -12,13 +12,14 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-#include <bsoncxx/private/make_unique.hh>
+#include <mongocxx/options/transaction.hh>
+
+//
 
 #include <mongocxx/exception/error_code.hpp>
 #include <mongocxx/exception/logic_error.hpp>
-#include <mongocxx/options/private/transaction.hh>
 
-#include <mongocxx/config/private/prelude.hh>
+#include <bsoncxx/private/make_unique.hh>
 
 namespace mongocxx {
 namespace v_noabi {
@@ -29,43 +30,40 @@ transaction::transaction() : _impl{bsoncxx::make_unique<impl>()} {}
 transaction::transaction(transaction&&) noexcept = default;
 transaction& transaction::operator=(transaction&&) noexcept = default;
 
-transaction::transaction(const transaction& other)
+transaction::transaction(transaction const& other)
     : _impl{bsoncxx::make_unique<impl>(other._get_impl().get_transaction_opt_t())} {}
 
-transaction& transaction::operator=(const transaction& other) {
+transaction& transaction::operator=(transaction const& other) {
     _impl = bsoncxx::make_unique<impl>(other._get_impl().get_transaction_opt_t());
     return *this;
 }
 
 transaction::~transaction() noexcept = default;
 
-transaction& transaction::read_concern(const mongocxx::v_noabi::read_concern& rc) {
+transaction& transaction::read_concern(mongocxx::v_noabi::read_concern const& rc) {
     _impl->read_concern(rc);
     return *this;
 }
 
-bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::read_concern> transaction::read_concern()
-    const {
+bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::read_concern> transaction::read_concern() const {
     return _impl->read_concern();
 }
 
-transaction& transaction::write_concern(const mongocxx::v_noabi::write_concern& wc) {
+transaction& transaction::write_concern(mongocxx::v_noabi::write_concern const& wc) {
     _impl->write_concern(wc);
     return *this;
 }
 
-bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::write_concern> transaction::write_concern()
-    const {
+bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::write_concern> transaction::write_concern() const {
     return _impl->write_concern();
 }
 
-transaction& transaction::read_preference(const mongocxx::v_noabi::read_preference& rp) {
+transaction& transaction::read_preference(mongocxx::v_noabi::read_preference const& rp) {
     _impl->read_preference(rp);
     return *this;
 }
 
-bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::read_preference> transaction::read_preference()
-    const {
+bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::read_preference> transaction::read_preference() const {
     return _impl->read_preference();
 }
 
@@ -74,12 +72,11 @@ transaction& transaction::max_commit_time_ms(std::chrono::milliseconds ms) {
     return *this;
 }
 
-bsoncxx::v_noabi::stdx::optional<std::chrono::milliseconds> transaction::max_commit_time_ms()
-    const {
+bsoncxx::v_noabi::stdx::optional<std::chrono::milliseconds> transaction::max_commit_time_ms() const {
     return _impl->max_commit_time_ms();
 }
 
-const transaction::impl& transaction::_get_impl() const {
+transaction::impl const& transaction::_get_impl() const {
     if (!_impl) {
         throw logic_error{error_code::k_invalid_transaction_options_object};
     }
@@ -87,12 +84,10 @@ const transaction::impl& transaction::_get_impl() const {
 }
 
 transaction::impl& transaction::_get_impl() {
-    auto cthis = const_cast<const transaction*>(this);
+    auto cthis = const_cast<transaction const*>(this);
     return const_cast<transaction::impl&>(cthis->_get_impl());
 }
 
-}  // namespace options
-}  // namespace v_noabi
-}  // namespace mongocxx
-
-#include <mongocxx/config/private/postlude.hh>
+} // namespace options
+} // namespace v_noabi
+} // namespace mongocxx
