@@ -1,4 +1,4 @@
-// Copyright 2015 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -13,32 +13,32 @@
 // limitations under the License.
 
 #include <bsoncxx/builder/basic/document.hpp>
-#include <bsoncxx/stdx/make_unique.hpp>
 #include <bsoncxx/string/to_string.hpp>
+
 #include <mongocxx/exception/error_code.hpp>
 #include <mongocxx/exception/exception.hpp>
-#include <mongocxx/private/libmongoc.hh>
-#include <mongocxx/private/read_concern.hh>
 #include <mongocxx/read_concern.hpp>
 
-#include <mongocxx/config/private/prelude.hh>
+#include <bsoncxx/private/make_unique.hh>
+
+#include <mongocxx/private/mongoc.hh>
+#include <mongocxx/private/read_concern.hh>
 
 namespace mongocxx {
 namespace v_noabi {
 
-read_concern::read_concern() : _impl{stdx::make_unique<impl>(libmongoc::read_concern_new())} {}
+read_concern::read_concern() : _impl{bsoncxx::make_unique<impl>(libmongoc::read_concern_new())} {}
 
-read_concern::read_concern(std::unique_ptr<impl>&& implementation)
-    : _impl{std::move(implementation)} {}
+read_concern::read_concern(std::unique_ptr<impl>&& implementation) : _impl{std::move(implementation)} {}
 
 read_concern::read_concern(read_concern&&) noexcept = default;
 read_concern& read_concern::operator=(read_concern&&) noexcept = default;
 
-read_concern::read_concern(const read_concern& other)
-    : _impl(stdx::make_unique<impl>(libmongoc::read_concern_copy(other._impl->read_concern_t))) {}
+read_concern::read_concern(read_concern const& other)
+    : _impl(bsoncxx::make_unique<impl>(libmongoc::read_concern_copy(other._impl->read_concern_t))) {}
 
-read_concern& read_concern::operator=(const read_concern& other) {
-    _impl = stdx::make_unique<impl>(libmongoc::read_concern_copy(other._impl->read_concern_t));
+read_concern& read_concern::operator=(read_concern const& other) {
+    _impl = bsoncxx::make_unique<impl>(libmongoc::read_concern_copy(other._impl->read_concern_t));
     return *this;
 }
 
@@ -47,39 +47,35 @@ read_concern::~read_concern() = default;
 void read_concern::acknowledge_level(read_concern::level rc_level) {
     switch (rc_level) {
         case read_concern::level::k_local:
-            libmongoc::read_concern_set_level(_impl->read_concern_t,
-                                              MONGOC_READ_CONCERN_LEVEL_LOCAL);
+            libmongoc::read_concern_set_level(_impl->read_concern_t, MONGOC_READ_CONCERN_LEVEL_LOCAL);
             break;
         case read_concern::level::k_majority:
-            libmongoc::read_concern_set_level(_impl->read_concern_t,
-                                              MONGOC_READ_CONCERN_LEVEL_MAJORITY);
+            libmongoc::read_concern_set_level(_impl->read_concern_t, MONGOC_READ_CONCERN_LEVEL_MAJORITY);
             break;
         case read_concern::level::k_linearizable:
-            libmongoc::read_concern_set_level(_impl->read_concern_t,
-                                              MONGOC_READ_CONCERN_LEVEL_LINEARIZABLE);
+            libmongoc::read_concern_set_level(_impl->read_concern_t, MONGOC_READ_CONCERN_LEVEL_LINEARIZABLE);
             break;
         case read_concern::level::k_server_default:
             // libmongoc uses a NULL level to mean "use the server's default read_concern."
-            libmongoc::read_concern_set_level(_impl->read_concern_t, NULL);
+            libmongoc::read_concern_set_level(_impl->read_concern_t, nullptr);
             break;
         case read_concern::level::k_available:
-            libmongoc::read_concern_set_level(_impl->read_concern_t,
-                                              MONGOC_READ_CONCERN_LEVEL_AVAILABLE);
+            libmongoc::read_concern_set_level(_impl->read_concern_t, MONGOC_READ_CONCERN_LEVEL_AVAILABLE);
             break;
         case read_concern::level::k_snapshot:
-            libmongoc::read_concern_set_level(_impl->read_concern_t,
-                                              MONGOC_READ_CONCERN_LEVEL_SNAPSHOT);
+            libmongoc::read_concern_set_level(_impl->read_concern_t, MONGOC_READ_CONCERN_LEVEL_SNAPSHOT);
             break;
+
+        case read_concern::level::k_unknown:
         default:
             throw exception{error_code::k_unknown_read_concern};
     }
 }
 
-void read_concern::acknowledge_string(stdx::string_view rc_string) {
+void read_concern::acknowledge_string(bsoncxx::v_noabi::stdx::string_view rc_string) {
     // libmongoc uses a NULL level to mean "use the server's default read_concern."
     libmongoc::read_concern_set_level(
-        _impl->read_concern_t,
-        rc_string.empty() ? NULL : bsoncxx::v_noabi::string::to_string(rc_string).data());
+        _impl->read_concern_t, rc_string.empty() ? nullptr : bsoncxx::v_noabi::string::to_string(rc_string).data());
 }
 
 read_concern::level read_concern::acknowledge_level() const {
@@ -102,12 +98,12 @@ read_concern::level read_concern::acknowledge_level() const {
     }
 }
 
-stdx::string_view read_concern::acknowledge_string() const {
+bsoncxx::v_noabi::stdx::string_view read_concern::acknowledge_string() const {
     auto level = libmongoc::read_concern_get_level(_impl->read_concern_t);
     if (!level) {
         return "";
     }
-    return {stdx::string_view{level}};
+    return {bsoncxx::v_noabi::stdx::string_view{level}};
 }
 
 bsoncxx::v_noabi::document::value read_concern::to_document() const {
@@ -118,18 +114,18 @@ bsoncxx::v_noabi::document::value read_concern::to_document() const {
     bsoncxx::v_noabi::builder::basic::document doc;
     if (level) {
         doc.append(kvp("level", level));
-    };
+    }
 
     return doc.extract();
 }
 
-bool MONGOCXX_CALL operator==(const read_concern& lhs, const read_concern& rhs) {
+bool operator==(read_concern const& lhs, read_concern const& rhs) {
     return lhs.acknowledge_level() == rhs.acknowledge_level();
 }
 
-bool MONGOCXX_CALL operator!=(const read_concern& lhs, const read_concern& rhs) {
+bool operator!=(read_concern const& lhs, read_concern const& rhs) {
     return !(lhs == rhs);
 }
 
-}  // namespace v_noabi
-}  // namespace mongocxx
+} // namespace v_noabi
+} // namespace mongocxx
