@@ -1,4 +1,4 @@
-// Copyright 2014 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -14,15 +14,13 @@
 
 #include <mongocxx/result/replace_one.hpp>
 
-#include <mongocxx/config/private/prelude.hh>
-
 namespace mongocxx {
 namespace v_noabi {
 namespace result {
 
 replace_one::replace_one(result::bulk_write result) : _result(std::move(result)) {}
 
-const result::bulk_write& replace_one::result() const {
+result::bulk_write const& replace_one::result() const {
     return _result;
 }
 
@@ -34,20 +32,20 @@ std::int32_t replace_one::modified_count() const {
     return _result.modified_count();
 }
 
-stdx::optional<bsoncxx::v_noabi::document::element> replace_one::upserted_id() const {
+bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::element> replace_one::upserted_id() const {
     if (_result.upserted_ids().size() == 0) {
-        return stdx::nullopt;
+        return bsoncxx::v_noabi::stdx::nullopt;
     }
     return _result.upserted_ids()[0];
 }
 
-bool MONGOCXX_CALL operator==(const replace_one& lhs, const replace_one& rhs) {
+bool operator==(replace_one const& lhs, replace_one const& rhs) {
     return lhs.result() == rhs.result();
 }
-bool MONGOCXX_CALL operator!=(const replace_one& lhs, const replace_one& rhs) {
+bool operator!=(replace_one const& lhs, replace_one const& rhs) {
     return !(lhs == rhs);
 }
 
-}  // namespace result
-}  // namespace v_noabi
-}  // namespace mongocxx
+} // namespace result
+} // namespace v_noabi
+} // namespace mongocxx
