@@ -35,11 +35,9 @@
 #include <mongocxx/exception/error_code.hpp>
 #include <mongocxx/exception/logic_error.hpp>
 #include <mongocxx/exception/operation_exception.hpp>
-#include <mongocxx/private/libmongoc.hh>
 
-#include <bsoncxx/config/prelude.hpp>
-
-#include <mongocxx/config/private/prelude.hh>
+#include <mongocxx/private/config/config.hh>
+#include <mongocxx/private/mongoc.hh>
 
 #include <bsoncxx/test/catch.hh>
 
@@ -57,21 +55,30 @@ using bsoncxx::builder::basic::make_document;
 
 namespace {
 // These frequently used network calls are cached to avoid bottlenecks during tests.
-document::value get_is_master(const client& client) {
-    static auto reply = client["admin"].run_command(make_document(kvp("isMaster", 1)));
+document::value get_is_master() {
+    static auto reply = []() {
+        auto client = mongocxx::client{mongocxx::uri{}, test_util::add_test_server_api()};
+        return client["admin"].run_command(make_document(kvp("isMaster", 1)));
+    }();
     return reply;
 }
 
-document::value get_server_status(const client& client) {
-    static auto status = client["admin"].run_command(make_document(kvp("serverStatus", 1)));
+document::value get_server_status() {
+    static auto status = []() {
+        auto client = mongocxx::client{mongocxx::uri{}, test_util::add_test_server_api()};
+        return client["admin"].run_command(make_document(kvp("serverStatus", 1)));
+    }();
     return status;
 }
 
-bsoncxx::stdx::optional<document::value> get_shards(const client& client) {
-    static auto shards = client["config"]["shards"].find_one({});
+bsoncxx::stdx::optional<document::value> get_shards() {
+    static auto shards = []() {
+        auto client = mongocxx::client{mongocxx::uri{}, test_util::add_test_server_api()};
+        return client["config"]["shards"].find_one({});
+    }();
     return (shards) ? shards.value() : bsoncxx::stdx::optional<document::value>{};
 }
-}  // namespace
+} // namespace
 
 std::vector<std::int32_t> parse_version(std::string version) {
     std::vector<std::int32_t> elements;
@@ -85,13 +92,13 @@ std::vector<std::int32_t> parse_version(std::string version) {
     return elements;
 }
 
-bsoncxx::document::value transform_document_recursive(bsoncxx::document::view view,
-                                                      const xformer_t& fcn,
-                                                      bsoncxx::builder::basic::array* context);
+bsoncxx::document::value transform_document_recursive(
+    bsoncxx::document::view view,
+    xformer_t const& fcn,
+    bsoncxx::builder::basic::array* context);
 
-bsoncxx::array::value transform_array(bsoncxx::array::view view,
-                                      const xformer_t& fcn,
-                                      bsoncxx::builder::basic::array* context) {
+bsoncxx::array::value
+transform_array(bsoncxx::array::view view, xformer_t const& fcn, bsoncxx::builder::basic::array* context) {
     bsoncxx::builder::basic::array builder;
 
     for (auto&& element : view) {
@@ -144,9 +151,10 @@ bsoncxx::array::value transform_array(bsoncxx::array::view view,
     return builder.extract();
 }
 
-bsoncxx::document::value transform_document_recursive(bsoncxx::document::view view,
-                                                      const xformer_t& fcn,
-                                                      bsoncxx::builder::basic::array* context) {
+bsoncxx::document::value transform_document_recursive(
+    bsoncxx::document::view view,
+    xformer_t const& fcn,
+    bsoncxx::builder::basic::array* context) {
     bsoncxx::builder::basic::document builder;
 
     for (auto&& element : view) {
@@ -174,8 +182,7 @@ bsoncxx::document::value transform_document_recursive(bsoncxx::document::view vi
                 break;
 
             case bsoncxx::type::k_array:
-                builder.append(bsoncxx::builder::basic::kvp(
-                    k, transform_array(v.get_array().value, fcn, context)));
+                builder.append(bsoncxx::builder::basic::kvp(k, transform_array(v.get_array().value, fcn, context)));
                 break;
 
             case bsoncxx::type::k_double:
@@ -206,7 +213,7 @@ bsoncxx::document::value transform_document_recursive(bsoncxx::document::view vi
     return builder.extract();
 }
 
-}  // namespace
+} // namespace
 
 std::int32_t compare_versions(std::string version1, std::string version2) {
     std::vector<std::int32_t> v1 = parse_version(version1);
@@ -223,8 +230,8 @@ std::int32_t compare_versions(std::string version1, std::string version2) {
     return 0;
 }
 
-bool newer_than(const client& client, std::string version) {
-    auto server_version = get_server_version(client);
+bool newer_than(std::string version) {
+    auto server_version = get_server_version();
     return (compare_versions(server_version, version) >= 0);
 }
 
@@ -234,8 +241,7 @@ std::basic_string<std::uint8_t> convert_hex_string_to_bytes(bsoncxx::stdx::strin
     // Convert each pair of hexadecimal digits into a number and store it in the array.
     for (std::size_t i = 0; i < hex.size(); i += 2) {
         bsoncxx::stdx::string_view sub = hex.substr(i, 2);
-        bytes.push_back(
-            static_cast<std::uint8_t>(std::stoi(bsoncxx::string::to_string(sub), nullptr, 16)));
+        bytes.push_back(static_cast<std::uint8_t>(std::stoi(bsoncxx::string::to_string(sub), nullptr, 16)));
     }
 
     return bytes;
@@ -251,8 +257,8 @@ options::client add_test_server_api(options::client opts) {
     return opts;
 }
 
-std::int32_t get_max_wire_version(const client& client) {
-    auto reply = get_is_master(client);
+std::int32_t get_max_wire_version() {
+    auto reply = get_is_master();
     auto max_wire_version = reply.view()["maxWireVersion"];
     if (!max_wire_version) {
         // If wire version is not available (i.e. server version too old), it is assumed to be
@@ -265,18 +271,23 @@ std::int32_t get_max_wire_version(const client& client) {
     return max_wire_version.get_int32().value;
 }
 
-std::string get_server_version(const client& client) {
-    auto output = get_server_status(client);
+std::string get_server_version() {
+    auto output = get_server_status();
     return bsoncxx::string::to_string(output.view()["version"].get_string().value);
 }
 
-document::value get_server_params(const client& client) {
-    auto reply = client["admin"].run_command(make_document(kvp("getParameter", "*")));
+document::value get_server_params() {
+    // Cache reply.
+    static auto reply = []() {
+        auto client = mongocxx::client{mongocxx::uri{}, test_util::add_test_server_api()};
+        return client["admin"].run_command(make_document(kvp("getParameter", "*")));
+    }();
+
     return reply;
 }
 
-std::string replica_set_name(const client& client) {
-    auto reply = get_is_master(client);
+std::string replica_set_name() {
+    auto reply = get_is_master();
     auto name = reply.view()["setName"];
     if (name) {
         return bsoncxx::string::to_string(name.get_string().value);
@@ -289,12 +300,12 @@ static bool is_replica_set(document::view reply) {
     return static_cast<bool>(reply["setName"]);
 }
 
-bool is_replica_set(const client& client) {
-    return is_replica_set(get_is_master(client));
+bool is_replica_set() {
+    return is_replica_set(get_is_master());
 }
 
 static bool is_sharded_cluster(document::view reply) {
-    const auto msg = reply["msg"];
+    auto const msg = reply["msg"];
 
     if (!msg) {
         return false;
@@ -303,19 +314,19 @@ static bool is_sharded_cluster(document::view reply) {
     return msg.get_string().value == "isdbgrid";
 }
 
-bool is_sharded_cluster(const client& client) {
-    return is_sharded_cluster(get_is_master(client));
+bool is_sharded_cluster() {
+    return is_sharded_cluster(get_is_master());
 }
 
-std::string get_hosts(const client& client) {
-    auto shards = get_shards(client);
+std::string get_hosts() {
+    auto shards = get_shards();
     if (shards)
         return string::to_string(shards->view()["host"].get_string().value);
     return "";
 }
 
-std::string get_topology(const client& client) {
-    const auto reply = get_is_master(client);
+std::string get_topology() {
+    auto const reply = get_is_master();
 
     if (is_replica_set(reply)) {
         return "replicaset";
@@ -333,14 +344,14 @@ bsoncxx::stdx::optional<bsoncxx::document::value> parse_test_file(std::string pa
     std::ifstream test_file{path};
 
     if (test_file.bad()) {
-        return {};
+        return bsoncxx::v_noabi::stdx::nullopt;
     }
 
     stream << test_file.rdbuf();
     return bsoncxx::from_json(stream.str());
 }
 
-bsoncxx::document::value transform_document(bsoncxx::document::view view, const xformer_t& fcn) {
+bsoncxx::document::value transform_document(bsoncxx::document::view view, xformer_t const& fcn) {
     bsoncxx::builder::basic::array context;
 
     return transform_document_recursive(view, fcn, &context);
@@ -357,13 +368,11 @@ double as_double(bsoncxx::types::bson_value::view value) {
         return static_cast<double>(value.get_double());
     }
 
-    throw std::logic_error{"could not convert type " + bsoncxx::to_string(value.type()) +
-                           " to double"};
+    throw std::logic_error{"could not convert type " + bsoncxx::to_string(value.type()) + " to double"};
 }
 
 bool is_numeric(types::bson_value::view value) {
-    return value.type() == type::k_int32 || value.type() == type::k_int64 ||
-           value.type() == type::k_double;
+    return value.type() == type::k_int32 || value.type() == type::k_int64 || value.type() == type::k_double;
 }
 
 static bsoncxx::stdx::optional<type> is_type_operator(types::bson_value::view value) {
@@ -376,18 +385,16 @@ static bsoncxx::stdx::optional<type> is_type_operator(types::bson_value::view va
         }
         throw std::logic_error{"unsupported type for $$type"};
     }
-    return {};
+    return bsoncxx::v_noabi::stdx::nullopt;
 }
 
-bool matches(types::bson_value::view main,
-             types::bson_value::view pattern,
-             match_visitor visitor_fn) {
+bool matches(types::bson_value::view main, types::bson_value::view pattern, match_visitor visitor_fn) {
     if (auto t = is_type_operator(pattern)) {
         return t == main.type();
     }
 
-    BSONCXX_PUSH_WARNINGS();
-    BSONCXX_DISABLE_WARNING(GNU("-Wfloat-equal"));
+    BSONCXX_PRIVATE_WARNINGS_PUSH();
+    BSONCXX_PRIVATE_WARNINGS_DISABLE(GNU("-Wfloat-equal"));
 
     if (is_numeric(pattern) && as_double(pattern) == 42.0) {
         return true;
@@ -398,7 +405,7 @@ bool matches(types::bson_value::view main,
         return true;
     }
 
-    BSONCXX_POP_WARNINGS();
+    BSONCXX_PRIVATE_WARNINGS_POP();
 
     if (main.type() == type::k_document) {
         // the value '42' acts as placeholders for "any value"
@@ -471,9 +478,10 @@ bool matches(types::bson_value::view main,
 }
 
 bool matches(document::view doc, document::view pattern, match_visitor visitor_fn) {
-    return matches(types::bson_value::view{types::b_document{doc}},
-                   types::bson_value::view{types::b_document{pattern}},
-                   visitor_fn);
+    return matches(
+        types::bson_value::view{types::b_document{doc}},
+        types::bson_value::view{types::b_document{pattern}},
+        visitor_fn);
 }
 
 std::string tolowercase(bsoncxx::stdx::string_view view) {
@@ -520,21 +528,22 @@ void check_outcome_collection(mongocxx::collection* coll, bsoncxx::document::vie
 
     using namespace std;
 
-    const auto expected_data = expected["data"].get_array().value;
+    auto const expected_data = expected["data"].get_array().value;
     auto actual = coll->find({}, options::find().sort(make_document(kvp("_id", 1))));
 
-    REQUIRE(equal(begin(expected_data),
-                  end(expected_data),
-                  begin(actual),
-                  [&](const bsoncxx::array::element& ele, const document::view& doc) {
-                      REQUIRE_BSON_MATCHES(doc, ele.get_document().value);
-                      return true;
-                  }));
+    REQUIRE(equal(
+        begin(expected_data),
+        end(expected_data),
+        begin(actual),
+        [&](bsoncxx::array::element const& ele, document::view const& doc) {
+            REQUIRE_BSON_MATCHES(doc, ele.get_document().value);
+            return true;
+        }));
     REQUIRE(begin(actual) == end(actual));
 }
 
-bool server_has_sessions_impl(const client& conn) {
-    auto result = get_is_master(conn);
+bool server_has_sessions_impl() {
+    auto result = get_is_master();
     auto result_view = result.view();
 
     if (result_view["logicalSessionTimeoutMinutes"]) {
@@ -547,8 +556,8 @@ bool server_has_sessions_impl(const client& conn) {
 #if defined(MONGOC_ENABLE_CLIENT_SIDE_ENCRYPTION)
 
 cseeos_result client_side_encryption_enabled_or_skip_impl() {
-    static const cseeos_result result = [] {
-        std::vector<const char*> vars{
+    static cseeos_result const result = [] {
+        std::vector<char const*> vars{
             "MONGOCXX_TEST_AWS_SECRET_ACCESS_KEY",
             "MONGOCXX_TEST_AWS_ACCESS_KEY_ID",
             "MONGOCXX_TEST_AZURE_TENANT_ID",
@@ -560,9 +569,9 @@ cseeos_result client_side_encryption_enabled_or_skip_impl() {
             "MONGOCXX_TEST_GCP_PRIVATEKEY",
         };
 
-        const auto is_set = [](const char* var) -> bool { return std::getenv(var) != nullptr; };
+        auto const is_set = [](char const* var) -> bool { return std::getenv(var) != nullptr; };
 
-        const auto count = std::count_if(vars.begin(), vars.end(), is_set);
+        auto const count = std::count_if(vars.begin(), vars.end(), is_set);
 
         if (count == 0) {
             return cseeos_result::skip;
@@ -578,7 +587,7 @@ cseeos_result client_side_encryption_enabled_or_skip_impl() {
     return result;
 }
 
-#endif  // defined(MONGOC_ENABLE_CLIENT_SIDE_ENCRYPTION)
+#endif // defined(MONGOC_ENABLE_CLIENT_SIDE_ENCRYPTION)
 
 std::string getenv_or_fail(const std::string env_name) {
     auto val = std::getenv(env_name.c_str());
@@ -588,5 +597,5 @@ std::string getenv_or_fail(const std::string env_name) {
     return val;
 }
 
-}  // namespace test_util
-}  // namespace mongocxx
+} // namespace test_util
+} // namespace mongocxx
