@@ -14,15 +14,16 @@
 
 #include <sstream>
 
-#include <bsoncxx/private/helpers.hh>
-#include <bsoncxx/private/make_unique.hh>
-
 #include <mongocxx/client.hpp>
 #include <mongocxx/exception/bulk_write_exception.hpp>
 #include <mongocxx/exception/logic_error.hpp>
 #include <mongocxx/exception/server_error_code.hpp>
 #include <mongocxx/instance.hpp>
-#include <mongocxx/private/libmongoc.hh>
+
+#include <bsoncxx/private/helpers.hh>
+#include <bsoncxx/private/make_unique.hh>
+
+#include <mongocxx/private/mongoc.hh>
 
 #include <bsoncxx/test/catch.hh>
 
@@ -45,7 +46,7 @@ TEST_CASE("session options", "[session]") {
 
     client c{uri{}, test_util::add_test_server_api()};
 
-    SERVER_HAS_SESSIONS_OR_SKIP(c);
+    SERVER_HAS_SESSIONS_OR_SKIP();
 
     SECTION("default") {
         // Make sure the defaults don't cause a client exception:
@@ -128,14 +129,10 @@ TEST_CASE("session options", "[session]") {
         // an enumeration:
         enum struct optional_state { empty, no, yes };
 
-        auto causal_consistenty_opt = GENERATE(Catch::Generators::as<optional_state>{},
-                                               optional_state::empty,
-                                               optional_state::no,
-                                               optional_state::yes);
-        auto snapshot_consistenty_opt = GENERATE(Catch::Generators::as<optional_state>{},
-                                                 optional_state::empty,
-                                                 optional_state::no,
-                                                 optional_state::yes);
+        auto causal_consistenty_opt = GENERATE(
+            Catch::Generators::as<optional_state>{}, optional_state::empty, optional_state::no, optional_state::yes);
+        auto snapshot_consistenty_opt = GENERATE(
+            Catch::Generators::as<optional_state>{}, optional_state::empty, optional_state::no, optional_state::yes);
 
         // Only actually set a value if we generate a non-empty setting:
         if (optional_state::empty != causal_consistenty_opt)
@@ -145,8 +142,7 @@ TEST_CASE("session options", "[session]") {
             opts.snapshot(optional_state::yes == snapshot_consistenty_opt);
 
         // We should always expect an error if both are enabled:
-        if (optional_state::yes == causal_consistenty_opt &&
-            optional_state::yes == snapshot_consistenty_opt) {
+        if (optional_state::yes == causal_consistenty_opt && optional_state::yes == snapshot_consistenty_opt) {
             REQUIRE_THROWS_AS(c.start_session(opts), mongocxx::exception);
         } else {
             CHECK_NOTHROW(c.start_session(opts));
@@ -162,9 +158,7 @@ TEST_CASE("start_session failure", "[session]") {
     instance::current();
 
     client_start_session
-        ->interpose([](mongoc_client_t*,
-                       const mongoc_session_opt_t*,
-                       bson_error_t* error) -> mongoc_client_session_t* {
+        ->interpose([](mongoc_client_t*, mongoc_session_opt_t const*, bson_error_t* error) -> mongoc_client_session_t* {
             bson_set_error(error, MONGOC_ERROR_CLIENT, MONGOC_ERROR_CLIENT_SESSION_FAILURE, "foo");
             return nullptr;
         })
@@ -172,8 +166,7 @@ TEST_CASE("start_session failure", "[session]") {
 
     client c{uri{}, test_util::add_test_server_api()};
 
-    REQUIRE_THROWS_MATCHES(
-        c.start_session(), mongocxx::exception, mongocxx_exception_matcher{"foo"});
+    REQUIRE_THROWS_MATCHES(c.start_session(), mongocxx::exception, mongocxx_exception_matcher{"foo"});
 }
 
 TEST_CASE("session", "[session]") {
@@ -183,7 +176,7 @@ TEST_CASE("session", "[session]") {
 
     client c{uri{}, test_util::add_test_server_api()};
 
-    SERVER_HAS_SESSIONS_OR_SKIP(c);
+    SERVER_HAS_SESSIONS_OR_SKIP();
 
     auto s = c.start_session();
 
@@ -203,8 +196,7 @@ TEST_CASE("session", "[session]") {
         REQUIRE(s.operation_time() == zero);
 
         // Advance the cluster time - just a basic test, rely on libmongoc's logic.
-        s.advance_cluster_time(
-            from_json("{\"clusterTime\": {\"$timestamp\": {\"t\": 1, \"i\": 0}}}"));
+        s.advance_cluster_time(from_json("{\"clusterTime\": {\"$timestamp\": {\"t\": 1, \"i\": 0}}}"));
         REQUIRE(!s.cluster_time().empty());
         REQUIRE(s.operation_time() == zero);
 
@@ -241,8 +233,7 @@ TEST_CASE("session", "[session]") {
         auto collection2 = db2["collection"];
 
 #define REQUIRE_THROWS_INVALID_SESSION(_expr) \
-    REQUIRE_THROWS_MATCHES(                   \
-        (_expr), mongocxx::exception, mongocxx_exception_matcher{"Invalid sessionId"})
+    REQUIRE_THROWS_MATCHES((_expr), mongocxx::exception, mongocxx_exception_matcher{"Invalid sessionId"})
 
         REQUIRE_THROWS_INVALID_SESSION(collection2.count_documents(s, {}));
         REQUIRE_THROWS_INVALID_SESSION(collection2.create_index(s, make_document(kvp("a", 1))));
@@ -314,7 +305,7 @@ class session_test {
         options::client client_opts;
         options::apm apm_opts;
 
-        apm_opts.on_command_started([&](const events::command_started_event& event) {
+        apm_opts.on_command_started([&](events::command_started_event const& event) {
             std::string command_name{event.command_name().data()};
 
             // Ignore auth commands like "saslStart", and handshakes with "hello" (and the legacy
@@ -332,7 +323,7 @@ class session_test {
         client = mongocxx::client(uri{}, test_util::add_test_server_api(client_opts));
     }
 
-    void test_method_with_session(const std::function<void(bool)>& f, const client_session& s) {
+    void test_method_with_session(std::function<void(bool)> const& f, client_session const& s) {
         using std::string;
 
         events.clear();
@@ -346,12 +337,10 @@ class session_test {
 
         for (auto& event : events) {
             if (!event.command["lsid"]) {
-                throw std::logic_error{"no lsid in " + event.command_name +
-                                       " with explicit session"};
+                throw std::logic_error{"no lsid in " + event.command_name + " with explicit session"};
             }
             if (event.command["lsid"].get_document().view() != s.id()) {
-                throw std::logic_error{"wrong lsid in " + event.command_name +
-                                       " with explicit session"};
+                throw std::logic_error{"wrong lsid in " + event.command_name + " with explicit session"};
             }
         }
 
@@ -366,19 +355,17 @@ class session_test {
 
         for (auto& event : events) {
             if (!event.command["lsid"]) {
-                throw std::logic_error{"no lsid in " + event.command_name +
-                                       " with implicit session"};
+                throw std::logic_error{"no lsid in " + event.command_name + " with implicit session"};
             }
             if (event.command["lsid"].get_document().view() == s.id()) {
-                throw std::logic_error{"wrong lsid in " + event.command_name +
-                                       " with implicit session"};
+                throw std::logic_error{"wrong lsid in " + event.command_name + " with implicit session"};
             }
         }
     }
 
     class apm_event {
        public:
-        apm_event(const std::string& command_name_, const bsoncxx::document::value& document_)
+        apm_event(std::string const& command_name_, bsoncxx::document::value const& document_)
             : command_name(command_name_), value(document_), command(value.view()) {}
 
         std::string command_name;
@@ -395,7 +382,7 @@ TEST_CASE("lsid", "[session]") {
 
     session_test test;
 
-    SERVER_HAS_SESSIONS_OR_SKIP(test.client);
+    SERVER_HAS_SESSIONS_OR_SKIP();
 
     auto s = test.client.start_session();
     auto db = test.client["lsid"];
@@ -417,14 +404,14 @@ TEST_CASE("lsid", "[session]") {
 
             auto one = bsoncxx::types::bson_value::view{bsoncxx::types::b_int32{1}};
             auto two = bsoncxx::types::bson_value::view{bsoncxx::types::b_int32{2}};
-            auto data = reinterpret_cast<const uint8_t*>("foo");
+            auto data = reinterpret_cast<uint8_t const*>("foo");
             size_t len = 4;
             // Ensure multiple chunks.
             options::gridfs::upload opts;
             opts.chunk_size_bytes(1);
 
-            auto up = use_session ? bucket.open_upload_stream(s, "file", opts)
-                                  : bucket.open_upload_stream("file", opts);
+            auto up =
+                use_session ? bucket.open_upload_stream(s, "file", opts) : bucket.open_upload_stream("file", opts);
             up.write(data, len);
             up.close();
 
@@ -444,10 +431,8 @@ TEST_CASE("lsid", "[session]") {
             use_session ? bucket.upload_from_stream_with_id(s, two, "file", &stream, opts)
                         : bucket.upload_from_stream_with_id(two, "file", &stream, opts);
 
-            auto down = use_session ? bucket.open_download_stream(s, two)
-                                    : bucket.open_download_stream(two);
-            use_session ? bucket.download_to_stream(s, two, &stream)
-                        : bucket.download_to_stream(two, &stream);
+            auto down = use_session ? bucket.open_download_stream(s, two) : bucket.open_download_stream(two);
+            use_session ? bucket.download_to_stream(s, two, &stream) : bucket.download_to_stream(two, &stream);
 
             auto cursor = use_session ? bucket.find(s, {}) : bucket.find({});
             auto total = std::distance(cursor.begin(), cursor.end());
@@ -461,8 +446,7 @@ TEST_CASE("lsid", "[session]") {
 
     SECTION("client::list_databases") {
         auto f = [&s, &test](bool use_session) {
-            auto cursor =
-                use_session ? test.client.list_databases(s) : test.client.list_databases();
+            auto cursor = use_session ? test.client.list_databases(s) : test.client.list_databases();
             auto total = std::distance(cursor.begin(), cursor.end());
 
             REQUIRE(total > 0);
@@ -475,8 +459,7 @@ TEST_CASE("lsid", "[session]") {
         auto f = [&s, &collection](bool use_session) {
             options::aggregate opts;
             opts.batch_size(2);
-            auto cursor =
-                use_session ? collection.aggregate(s, {}, opts) : collection.aggregate({}, opts);
+            auto cursor = use_session ? collection.aggregate(s, {}, opts) : collection.aggregate({}, opts);
             auto total = std::distance(cursor.begin(), cursor.end());
 
             REQUIRE(total == 10);
@@ -506,8 +489,7 @@ TEST_CASE("lsid", "[session]") {
 
     SECTION("collection::count") {
         auto f = [&s, &collection](bool use_session) {
-            auto total =
-                use_session ? collection.count_documents(s, {}) : collection.count_documents({});
+            auto total = use_session ? collection.count_documents(s, {}) : collection.count_documents({});
             REQUIRE(total == 10);
         };
 
@@ -516,8 +498,7 @@ TEST_CASE("lsid", "[session]") {
 
     SECTION("collection::create_bulk_write") {
         auto f = [&s, &collection](bool use_session) {
-            auto bulk =
-                use_session ? collection.create_bulk_write(s) : collection.create_bulk_write();
+            auto bulk = use_session ? collection.create_bulk_write(s) : collection.create_bulk_write();
 
             bulk.append(model::insert_one{{}});
             bulk.execute();
@@ -589,8 +570,7 @@ TEST_CASE("lsid", "[session]") {
 
     SECTION("collection::find_one_and_delete") {
         auto f = [&s, &collection](bool use_session) {
-            use_session ? collection.find_one_and_delete(s, {})
-                        : collection.find_one_and_delete({});
+            use_session ? collection.find_one_and_delete(s, {}) : collection.find_one_and_delete({});
         };
 
         test.test_method_with_session(f, s);
@@ -598,8 +578,7 @@ TEST_CASE("lsid", "[session]") {
 
     SECTION("collection::find_one_and_replace") {
         auto f = [&s, &collection](bool use_session) {
-            use_session ? collection.find_one_and_replace(s, {}, {})
-                        : collection.find_one_and_replace({}, {});
+            use_session ? collection.find_one_and_replace(s, {}, {}) : collection.find_one_and_replace({}, {});
         };
 
         test.test_method_with_session(f, s);
@@ -607,8 +586,7 @@ TEST_CASE("lsid", "[session]") {
 
     SECTION("collection::find_one_and_update") {
         auto f = [&s, &collection](bool use_session) {
-            use_session ? collection.find_one_and_update(s, {}, {})
-                        : collection.find_one_and_update({}, {});
+            use_session ? collection.find_one_and_update(s, {}, {}) : collection.find_one_and_update({}, {});
         };
 
         test.test_method_with_session(f, s);
@@ -675,8 +653,7 @@ TEST_CASE("lsid", "[session]") {
     SECTION("collection::update_many") {
         auto f = [&s, &collection](bool use_session) {
             auto u = make_document(kvp("$set", make_document(kvp("a", 1))));
-            use_session ? collection.update_many(s, {}, u.view())
-                        : collection.update_many({}, u.view());
+            use_session ? collection.update_many(s, {}, u.view()) : collection.update_many({}, u.view());
         };
 
         test.test_method_with_session(f, s);
@@ -685,15 +662,14 @@ TEST_CASE("lsid", "[session]") {
     SECTION("collection::update_one") {
         auto f = [&s, &collection](bool use_session) {
             auto u = make_document(kvp("$set", make_document(kvp("a", 1))));
-            use_session ? collection.update_one(s, {}, u.view())
-                        : collection.update_one({}, u.view());
+            use_session ? collection.update_one(s, {}, u.view()) : collection.update_one({}, u.view());
         };
 
         test.test_method_with_session(f, s);
     }
 
     SECTION("collection::watch") {
-        if (!test_util::is_replica_set(test.client)) {
+        if (!test_util::is_replica_set()) {
             SKIP("watch() requires replica set");
         }
 
@@ -789,8 +765,8 @@ TEST_CASE("lsid", "[session]") {
 
     SECTION("index_view::create_many") {
         auto f = [&s, &indexes](bool use_session) {
-            auto models = std::vector<index_model>{index_model{make_document(kvp("a", 1))},
-                                                   index_model{make_document(kvp("b", 1))}};
+            auto models = std::vector<index_model>{
+                index_model{make_document(kvp("a", 1))}, index_model{make_document(kvp("b", 1))}};
 
             use_session ? indexes.create_many(s, models) : indexes.create_many(models);
         };
@@ -801,8 +777,7 @@ TEST_CASE("lsid", "[session]") {
     SECTION("index_view::drop_one") {
         auto drop_by_name = [&s, &indexes](bool use_session) {
             auto keys = make_document(kvp("a", 1));
-            auto name =
-                use_session ? indexes.create_one(s, keys.view()) : indexes.create_one(keys.view());
+            auto name = use_session ? indexes.create_one(s, keys.view()) : indexes.create_one(keys.view());
             use_session ? indexes.drop_one(s, name.value()) : indexes.drop_one(name.value());
         };
 
@@ -827,9 +802,7 @@ TEST_CASE("lsid", "[session]") {
     }
 
     SECTION("index_view::drop_all") {
-        auto f = [&s, &indexes](bool use_session) {
-            use_session ? indexes.drop_all(s) : indexes.drop_all();
-        };
+        auto f = [&s, &indexes](bool use_session) { use_session ? indexes.drop_all(s) : indexes.drop_all(); };
 
         test.test_method_with_session(f, s);
     }
@@ -842,7 +815,7 @@ TEST_CASE("with_transaction", "[session]") {
 
     session_test test;
 
-    SERVER_HAS_SESSIONS_OR_SKIP(test.client);
+    SERVER_HAS_SESSIONS_OR_SKIP();
 
     auto session = test.client.start_session();
 
@@ -850,21 +823,19 @@ TEST_CASE("with_transaction", "[session]") {
     SECTION("prose tests for with_transaction") {
         SECTION("callback raises a custom error") {
             // Multi-document transactions require server 4.2+.
-            if (compare_versions(get_server_version(test.client), "4.2") < 0) {
+            if (compare_versions(get_server_version(), "4.2") < 0) {
                 SKIP("MongoDB server 4.2 or newer required");
             }
 
             // Test an operation_exception
-            REQUIRE_THROWS_MATCHES(session.with_transaction([](client_session*) {
-                throw operation_exception{{}, "The meaning of life"};
-            }),
-                                   operation_exception,
-                                   mongocxx_exception_matcher{"The meaning of life"});
+            REQUIRE_THROWS_MATCHES(
+                session.with_transaction([](client_session*) { throw operation_exception{{}, "The meaning of life"}; }),
+                operation_exception,
+                mongocxx_exception_matcher{"The meaning of life"});
 
             // Test a different exception
-            REQUIRE_THROWS_AS(session.with_transaction(
-                                  [](client_session*) { throw std::logic_error{"it's 42"}; }),
-                              std::logic_error);
+            REQUIRE_THROWS_AS(
+                session.with_transaction([](client_session*) { throw std::logic_error{"it's 42"}; }), std::logic_error);
         }
 
         SECTION("callback returns a value") {
@@ -876,7 +847,7 @@ TEST_CASE("with_transaction", "[session]") {
             // expose the mock timeout mechanism that allows this to be tested without
             // performing long sleeps.
         }
-    }  // End prose tests.
+    } // End prose tests.
 }
 
 TEST_CASE("unacknowledged write in session", "[session]") {
@@ -886,7 +857,7 @@ TEST_CASE("unacknowledged write in session", "[session]") {
 
     session_test test;
 
-    SERVER_HAS_SESSIONS_OR_SKIP(test.client);
+    SERVER_HAS_SESSIONS_OR_SKIP();
 
     auto s = test.client.start_session();
     auto db = test.client["lsid"];
@@ -903,4 +874,4 @@ TEST_CASE("unacknowledged write in session", "[session]") {
             mongocxx_exception_matcher{"Cannot use client session with unacknowledged writes"});
     }
 }
-}  // namespace
+} // namespace
