@@ -24,9 +24,10 @@
 #include <mongocxx/index_view.hpp>
 #include <mongocxx/instance.hpp>
 #include <mongocxx/options/index_view.hpp>
+
+#include <mongocxx/private/bson.hh>
 #include <mongocxx/private/conversions.hh>
-#include <mongocxx/private/libbson.hh>
-#include <mongocxx/private/libmongoc.hh>
+#include <mongocxx/private/mongoc.hh>
 
 #include <bsoncxx/test/catch.hh>
 
@@ -141,7 +142,7 @@ TEST_CASE("A database", "[database]") {
 
     SECTION("is created by a client") {
         bool called = false;
-        get_database->interpose([&](mongoc_client_t*, const char* d_name) {
+        get_database->interpose([&](mongoc_client_t*, char const* d_name) {
             called = true;
             REQUIRE(database_name == bsoncxx::stdx::string_view{d_name});
             return nullptr;
@@ -167,14 +168,10 @@ TEST_CASE("A database", "[database]") {
     }
 
     SECTION("throws an exception when has_collection causes an error") {
-        database_has_collection->interpose(
-            [](mongoc_database_t*, const char*, bson_error_t* error) {
-                bson_set_error(error,
-                               MONGOC_ERROR_COMMAND,
-                               MONGOC_ERROR_COMMAND_INVALID_ARG,
-                               "expected error from mock");
-                return false;
-            });
+        database_has_collection->interpose([](mongoc_database_t*, char const*, bson_error_t* error) {
+            bson_set_error(error, MONGOC_ERROR_COMMAND, MONGOC_ERROR_COMMAND_INVALID_ARG, "expected error from mock");
+            return false;
+        });
         database database = mongo_client["database"];
         REQUIRE_THROWS(database.has_collection("some_collection"));
     }
@@ -203,9 +200,9 @@ TEST_CASE("A database", "[database]") {
         rc.acknowledge_level(read_concern::level::k_majority);
 
         database_set_read_concern->interpose(
-            [&database_set_rc_called](::mongoc_database_t*, const ::mongoc_read_concern_t* rc_t) {
+            [&database_set_rc_called](::mongoc_database_t*, ::mongoc_read_concern_t const* rc_t) {
                 REQUIRE(rc_t);
-                const auto result = libmongoc::read_concern_get_level(rc_t);
+                auto const result = libmongoc::read_concern_get_level(rc_t);
                 REQUIRE(result);
                 REQUIRE(strcmp(result, "majority") == 0);
                 database_set_rc_called = true;
@@ -227,24 +224,20 @@ TEST_CASE("A database", "[database]") {
         std::unique_ptr<mongoc_read_prefs_t, decltype(deleter)> saved_preference(nullptr, deleter);
 
         bool called = false;
-        database_set_preference->interpose(
-            [&](mongoc_database_t*, const mongoc_read_prefs_t* read_prefs) {
-                called = true;
-                saved_preference.reset(mongoc_read_prefs_copy(read_prefs));
-                REQUIRE(mongoc_read_prefs_get_mode(read_prefs) ==
-                        libmongoc::conversions::read_mode_t_from_read_mode(
-                            read_preference::read_mode::k_secondary_preferred));
-            });
+        database_set_preference->interpose([&](mongoc_database_t*, mongoc_read_prefs_t const* read_prefs) {
+            called = true;
+            saved_preference.reset(mongoc_read_prefs_copy(read_prefs));
+            REQUIRE(
+                mongoc_read_prefs_get_mode(read_prefs) ==
+                libmongoc::conversions::read_mode_t_from_read_mode(read_preference::read_mode::k_secondary_preferred));
+        });
 
-        database_get_preference
-            ->interpose([&](const mongoc_database_t*) { return saved_preference.get(); })
-            .forever();
+        database_get_preference->interpose([&](mongoc_database_t const*) { return saved_preference.get(); }).forever();
 
         mongo_database.read_preference(std::move(preference));
         REQUIRE(called);
 
-        REQUIRE(read_preference::read_mode::k_secondary_preferred ==
-                mongo_database.read_preference().mode());
+        REQUIRE(read_preference::read_mode::k_secondary_preferred == mongo_database.read_preference().mode());
     }
 
     SECTION("has a write concern which may be set and obtained") {
@@ -258,14 +251,13 @@ TEST_CASE("A database", "[database]") {
         mongoc_write_concern_t* underlying_wc;
 
         bool set_called = false;
-        database_set_concern->interpose(
-            [&](mongoc_database_t*, const mongoc_write_concern_t* concern) {
-                set_called = true;
-                underlying_wc = mongoc_write_concern_copy(concern);
-            });
+        database_set_concern->interpose([&](mongoc_database_t*, mongoc_write_concern_t const* concern) {
+            set_called = true;
+            underlying_wc = mongoc_write_concern_copy(concern);
+        });
 
         bool get_called = false;
-        database_get_concern->interpose([&](const mongoc_database_t*) {
+        database_get_concern->interpose([&](mongoc_database_t const*) {
             get_called = true;
             return underlying_wc;
         });
@@ -275,7 +267,7 @@ TEST_CASE("A database", "[database]") {
 
         MOCK_CONCERN
         bool copy_called = false;
-        concern_copy->interpose([&](const mongoc_write_concern_t*) {
+        concern_copy->interpose([&](mongoc_write_concern_t const*) {
             copy_called = true;
             return mongoc_write_concern_copy(underlying_wc);
         });
@@ -303,9 +295,9 @@ TEST_CASE("A database", "[database]") {
         libbson::scoped_bson_t bson_doc{doc.view()};
 
         database_command_with_opts->interpose([&](mongoc_database_t*,
-                                                  const bson_t*,
-                                                  const mongoc_read_prefs_t*,
-                                                  const bson_t*,
+                                                  bson_t const*,
+                                                  mongoc_read_prefs_t const*,
+                                                  bson_t const*,
                                                   bson_t* reply,
                                                   bson_error_t*) {
             called = true;
@@ -335,15 +327,14 @@ TEST_CASE("Database integration tests", "[database]") {
 
         auto get_results = [](cursor&& cursor) {
             std::vector<bsoncxx::document::value> results;
-            std::transform(cursor.begin(),
-                           cursor.end(),
-                           std::back_inserter(results),
-                           [](bsoncxx::document::view v) { return bsoncxx::document::value{v}; });
+            std::transform(cursor.begin(), cursor.end(), std::back_inserter(results), [](bsoncxx::document::view v) {
+                return bsoncxx::document::value{v};
+            });
             return results;
         };
 
         SECTION("listLocalSessions") {
-            SERVER_HAS_SESSIONS_OR_SKIP(mongo_client);
+            SERVER_HAS_SESSIONS_OR_SKIP();
 
             // SERVER-79306: Ensure the database exists for consistent behavior with sharded
             // clusters.
@@ -360,8 +351,7 @@ TEST_CASE("Database integration tests", "[database]") {
             auto results = get_results(std::move(cursor));
 
             REQUIRE(results.size() == 1);
-            REQUIRE(results[0].view()["name"].get_string().value ==
-                    bsoncxx::stdx::string_view("Jane"));
+            REQUIRE(results[0].view()["name"].get_string().value == bsoncxx::stdx::string_view("Jane"));
         }
     }
 
@@ -397,7 +387,7 @@ TEST_CASE("Database integration tests", "[database]") {
 
             auto cursor = database.list_collections();
             bool found = false;
-            for (const auto& coll : cursor) {
+            for (auto const& coll : cursor) {
                 auto name = bsoncxx::string::to_string(coll["name"].get_string().value);
                 if (name == std::string(collection_name)) {
                     found = true;
@@ -446,8 +436,8 @@ TEST_CASE("Database integration tests", "[database]") {
         db.drop();
 
         collection default_collection = db.create_collection("list_collections_default");
-        collection capped_collection = db.create_collection(
-            "list_collections_capped", make_document(kvp("capped", true), kvp("size", 256)));
+        collection capped_collection =
+            db.create_collection("list_collections_capped", make_document(kvp("capped", true), kvp("size", 256)));
 
         index_view default_index = default_collection.indexes();
         index_view capped_index = capped_collection.indexes();
@@ -459,8 +449,7 @@ TEST_CASE("Database integration tests", "[database]") {
         capped_collection.insert_one(make_document(kvp("a", 5)));
 
         auto cursor1 = db.list_collections();
-        std::set<std::string> expected_colls1{"list_collections_default",
-                                              "list_collections_capped"};
+        std::set<std::string> expected_colls1{"list_collections_default", "list_collections_capped"};
         REQUIRE(check_for_collections(std::move(cursor1), expected_colls1));
 
         auto cursor2 = db.list_collections(make_document(kvp("options.capped", true)));
@@ -495,11 +484,11 @@ TEST_CASE("Database integration tests", "[database]") {
 // also has a few inconsistencies with the standard, which appear to vary across platforms.
 template <typename EventT>
 struct check_service_id {
-    const bool expect_service_id;
+    bool const expect_service_id;
 
-    check_service_id(const bool expect_service_id) : expect_service_id(expect_service_id) {}
+    check_service_id(bool const expect_service_id) : expect_service_id(expect_service_id) {}
 
-    void operator()(const EventT& event) {
+    void operator()(EventT const& event) {
         INFO("checking for service_id()");
         CAPTURE(event.command_name(), expect_service_id);
 
@@ -522,25 +511,19 @@ TEST_CASE("serviceId presence depends on load-balancing mode") {
 
     // Set Application Performance Monitoring options (APM):
     mongocxx::options::apm apm_opts;
-    apm_opts.on_command_started(
-        check_service_id<mongocxx::events::command_started_event>{expect_service_id});
-    apm_opts.on_command_succeeded(
-        check_service_id<mongocxx::events::command_succeeded_event>{expect_service_id});
-    apm_opts.on_command_failed(
-        check_service_id<mongocxx::events::command_failed_event>{expect_service_id});
+    apm_opts.on_command_started(check_service_id<mongocxx::events::command_started_event>{expect_service_id});
+    apm_opts.on_command_succeeded(check_service_id<mongocxx::events::command_succeeded_event>{expect_service_id});
+    apm_opts.on_command_failed(check_service_id<mongocxx::events::command_failed_event>{expect_service_id});
 
     // Set up mocking for get_service_id events:
-    auto apm_command_started_get_service_id =
-        libmongoc::apm_command_started_get_service_id.create_instance();
-    auto apm_command_succeeded_get_service_id =
-        libmongoc::apm_command_succeeded_get_service_id.create_instance();
-    auto apm_command_failed_get_service_id =
-        libmongoc::apm_command_failed_get_service_id.create_instance();
+    auto apm_command_started_get_service_id = libmongoc::apm_command_started_get_service_id.create_instance();
+    auto apm_command_succeeded_get_service_id = libmongoc::apm_command_succeeded_get_service_id.create_instance();
+    auto apm_command_failed_get_service_id = libmongoc::apm_command_failed_get_service_id.create_instance();
 
     // Set up mocked functions that DO emit a service_id:
     if (expect_service_id) {
         // Return a bson_oid_t with data where the service_id has some value:
-        const auto make_service_id_bson_oid_t = [](const void*) -> const bson_oid_t* {
+        auto const make_service_id_bson_oid_t = [](void const*) -> bson_oid_t const* {
             static bson_oid_t tmp = {0x65};
             return &tmp;
         };
@@ -553,7 +536,7 @@ TEST_CASE("serviceId presence depends on load-balancing mode") {
 
     // Set up mocked functions that DO NOT emit a service_id:
     if (!expect_service_id) {
-        auto make_empty_bson_oid_t = [](const void*) -> bson_oid_t* { return nullptr; };
+        auto make_empty_bson_oid_t = [](void const*) -> bson_oid_t* { return nullptr; };
 
         apm_command_started_get_service_id->interpose(make_empty_bson_oid_t).forever();
         apm_command_succeeded_get_service_id->interpose(make_empty_bson_oid_t).forever();
@@ -577,4 +560,4 @@ TEST_CASE("serviceId presence depends on load-balancing mode") {
     CHECK_THROWS(database.run_command(cmd.view()));
 }
 
-}  // namespace
+} // namespace
