@@ -22,11 +22,10 @@
 namespace {
 using namespace mongocxx;
 
-TEST_CASE("mongocxx::gridfs::uploader default constructor makes invalid uploader",
-          "[gridfs::uploader]") {
+TEST_CASE("mongocxx::gridfs::uploader default constructor makes invalid uploader", "[gridfs::uploader]") {
     gridfs::uploader uploader;
     REQUIRE(!uploader);
     std::uint8_t c = 0x0;
     REQUIRE_THROWS_AS(uploader.write(&c, 1), logic_error);
 }
-}  // namespace
+} // namespace
