@@ -1,4 +1,4 @@
-// Copyright 2016 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -13,10 +13,13 @@
 // limitations under the License.
 
 #include <bsoncxx/builder/basic/document.hpp>
-#include <bsoncxx/test/catch.hh>
+
 #include <mongocxx/instance.hpp>
 #include <mongocxx/model/replace_one.hpp>
-#include <third_party/catch/include/helpers.hpp>
+
+#include <bsoncxx/test/catch.hh>
+
+#include <mongocxx/test/catch_helpers.hh>
 
 namespace {
 using namespace bsoncxx::builder::basic;
@@ -38,4 +41,4 @@ TEST_CASE("replace_one model tests", "[replace_one][model]") {
     CHECK_OPTIONAL_ARGUMENT(ro, upsert, true);
     CHECK_OPTIONAL_ARGUMENT(ro, collation, collation.view());
 }
-}  // namespace
+} // namespace
