@@ -1,4 +1,4 @@
-// Copyright 2016 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -14,12 +14,15 @@
 
 #include <chrono>
 
-#include "helpers.hpp"
 #include <bsoncxx/builder/basic/document.hpp>
-#include <bsoncxx/test_util/catch.hh>
+
 #include <mongocxx/instance.hpp>
 #include <mongocxx/options/find_one_and_delete.hpp>
 
+#include <bsoncxx/test/catch.hh>
+
+#include <mongocxx/test/catch_helpers.hh>
+
 namespace {
 using namespace bsoncxx::builder::basic;
 using namespace mongocxx;
@@ -39,4 +42,4 @@ TEST_CASE("find_one_and_delete", "[find_one_and_delete][option]") {
     CHECK_OPTIONAL_ARGUMENT(opts, projection, projection.view());
     CHECK_OPTIONAL_ARGUMENT(opts, sort, sort.view());
 }
-}  // namespace
+} // namespace
