@@ -1,4 +1,4 @@
-// Copyright 2017 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -14,10 +14,13 @@
 
 #include <bsoncxx/builder/basic/document.hpp>
 #include <bsoncxx/builder/basic/kvp.hpp>
-#include <bsoncxx/test/catch.hh>
+
 #include <mongocxx/instance.hpp>
 #include <mongocxx/options/gridfs/upload.hpp>
-#include <third_party/catch/include/helpers.hpp>
+
+#include <bsoncxx/test/catch.hh>
+
+#include <mongocxx/test/catch_helpers.hh>
 
 namespace {
 using namespace bsoncxx;
@@ -35,4 +38,4 @@ TEST_CASE("options::gridfs::upload accessors/mutators", "[options::gridfs::uploa
     CHECK_OPTIONAL_ARGUMENT(upload_options, chunk_size_bytes, 100);
     CHECK_OPTIONAL_ARGUMENT(upload_options, metadata, document.view());
 }
-}  // namespace
+} // namespace
