@@ -1,4 +1,4 @@
-// Copyright 2014 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -14,10 +14,12 @@
 
 #include <bsoncxx/builder/basic/document.hpp>
 #include <bsoncxx/json.hpp>
-#include <bsoncxx/test/catch.hh>
+
 #include <mongocxx/instance.hpp>
 #include <mongocxx/result/delete.hpp>
 
+#include <bsoncxx/test/catch.hh>
+
 namespace {
 
 using bsoncxx::builder::basic::kvp;
@@ -41,8 +43,7 @@ TEST_CASE("delete", "[delete][result]") {
 TEST_CASE("delete equals", "[delete][result]") {
     mongocxx::instance::current();
 
-    auto doc =
-        make_document(kvp("_id", bsoncxx::oid{}), kvp("nRemoved", bsoncxx::types::b_int32{1}));
+    auto doc = make_document(kvp("_id", bsoncxx::oid{}), kvp("nRemoved", bsoncxx::types::b_int32{1}));
 
     mongocxx::result::bulk_write a{doc};
     mongocxx::result::bulk_write b{doc};
@@ -67,4 +68,4 @@ TEST_CASE("delete inequals", "[delete][result]") {
     REQUIRE(delete_result1 != delete_result2);
 }
 
-}  // namespace
+} // namespace
