@@ -23,17 +23,13 @@ using bsoncxx::builder::basic::make_array;
 using bsoncxx::builder::basic::make_document;
 using namespace mongocxx;
 
-bool does_search_index_exist_on_cursor(cursor& c,
-                                       const search_index_model& model,
-                                       bool with_status) {
-    for (const auto& index : c) {
+bool does_search_index_exist_on_cursor(cursor& c, search_index_model const& model, bool with_status) {
+    for (auto const& index : c) {
         // look for a queryable index with a matching name and assert the definition matches model
-        if (index["name"].get_string().value == model.name().value() &&
-            index["queryable"].get_bool().value) {
+        if (index["name"].get_string().value == model.name().value() && index["queryable"].get_bool().value) {
             REQUIRE(index["latestDefinition"].get_document().view() == model.definition());
             // optional addition check needed if with_status is set
-            if (!with_status ||
-                bsoncxx::string::to_string(index["status"].get_string().value) == "READY") {
+            if (!with_status || bsoncxx::string::to_string(index["status"].get_string().value) == "READY") {
                 return true;
             }
         }
@@ -42,20 +38,19 @@ bool does_search_index_exist_on_cursor(cursor& c,
 }
 
 // Almost identical to does_search_index_exist_on_cursor but checks type field.
-bool does_search_index_exist_on_cursor_with_type(cursor& c,
-                                                 const search_index_model& model,
-                                                 const char* type,
-                                                 bool with_status) {
-    for (const auto& index : c) {
+bool does_search_index_exist_on_cursor_with_type(
+    cursor& c,
+    search_index_model const& model,
+    char const* type,
+    bool with_status) {
+    for (auto const& index : c) {
         // look for a queryable index with a matching name
-        if (index["name"].get_string().value == model.name().value() &&
-            index["queryable"].get_bool().value) {
+        if (index["name"].get_string().value == model.name().value() && index["queryable"].get_bool().value) {
             // assert the definition and type match
             REQUIRE(index["latestDefinition"].get_document().view() == model.definition());
             REQUIRE(!strcmp(index["type"].get_string().value.data(), type));
             // optional addition check needed if with_status is set
-            if (!with_status ||
-                bsoncxx::string::to_string(index["status"].get_string().value) == "READY") {
+            if (!with_status || bsoncxx::string::to_string(index["status"].get_string().value) == "READY") {
                 return true;
             }
         }
@@ -99,10 +94,9 @@ TEST_CASE("atlas search indexes prose tests", "[atlas][search_indexes]") {
         //     mappings : { dynamic: false }
         //   }
         // }
-        const auto name = "test-search-index";
-        const auto definition =
-            make_document(kvp("mappings", make_document(kvp("dynamic", false))));
-        const auto model = search_index_model(name, definition.view());
+        auto const name = "test-search-index";
+        auto const definition = make_document(kvp("mappings", make_document(kvp("dynamic", false))));
+        auto const model = search_index_model(name, definition.view());
 
         REQUIRE(siv.create_one(model) == "test-search-index");
 
@@ -125,10 +119,9 @@ TEST_CASE("atlas search indexes prose tests", "[atlas][search_indexes]") {
         //     mappings : { dynamic: false }
         //   }
         // }
-        const auto name1 = "test-search-index-1";
-        const auto definition1 =
-            make_document(kvp("mappings", make_document(kvp("dynamic", false))));
-        const auto model1 = search_index_model(name1, definition1.view());
+        auto const name1 = "test-search-index-1";
+        auto const definition1 = make_document(kvp("mappings", make_document(kvp("dynamic", false))));
+        auto const model1 = search_index_model(name1, definition1.view());
 
         // {
         //   name: 'test-search-index-2',
@@ -136,15 +129,14 @@ TEST_CASE("atlas search indexes prose tests", "[atlas][search_indexes]") {
         //     mappings : { dynamic: false }
         //   }
         // }
-        const auto name2 = "test-search-index-2";
-        const auto definition2 =
-            make_document(kvp("mappings", make_document(kvp("dynamic", false))));
-        const auto model2 = search_index_model(name2, definition2.view());
+        auto const name2 = "test-search-index-2";
+        auto const definition2 = make_document(kvp("mappings", make_document(kvp("dynamic", false))));
+        auto const model2 = search_index_model(name2, definition2.view());
 
-        const std::vector<search_index_model> models = {model1, model2};
+        std::vector<search_index_model> const models = {model1, model2};
 
-        const std::vector<std::string> result = siv.create_many(models);
-        const std::vector<std::string> expected = {"test-search-index-1", "test-search-index-2"};
+        std::vector<std::string> const result = siv.create_many(models);
+        std::vector<std::string> const expected = {"test-search-index-1", "test-search-index-2"};
         REQUIRE(result == expected);
 
         assert_soon([&siv, &model1, &model2](void) -> bool {
@@ -166,10 +158,9 @@ TEST_CASE("atlas search indexes prose tests", "[atlas][search_indexes]") {
         //     mappings : { dynamic: false }
         //   }
         // }
-        const auto name = "test-search-index";
-        const auto definition =
-            make_document(kvp("mappings", make_document(kvp("dynamic", false))));
-        const auto model = search_index_model(name, definition.view());
+        auto const name = "test-search-index";
+        auto const definition = make_document(kvp("mappings", make_document(kvp("dynamic", false))));
+        auto const model = search_index_model(name, definition.view());
 
         REQUIRE(siv.create_one(model) == "test-search-index");
 
@@ -200,10 +191,9 @@ TEST_CASE("atlas search indexes prose tests", "[atlas][search_indexes]") {
         //     mappings: { dynamic: false }
         //    }
         // }
-        const auto name = "test-search-index";
-        const auto definition =
-            make_document(kvp("mappings", make_document(kvp("dynamic", false))));
-        const auto model = search_index_model(name, definition.view());
+        auto const name = "test-search-index";
+        auto const definition = make_document(kvp("mappings", make_document(kvp("dynamic", false))));
+        auto const model = search_index_model(name, definition.view());
 
         REQUIRE(siv.create_one(model) == "test-search-index");
 
@@ -218,9 +208,8 @@ TEST_CASE("atlas search indexes prose tests", "[atlas][search_indexes]") {
         //     mappings: { dynamic: true }
         //   }
         // }
-        const auto new_definition =
-            make_document(kvp("mappings", make_document(kvp("dynamic", true))));
-        const auto new_model = search_index_model(name, new_definition.view());
+        auto const new_definition = make_document(kvp("mappings", make_document(kvp("dynamic", true))));
+        auto const new_model = search_index_model(name, new_definition.view());
         siv.update_one(name, new_definition.view());
 
         assert_soon([&siv, &new_model](void) -> bool {
@@ -261,10 +250,9 @@ TEST_CASE("atlas search indexes prose tests", "[atlas][search_indexes]") {
         //     mappings: { dynamic: false }
         //   }
         // }
-        const auto name = "test-search-index-case6";
-        const auto definition =
-            make_document(kvp("mappings", make_document(kvp("dynamic", false))));
-        const auto model = search_index_model(name, definition.view());
+        auto const name = "test-search-index-case6";
+        auto const definition = make_document(kvp("mappings", make_document(kvp("dynamic", false))));
+        auto const model = search_index_model(name, definition.view());
 
         REQUIRE(siv.create_one(model) == "test-search-index-case6");
 
@@ -292,10 +280,9 @@ TEST_CASE("atlas search indexes prose tests", "[atlas][search_indexes]") {
             //      mappings: { dynamic: false }
             //     }
             // }
-            const auto name = "test-search-index-case7-implicit";
-            const auto definition =
-                make_document(kvp("mappings", make_document(kvp("dynamic", false))));
-            const auto model = search_index_model(name, definition.view());
+            auto const name = "test-search-index-case7-implicit";
+            auto const definition = make_document(kvp("mappings", make_document(kvp("dynamic", false))));
+            auto const model = search_index_model(name, definition.view());
 
             REQUIRE(siv.create_one(model) == "test-search-index-case7-implicit");
 
@@ -313,9 +300,8 @@ TEST_CASE("atlas search indexes prose tests", "[atlas][search_indexes]") {
             //       mappings: { dynamic: false }
             //     }
             //   }
-            const auto name = "test-search-index-case7-explicit";
-            const auto definition =
-                make_document(kvp("mappings", make_document(kvp("dynamic", false))));
+            auto const name = "test-search-index-case7-explicit";
+            auto const definition = make_document(kvp("mappings", make_document(kvp("dynamic", false))));
             auto model = search_index_model(name, definition.view()).type("search");
 
             REQUIRE(siv.create_one(model) == "test-search-index-case7-explicit");
@@ -341,14 +327,15 @@ TEST_CASE("atlas search indexes prose tests", "[atlas][search_indexes]") {
             //       ]
             //     }
             //   }
-            const auto name = "test-search-index-case7-vector";
-            const auto type = "vectorSearch";
-            const auto definition =
-                make_document(kvp("fields",
-                                  make_array(make_document(kvp("type", "vector"),
-                                                           kvp("path", "plot_embedding"),
-                                                           kvp("numDimensions", 1536),
-                                                           kvp("similarity", "euclidean")))));
+            auto const name = "test-search-index-case7-vector";
+            auto const type = "vectorSearch";
+            auto const definition = make_document(
+                kvp("fields",
+                    make_array(make_document(
+                        kvp("type", "vector"),
+                        kvp("path", "plot_embedding"),
+                        kvp("numDimensions", 1536),
+                        kvp("similarity", "euclidean")))));
             auto model = search_index_model(name, definition.view()).type(type);
 
             REQUIRE(model.type().value() == "vectorSearch");
@@ -356,8 +343,7 @@ TEST_CASE("atlas search indexes prose tests", "[atlas][search_indexes]") {
 
             assert_soon([&siv, &model](void) -> bool {
                 auto cursor = siv.list();
-                return does_search_index_exist_on_cursor_with_type(
-                    cursor, model, "vectorSearch", false);
+                return does_search_index_exist_on_cursor_with_type(cursor, model, "vectorSearch", false);
             });
         }
 
@@ -383,17 +369,17 @@ TEST_CASE("atlas search indexes prose tests", "[atlas][search_indexes]") {
         //       ]
         //     }
         //   }
-        const auto name = "test-search-index-case8-error";
-        const auto definition =
-            make_document(kvp("fields",
-                              make_array(make_document(kvp("type", "vector"),
-                                                       kvp("path", "plot_embedding"),
-                                                       kvp("numDimensions", 1536),
-                                                       kvp("similarity", "euclidean")))));
-        const auto model = search_index_model(name, definition.view());
+        auto const name = "test-search-index-case8-error";
+        auto const definition = make_document(
+            kvp("fields",
+                make_array(make_document(
+                    kvp("type", "vector"),
+                    kvp("path", "plot_embedding"),
+                    kvp("numDimensions", 1536),
+                    kvp("similarity", "euclidean")))));
+        auto const model = search_index_model(name, definition.view());
 
-        REQUIRE_THROWS_WITH(siv.create_one(model),
-                            Catch::Matchers::ContainsSubstring("Attribute mappings missing"));
+        REQUIRE_THROWS_WITH(siv.create_one(model), Catch::Matchers::ContainsSubstring("Attribute mappings missing"));
 
         SUCCEED("Prose Test Case 8: Driver requires explicit type to create a vector search index");
     }
@@ -420,10 +406,9 @@ TEST_CASE("atlas search indexes tests", "[atlas][search_indexes]") {
             //     mappings : { dynamic: false }
             //   }
             // }
-            const auto name = "test-search-index";
-            const auto type = "search";
-            const auto definition =
-                make_document(kvp("mappings", make_document(kvp("dynamic", false))));
+            auto const name = "test-search-index";
+            auto const type = "search";
+            auto const definition = make_document(kvp("mappings", make_document(kvp("dynamic", false))));
             auto model = search_index_model(name, definition.view()).type(type);
 
             REQUIRE(model.name().value() == name);
@@ -446,14 +431,15 @@ TEST_CASE("atlas search indexes tests", "[atlas][search_indexes]") {
             //       ]
             //     }
             //   }
-            const auto name = "test-search-index-vector";
-            const auto type = "vectorSearch";
-            const auto definition =
-                make_document(kvp("fields",
-                                  make_array(make_document(kvp("type", "vector"),
-                                                           kvp("path", "plot_embedding"),
-                                                           kvp("numDimensions", 1536),
-                                                           kvp("similarity", "euclidean")))));
+            auto const name = "test-search-index-vector";
+            auto const type = "vectorSearch";
+            auto const definition = make_document(
+                kvp("fields",
+                    make_array(make_document(
+                        kvp("type", "vector"),
+                        kvp("path", "plot_embedding"),
+                        kvp("numDimensions", 1536),
+                        kvp("similarity", "euclidean")))));
             auto model = search_index_model(name, definition.view()).type(type);
 
             REQUIRE(model.name().value() == name);
@@ -475,10 +461,9 @@ TEST_CASE("atlas search indexes tests", "[atlas][search_indexes]") {
         //     mappings : { dynamic: false }
         //   }
         // }
-        const auto name1 = "test-search-index-1";
-        const auto type1 = "search";
-        const auto definition1 =
-            make_document(kvp("mappings", make_document(kvp("dynamic", false))));
+        auto const name1 = "test-search-index-1";
+        auto const type1 = "search";
+        auto const definition1 = make_document(kvp("mappings", make_document(kvp("dynamic", false))));
         auto model1 = search_index_model(name1, definition1.view()).type(type1);
 
         // {
@@ -488,16 +473,15 @@ TEST_CASE("atlas search indexes tests", "[atlas][search_indexes]") {
         //     mappings : { dynamic: false }
         //   }
         // }
-        const auto name2 = "test-search-index-2";
-        const auto type2 = "search";
-        const auto definition2 =
-            make_document(kvp("mappings", make_document(kvp("dynamic", false))));
+        auto const name2 = "test-search-index-2";
+        auto const type2 = "search";
+        auto const definition2 = make_document(kvp("mappings", make_document(kvp("dynamic", false))));
         auto model2 = search_index_model(name2, definition2.view()).type(type2);
 
-        const std::vector<search_index_model> models = {model1, model2};
+        std::vector<search_index_model> const models = {model1, model2};
 
-        const std::vector<std::string> result = siv.create_many(models);
-        const std::vector<std::string> expected = {"test-search-index-1", "test-search-index-2"};
+        std::vector<std::string> const result = siv.create_many(models);
+        std::vector<std::string> const expected = {"test-search-index-1", "test-search-index-2"};
         REQUIRE(result == expected);
 
         assert_soon([&siv, &model1, &model2](void) -> bool {
@@ -527,14 +511,15 @@ TEST_CASE("atlas search indexes tests", "[atlas][search_indexes]") {
         //       ]
         //     }
         //   }
-        const auto name1 = "test-search-index-1";
-        const auto type1 = "vectorSearch";
-        const auto definition1 =
-            make_document(kvp("fields",
-                              make_array(make_document(kvp("type", "vector"),
-                                                       kvp("path", "plot_embedding"),
-                                                       kvp("numDimensions", 1536),
-                                                       kvp("similarity", "euclidean")))));
+        auto const name1 = "test-search-index-1";
+        auto const type1 = "vectorSearch";
+        auto const definition1 = make_document(
+            kvp("fields",
+                make_array(make_document(
+                    kvp("type", "vector"),
+                    kvp("path", "plot_embedding"),
+                    kvp("numDimensions", 1536),
+                    kvp("similarity", "euclidean")))));
         auto model1 = search_index_model(name1, definition1.view()).type(type1);
 
         //   {
@@ -551,31 +536,30 @@ TEST_CASE("atlas search indexes tests", "[atlas][search_indexes]") {
         //       ]
         //     }
         //   }
-        const auto name2 = "test-search-index-2";
-        const auto type2 = "vectorSearch";
-        const auto definition2 =
-            make_document(kvp("fields",
-                              make_array(make_document(kvp("type", "vector"),
-                                                       kvp("path", "plot_embedding"),
-                                                       kvp("numDimensions", 1536),
-                                                       kvp("similarity", "euclidean")))));
+        auto const name2 = "test-search-index-2";
+        auto const type2 = "vectorSearch";
+        auto const definition2 = make_document(
+            kvp("fields",
+                make_array(make_document(
+                    kvp("type", "vector"),
+                    kvp("path", "plot_embedding"),
+                    kvp("numDimensions", 1536),
+                    kvp("similarity", "euclidean")))));
         auto model2 = search_index_model(name2, definition2.view()).type(type2);
 
-        const std::vector<search_index_model> models = {model1, model2};
+        std::vector<search_index_model> const models = {model1, model2};
 
-        const std::vector<std::string> result = siv.create_many(models);
-        const std::vector<std::string> expected = {"test-search-index-1", "test-search-index-2"};
+        std::vector<std::string> const result = siv.create_many(models);
+        std::vector<std::string> const expected = {"test-search-index-1", "test-search-index-2"};
         REQUIRE(result == expected);
 
         assert_soon([&siv, &model1, &model2](void) -> bool {
             auto cursor = siv.list();
-            return does_search_index_exist_on_cursor_with_type(
-                       cursor, model1, "vectorSearch", false) &&
-                   does_search_index_exist_on_cursor_with_type(
-                       cursor, model2, "vectorSearch", false);
+            return does_search_index_exist_on_cursor_with_type(cursor, model1, "vectorSearch", false) &&
+                   does_search_index_exist_on_cursor_with_type(cursor, model2, "vectorSearch", false);
         });
 
         SUCCEED("Create many works with vector search types");
     }
 }
-}  // namespace
+} // namespace
