@@ -34,7 +34,7 @@ using namespace bsoncxx;
 using namespace mongocxx;
 using namespace spec;
 
-void _set_up_key_vault(const client& client, document::view test_spec_view) {
+void _set_up_key_vault(client const& client, document::view test_spec_view) {
     if (test_spec_view["key_vault_data"]) {
         write_concern wc_majority;
         wc_majority.acknowledge_level(write_concern::level::k_majority);
@@ -60,17 +60,15 @@ void add_auto_encryption_opts(document::view test, options::client* client_opts)
         options::auto_encryption auto_encrypt_opts{};
 
         if (test_encrypt_opts["bypassAutoEncryption"]) {
-            auto_encrypt_opts.bypass_auto_encryption(
-                test_encrypt_opts["bypassAutoEncryption"].get_bool().value);
+            auto_encrypt_opts.bypass_auto_encryption(test_encrypt_opts["bypassAutoEncryption"].get_bool().value);
         }
 
-        if (const auto bqa = test_encrypt_opts["bypassQueryAnalysis"]) {
+        if (auto const bqa = test_encrypt_opts["bypassQueryAnalysis"]) {
             auto_encrypt_opts.bypass_query_analysis(bqa.get_bool().value);
         }
 
         if (test_encrypt_opts["keyVaultNamespace"]) {
-            auto ns_string = bsoncxx::string::to_string(
-                test_encrypt_opts["keyVaultNamespace"].get_string().value);
+            auto ns_string = bsoncxx::string::to_string(test_encrypt_opts["keyVaultNamespace"].get_string().value);
             auto dot = ns_string.find(".");
             std::string db = ns_string.substr(0, dot);
             std::string coll = ns_string.substr(dot + 1);
@@ -85,11 +83,10 @@ void add_auto_encryption_opts(document::view test, options::client* client_opts)
         }
 
         if (test_encrypt_opts["encryptedFieldsMap"]) {
-            auto_encrypt_opts.encrypted_fields_map(
-                test_encrypt_opts["encryptedFieldsMap"].get_document().value);
+            auto_encrypt_opts.encrypted_fields_map(test_encrypt_opts["encryptedFieldsMap"].get_document().value);
         }
 
-        if (const auto providers = test_encrypt_opts["kmsProviders"]) {
+        if (auto const providers = test_encrypt_opts["kmsProviders"]) {
             using bsoncxx::builder::basic::kvp;
             using bsoncxx::builder::basic::sub_document;
 
@@ -100,74 +97,58 @@ void add_auto_encryption_opts(document::view test, options::client* client_opts)
             if (providers["aws"]) {
                 kms_doc.append(kvp("aws", [](sub_document subdoc) {
                     subdoc.append(
-                        kvp("secretAccessKey",
-                            test_util::getenv_or_fail("MONGOCXX_TEST_AWS_SECRET_ACCESS_KEY")));
-                    subdoc.append(
-                        kvp("accessKeyId",
-                            test_util::getenv_or_fail("MONGOCXX_TEST_AWS_ACCESS_KEY_ID")));
+                        kvp("secretAccessKey", test_util::getenv_or_fail("MONGOCXX_TEST_AWS_SECRET_ACCESS_KEY")));
+                    subdoc.append(kvp("accessKeyId", test_util::getenv_or_fail("MONGOCXX_TEST_AWS_ACCESS_KEY_ID")));
                 }));
             }
 
             if (providers["awsTemporary"]) {
                 kms_doc.append(kvp("aws", [](sub_document subdoc) {
                     subdoc.append(
-                        kvp("secretAccessKey",
-                            test_util::getenv_or_fail("MONGOCXX_TEST_AWS_TEMP_SECRET_ACCESS_KEY")));
+                        kvp("secretAccessKey", test_util::getenv_or_fail("MONGOCXX_TEST_AWS_TEMP_SECRET_ACCESS_KEY")));
                     subdoc.append(
-                        kvp("accessKeyId",
-                            test_util::getenv_or_fail("MONGOCXX_TEST_AWS_TEMP_ACCESS_KEY_ID")));
+                        kvp("accessKeyId", test_util::getenv_or_fail("MONGOCXX_TEST_AWS_TEMP_ACCESS_KEY_ID")));
                     subdoc.append(
-                        kvp("sessionToken",
-                            test_util::getenv_or_fail("MONGOCXX_TEST_AWS_TEMP_SESSION_TOKEN")));
+                        kvp("sessionToken", test_util::getenv_or_fail("MONGOCXX_TEST_AWS_TEMP_SESSION_TOKEN")));
                 }));
             }
 
             if (providers["awsTemporaryNoSessionToken"]) {
                 kms_doc.append(kvp("aws", [](sub_document subdoc) {
                     subdoc.append(
-                        kvp("secretAccessKey",
-                            test_util::getenv_or_fail("MONGOCXX_TEST_AWS_TEMP_SECRET_ACCESS_KEY")));
+                        kvp("secretAccessKey", test_util::getenv_or_fail("MONGOCXX_TEST_AWS_TEMP_SECRET_ACCESS_KEY")));
                     subdoc.append(
-                        kvp("accessKeyId",
-                            test_util::getenv_or_fail("MONGOCXX_TEST_AWS_TEMP_ACCESS_KEY_ID")));
+                        kvp("accessKeyId", test_util::getenv_or_fail("MONGOCXX_TEST_AWS_TEMP_ACCESS_KEY_ID")));
                 }));
             }
 
             // Add gcp credentials (from the enviornment):
             if (providers["gcp"]) {
                 kms_doc.append(kvp("gcp", [](sub_document subdoc) {
-                    subdoc.append(
-                        kvp("email", test_util::getenv_or_fail("MONGOCXX_TEST_GCP_EMAIL")));
-                    subdoc.append(kvp("privateKey",
-                                      test_util::getenv_or_fail("MONGOCXX_TEST_GCP_PRIVATEKEY")));
+                    subdoc.append(kvp("email", test_util::getenv_or_fail("MONGOCXX_TEST_GCP_EMAIL")));
+                    subdoc.append(kvp("privateKey", test_util::getenv_or_fail("MONGOCXX_TEST_GCP_PRIVATEKEY")));
                 }));
             }
 
             // Add Azure credentials (from the environment):
             if (providers["azure"]) {
                 kms_doc.append(kvp("azure", [](sub_document subdoc) {
-                    subdoc.append(kvp("tenantId",
-                                      test_util::getenv_or_fail("MONGOCXX_TEST_AZURE_TENANT_ID")));
-                    subdoc.append(kvp("clientId",
-                                      test_util::getenv_or_fail("MONGOCXX_TEST_AZURE_CLIENT_ID")));
-                    subdoc.append(
-                        kvp("clientSecret",
-                            test_util::getenv_or_fail("MONGOCXX_TEST_AZURE_CLIENT_SECRET")));
+                    subdoc.append(kvp("tenantId", test_util::getenv_or_fail("MONGOCXX_TEST_AZURE_TENANT_ID")));
+                    subdoc.append(kvp("clientId", test_util::getenv_or_fail("MONGOCXX_TEST_AZURE_CLIENT_ID")));
+                    subdoc.append(kvp("clientSecret", test_util::getenv_or_fail("MONGOCXX_TEST_AZURE_CLIENT_SECRET")));
                 }));
             }
 
             // Add KMIP credentials (from the json file):
             if (providers["kmip"]) {
-                kms_doc.append(kvp("kmip", [&](sub_document subdoc) {
-                    subdoc.append(kvp("endpoint", "localhost:5698"));
-                }));
+                kms_doc.append(
+                    kvp("kmip", [&](sub_document subdoc) { subdoc.append(kvp("endpoint", "localhost:5698")); }));
 
                 tls_opts.append(kvp("kmip", [&](sub_document subdoc) {
-                    subdoc.append(kvp(
-                        "tlsCAFile", test_util::getenv_or_fail("MONGOCXX_TEST_CSFLE_TLS_CA_FILE")));
-                    subdoc.append(kvp(
-                        "tlsCertificateKeyFile",
-                        test_util::getenv_or_fail("MONGOCXX_TEST_CSFLE_TLS_CERTIFICATE_KEY_FILE")));
+                    subdoc.append(kvp("tlsCAFile", test_util::getenv_or_fail("MONGOCXX_TEST_CSFLE_TLS_CA_FILE")));
+                    subdoc.append(
+                        kvp("tlsCertificateKeyFile",
+                            test_util::getenv_or_fail("MONGOCXX_TEST_CSFLE_TLS_CERTIFICATE_KEY_FILE")));
                 }));
             }
 
@@ -201,7 +182,7 @@ void add_auto_encryption_opts(document::view test, options::client* client_opts)
     }
 }
 
-void run_encryption_tests_in_file(const std::string& test_path) {
+void run_encryption_tests_in_file(std::string const& test_path) {
     INFO("Test path: " << test_path);
 
     auto test_spec = test_util::parse_test_file(test_path);
@@ -213,7 +194,7 @@ void run_encryption_tests_in_file(const std::string& test_path) {
     auto tests = test_spec_view["tests"].get_array().value;
 
     /* we may not have a supported topology */
-    CHECK_IF_SKIP_SPEC_TEST((client{uri{}, test_util::add_test_server_api()}), test_spec_view);
+    CHECK_IF_SKIP_SPEC_TEST(test_spec_view);
 
     mongocxx::client setup_client{
         uri{},
@@ -224,11 +205,10 @@ void run_encryption_tests_in_file(const std::string& test_path) {
     wc_majority.acknowledge_level(write_concern::level::k_majority);
 
     for (auto&& test : tests) {
-        const auto description = string::to_string(test["description"].get_string().value);
+        auto const description = string::to_string(test["description"].get_string().value);
 
         DYNAMIC_SECTION(description) {
-            CHECK_IF_SKIP_SPEC_TEST((client{uri{}, test_util::add_test_server_api()}),
-                                    test.get_document().value);
+            CHECK_IF_SKIP_SPEC_TEST(test.get_document().value);
 
             options::client client_opts;
 
@@ -237,8 +217,7 @@ void run_encryption_tests_in_file(const std::string& test_path) {
 
             add_auto_encryption_opts(test.get_document().value, &client_opts);
 
-            if (strcmp(test["description"].get_string().value.data(),
-                       "operation fails with maxWireVersion < 8") == 0) {
+            if (strcmp(test["description"].get_string().value.data(), "operation fails with maxWireVersion < 8") == 0) {
                 // We cannot create a client with auto encryption enabled on 4.0,
                 // and it fails in different ways on Windows and POSIX, so rather
                 // than running this test, skip it.
@@ -246,8 +225,9 @@ void run_encryption_tests_in_file(const std::string& test_path) {
             }
 
             bool check_results_logging = false;
-            if (strcmp(test["description"].get_string().value.data(),
-                       "Insert with deterministic encryption, then find it") == 0) {
+            if (strcmp(
+                    test["description"].get_string().value.data(),
+                    "Insert with deterministic encryption, then find it") == 0) {
                 // CDRIVER-3566 Remove this once windows is debugged.
                 check_results_logging = true;
             }
@@ -275,9 +255,8 @@ void run_encryption_tests_in_file(const std::string& test_path) {
                     UNSCOPED_INFO("collection contents before:\n" << contents);
                 }
 
-                run_operation_check_result(op.get_document().value, [&]() {
-                    return operation_runner{&db, &test_coll};
-                });
+                run_operation_check_result(
+                    op.get_document().value, [&]() { return operation_runner{&db, &test_coll}; });
 
                 if (check_results_logging) {
                     std::string contents;
@@ -312,8 +291,7 @@ void run_encryption_tests_in_file(const std::string& test_path) {
                 outcome_coll.read_concern(rc);
                 outcome_coll.read_preference(std::move(rp));
 
-                test_util::check_outcome_collection(
-                    &outcome_coll, test["outcome"]["collection"].get_document().value);
+                test_util::check_outcome_collection(&outcome_coll, test["outcome"]["collection"].get_document().value);
             }
         }
     }
@@ -324,8 +302,7 @@ TEST_CASE("Client side encryption spec automated tests", "[client_side_encryptio
 
     CLIENT_SIDE_ENCRYPTION_ENABLED_OR_SKIP();
 
-    std::set<std::string> unsupported_tests = {
-        "badQueries.json", "count.json", "unsupportedCommand.json"};
+    std::set<std::string> unsupported_tests = {"badQueries.json", "count.json", "unsupportedCommand.json"};
 
     char* encryption_tests_path = std::getenv("CLIENT_SIDE_ENCRYPTION_LEGACY_TESTS_PATH");
     REQUIRE(encryption_tests_path);
@@ -341,8 +318,7 @@ TEST_CASE("Client side encryption spec automated tests", "[client_side_encryptio
     std::string test_file;
     while (std::getline(test_files, test_file)) {
         DYNAMIC_SECTION(test_file) {
-            if (std::find(unsupported_tests.begin(), unsupported_tests.end(), test_file) !=
-                unsupported_tests.end()) {
+            if (std::find(unsupported_tests.begin(), unsupported_tests.end(), test_file) != unsupported_tests.end()) {
                 SKIP("unsupported test file: " << test_file);
             }
 
@@ -351,4 +327,4 @@ TEST_CASE("Client side encryption spec automated tests", "[client_side_encryptio
     }
 }
 
-}  // namespace
+} // namespace
