@@ -20,8 +20,6 @@
 
 #include <mongocxx/exception/error_code.hpp>
 
-#include <mongocxx/config/private/prelude.hh>
-
 #include <bsoncxx/test/catch.hh>
 #include <bsoncxx/test/to_string.hh>
 
@@ -35,36 +33,32 @@ namespace spec {
 using namespace mongocxx;
 using bsoncxx::to_json;
 
-static void remove_ignored_command_monitoring_events(apm_checker::event_vector& events,
-                                                     const std::vector<std::string>& ignore) {
+static void remove_ignored_command_monitoring_events(
+    apm_checker::event_vector& events,
+    std::vector<std::string> const& ignore) {
     auto is_ignored = [&](bsoncxx::document::value v) {
-        return std::any_of(
-            std::begin(ignore), std::end(ignore), [&](bsoncxx::stdx::string_view key) {
-                return v.view()["commandStartedEvent"]["command"][key] ||
-                       v.view()["commandFailedEvent"]["command"][key] ||
-                       v.view()["commandSucceededEvent"]["command"][key];
-            });
+        return std::any_of(std::begin(ignore), std::end(ignore), [&](bsoncxx::stdx::string_view key) {
+            return v.view()["commandStartedEvent"]["command"][key] || v.view()["commandFailedEvent"]["command"][key] ||
+                   v.view()["commandSucceededEvent"]["command"][key];
+        });
     };
 
     events.erase(std::remove_if(events.begin(), events.end(), is_ignored), std::end(events));
 }
 
 // commands postfixed with "_unified" are used to support the unified test format.
-void apm_checker::compare_unified(bsoncxx::array::view expectations,
-                                  entity::map& map,
-                                  bool ignore_extra_events) {
+void apm_checker::compare_unified(bsoncxx::array::view expectations, entity::map& map, bool ignore_extra_events) {
     remove_ignored_command_monitoring_events(_events, _ignore);
 
     CAPTURE(print_all());
 
     // This will throw an exception on unmatched fields and return true in all other cases.
-    auto compare = [&](const bsoncxx::array::element& exp, const bsoncxx::document::view actual) {
+    auto compare = [&](bsoncxx::array::element const& exp, bsoncxx::document::view const actual) {
         CAPTURE(to_json(actual), bsoncxx::to_string(exp.get_value()));
 
         // Extra fields are only allowed in root-level documents. Here, each k in keys is treated
         // as its own root-level document, allowing extra fields.
-        auto match_events = [&](bsoncxx::stdx::string_view event,
-                                std::initializer_list<std::string> keys) {
+        auto match_events = [&](bsoncxx::stdx::string_view event, std::initializer_list<std::string> keys) {
             for (auto&& k : keys)
                 if (exp[event][k])
                     assert::matches(actual[event][k].get_value(), exp[event][k].get_value(), map);
@@ -84,40 +78,39 @@ void apm_checker::compare_unified(bsoncxx::array::view expectations,
         compare(*exp_it, *ev_it);
     }
     if (exp_it != exp_end) {
-        FAIL_CHECK("Not enough events occurred (Expected "
-                   << std::distance(expectations.cbegin(), expectations.cend())
-                   << " events, but got " << (_events.size()) << " events)");
+        FAIL_CHECK(
+            "Not enough events occurred (Expected " << std::distance(expectations.cbegin(), expectations.cend())
+                                                    << " events, but got " << (_events.size()) << " events)");
     }
     if (!ignore_extra_events && ev_it != ev_end) {
-        FAIL_CHECK("Too many events occurred (Expected "
-                   << std::distance(expectations.cbegin(), expectations.cend())
-                   << " events, but got " << (_events.size()) << " events)");
+        FAIL_CHECK(
+            "Too many events occurred (Expected " << std::distance(expectations.cbegin(), expectations.cend())
+                                                  << " events, but got " << (_events.size()) << " events)");
     }
 }
 
-void apm_checker::compare(bsoncxx::array::view expectations,
-                          bool allow_extra,
-                          const test_util::match_visitor& match_visitor) {
+void apm_checker::compare(
+    bsoncxx::array::view expectations,
+    bool allow_extra,
+    test_util::match_visitor const& match_visitor) {
     auto is_ignored = [&](bsoncxx::document::value v) {
-        const auto view = v.view();
+        auto const view = v.view();
 
         // CXX-2155: Sharing a MongoClient for metadata lookup can lead to deadlock in
         // drivers using automatic encryption. Since the C++ driver does not use a separate
         // `client` for listCollections and finds on the key vault, we skip these checks.
         if (view["command_started_event"]["command"]["listCollections"]) {
-            const auto db = view["command_started_event"]["command"]["$db"];
+            auto const db = view["command_started_event"]["command"]["$db"];
 
             if (db && db.get_string().value == bsoncxx::stdx::string_view("keyvault")) {
                 return true;
             }
         }
 
-        return std::any_of(
-            std::begin(_ignore), std::end(_ignore), [&](bsoncxx::stdx::string_view key) {
-                return view["command_started_event"]["command"][key] ||
-                       view["command_failed_event"]["command"][key] ||
-                       view["command_succeeded_event"]["command"][key];
-            });
+        return std::any_of(std::begin(_ignore), std::end(_ignore), [&](bsoncxx::stdx::string_view key) {
+            return view["command_started_event"]["command"][key] || view["command_failed_event"]["command"][key] ||
+                   view["command_succeeded_event"]["command"][key];
+        });
     };
 
     auto events_iter = _events.begin();
@@ -126,18 +119,19 @@ void apm_checker::compare(bsoncxx::array::view expectations,
     for (auto expectation : expectations) {
         auto expected = expectation.get_document().view();
         if (events_iter == _events.end()) {
-            FAIL("Not enough events occurred: expected exactly "
-                 << std::distance(expectations.begin(), expectations.end()) << " events, but got "
-                 << _events.size() << " events");
+            FAIL(
+                "Not enough events occurred: expected exactly "
+                << std::distance(expectations.begin(), expectations.end()) << " events, but got " << _events.size()
+                << " events");
         }
         REQUIRE_BSON_MATCHES_V(*events_iter, expected, match_visitor);
         events_iter++;
     }
 
     if (!allow_extra && events_iter != _events.end()) {
-        FAIL_CHECK("Too many events occurred: expected exactly "
-                   << std::distance(expectations.begin(), expectations.end()) << " events, but got "
-                   << _events.size() << " events");
+        FAIL_CHECK(
+            "Too many events occurred: expected exactly " << std::distance(expectations.begin(), expectations.end())
+                                                          << " events, but got " << _events.size() << " events");
     }
 }
 
@@ -152,17 +146,16 @@ void apm_checker::has(bsoncxx::array::view expectations) {
 }
 
 bool apm_checker::should_ignore(bsoncxx::stdx::string_view command_name) const {
-    return std::any_of(
-        std::begin(_ignore), std::end(_ignore), [command_name](bsoncxx::stdx::string_view cmp) {
-            return command_name == cmp;
-        });
+    return std::any_of(std::begin(_ignore), std::end(_ignore), [command_name](bsoncxx::stdx::string_view cmp) {
+        return command_name == cmp;
+    });
 }
 
 std::string apm_checker::print_all() const {
     std::ostringstream output;
     output << "\n\n";
     output << "APM Checker contents:\n";
-    for (const auto& event : _events) {
+    for (auto const& event : _events) {
         output << "APM event: " << bsoncxx::to_json(event) << "\n\n";
     }
     return std::move(output).str();
@@ -173,19 +166,18 @@ std::string apm_checker::print_all() const {
 /// detect that it is sensitive by the mongoc library having removed the main body of the
 /// command events' requests and responses, thus we check for ".empty()" on that body.
 static bool is_hello_cmd_name(bsoncxx::stdx::string_view name) {
-    return name == bsoncxx::stdx::string_view("hello") ||
-           name == bsoncxx::stdx::string_view("ismaster") ||
+    return name == bsoncxx::stdx::string_view("hello") || name == bsoncxx::stdx::string_view("ismaster") ||
            name == bsoncxx::stdx::string_view("isMaster");
 }
-static bool is_sensitive_hello_cmd_event(const events::command_started_event& event) {
+static bool is_sensitive_hello_cmd_event(events::command_started_event const& event) {
     return event.command().empty();
 }
 
-static bool is_sensitive_hello_cmd_event(const events::command_succeeded_event& ev) {
+static bool is_sensitive_hello_cmd_event(events::command_succeeded_event const& ev) {
     return ev.reply().empty();
 }
 
-static bool is_sensitive_hello_cmd_event(const events::command_failed_event& ev) {
+static bool is_sensitive_hello_cmd_event(events::command_failed_event const& ev) {
     return ev.failure().empty();
 }
 
@@ -197,7 +189,7 @@ static bool is_sensitive_hello_cmd_event(const events::command_failed_event& ev)
  * and 'speculativeAuthenticate' is provided in the command (See is_sensitive_hello_cmd_event).
  */
 template <typename Ev>
-static bool is_sensitive_command(const Ev& event) noexcept {
+static bool is_sensitive_command(Ev const& event) noexcept {
     static bsoncxx::stdx::string_view sensitive_commands[] = {
         "authenticate",
         "saslStart",
@@ -209,10 +201,9 @@ static bool is_sensitive_command(const Ev& event) noexcept {
         "copyDbSaslStart",
         "copydb",
     };
-    const bool is_sensitive_cmd_name = std::find(std::begin(sensitive_commands),
-                                                 std::end(sensitive_commands),
-                                                 event.command_name())  //
-                                       != std::end(sensitive_commands);
+    bool const is_sensitive_cmd_name =
+        std::find(std::begin(sensitive_commands), std::end(sensitive_commands), event.command_name()) !=
+        std::end(sensitive_commands);
     if (is_sensitive_cmd_name) {
         return true;
     }
@@ -223,28 +214,7 @@ static bool is_sensitive_command(const Ev& event) noexcept {
 void apm_checker::set_command_started_unified(options::apm& apm) {
     using namespace bsoncxx::builder::basic;
 
-    apm.on_command_started([&](const events::command_started_event& event) {
-        if (!observe_sensitive_events && is_sensitive_command(event)) {
-            return;
-        }
-
-        if (should_ignore(event.command_name())) {
-            return;
-        }
-
-        document builder;
-        builder.append(kvp("commandStartedEvent",
-                           make_document(kvp("command", event.command()),
-                                         kvp("commandName", event.command_name()),
-                                         kvp("databaseName", event.database_name()))));
-        this->_events.emplace_back(builder.extract());
-    });
-}
-
-void apm_checker::set_command_failed_unified(options::apm& apm) {
-    using namespace bsoncxx::builder::basic;
-
-    apm.on_command_failed([&](const events::command_failed_event& event) {
+    apm.on_command_started([&](events::command_started_event const& event) {
         if (!observe_sensitive_events && is_sensitive_command(event)) {
             return;
         }
@@ -255,15 +225,19 @@ void apm_checker::set_command_failed_unified(options::apm& apm) {
 
         document builder;
         builder.append(
-            kvp("commandFailedEvent", make_document(kvp("commandName", event.command_name()))));
+            kvp("commandStartedEvent",
+                make_document(
+                    kvp("command", event.command()),
+                    kvp("commandName", event.command_name()),
+                    kvp("databaseName", event.database_name()))));
         this->_events.emplace_back(builder.extract());
     });
 }
 
-void apm_checker::set_command_succeeded_unified(options::apm& apm) {
+void apm_checker::set_command_failed_unified(options::apm& apm) {
     using namespace bsoncxx::builder::basic;
 
-    apm.on_command_succeeded([&](const events::command_succeeded_event& event) {
+    apm.on_command_failed([&](events::command_failed_event const& event) {
         if (!observe_sensitive_events && is_sensitive_command(event)) {
             return;
         }
@@ -273,9 +247,27 @@ void apm_checker::set_command_succeeded_unified(options::apm& apm) {
         }
 
         document builder;
-        builder.append(kvp(
-            "commandSucceededEvent",
-            make_document(kvp("reply", event.reply()), kvp("commandName", event.command_name()))));
+        builder.append(kvp("commandFailedEvent", make_document(kvp("commandName", event.command_name()))));
+        this->_events.emplace_back(builder.extract());
+    });
+}
+
+void apm_checker::set_command_succeeded_unified(options::apm& apm) {
+    using namespace bsoncxx::builder::basic;
+
+    apm.on_command_succeeded([&](events::command_succeeded_event const& event) {
+        if (!observe_sensitive_events && is_sensitive_command(event)) {
+            return;
+        }
+
+        if (should_ignore(event.command_name())) {
+            return;
+        }
+
+        document builder;
+        builder.append(
+            kvp("commandSucceededEvent",
+                make_document(kvp("reply", event.reply()), kvp("commandName", event.command_name()))));
         this->_events.emplace_back(builder.extract());
     });
 }
@@ -283,17 +275,19 @@ void apm_checker::set_command_succeeded_unified(options::apm& apm) {
 void apm_checker::set_command_started(options::apm& apm) {
     using namespace bsoncxx::builder::basic;
 
-    apm.on_command_started([&](const events::command_started_event& event) {
+    apm.on_command_started([&](events::command_started_event const& event) {
         if (should_ignore(event.command_name())) {
             return;
         }
 
         document builder;
-        builder.append(kvp("command_started_event",
-                           make_document(kvp("command", event.command()),
-                                         kvp("command_name", event.command_name()),
-                                         kvp("operation_id", event.operation_id()),
-                                         kvp("database_name", event.database_name()))));
+        builder.append(
+            kvp("command_started_event",
+                make_document(
+                    kvp("command", event.command()),
+                    kvp("command_name", event.command_name()),
+                    kvp("operation_id", event.operation_id()),
+                    kvp("database_name", event.database_name()))));
         this->_events.emplace_back(builder.extract());
     });
 }
@@ -301,15 +295,15 @@ void apm_checker::set_command_started(options::apm& apm) {
 void apm_checker::set_command_failed(options::apm& apm) {
     using namespace bsoncxx::builder::basic;
 
-    apm.on_command_failed([&](const events::command_failed_event& event) {
+    apm.on_command_failed([&](events::command_failed_event const& event) {
         if (should_ignore(event.command_name())) {
             return;
         }
 
         document builder;
-        builder.append(kvp("command_failed_event",
-                           make_document(kvp("command_name", event.command_name()),
-                                         kvp("operation_id", event.operation_id()))));
+        builder.append(
+            kvp("command_failed_event",
+                make_document(kvp("command_name", event.command_name()), kvp("operation_id", event.operation_id()))));
         this->_events.emplace_back(builder.extract());
     });
 }
@@ -317,16 +311,18 @@ void apm_checker::set_command_failed(options::apm& apm) {
 void apm_checker::set_command_succeeded(options::apm& apm) {
     using namespace bsoncxx::builder::basic;
 
-    apm.on_command_succeeded([&](const events::command_succeeded_event& event) {
+    apm.on_command_succeeded([&](events::command_succeeded_event const& event) {
         if (should_ignore(event.command_name())) {
             return;
         }
 
         document builder;
-        builder.append(kvp("command_succeeded_event",
-                           make_document(kvp("reply", event.reply()),
-                                         kvp("command_name", event.command_name()),
-                                         kvp("operation_id", event.operation_id()))));
+        builder.append(
+            kvp("command_succeeded_event",
+                make_document(
+                    kvp("reply", event.reply()),
+                    kvp("command_name", event.command_name()),
+                    kvp("operation_id", event.operation_id()))));
         this->_events.emplace_back(builder.extract());
     });
 }
@@ -343,7 +339,7 @@ options::apm apm_checker::get_apm_opts(bool command_started_events_only) {
     return opts;
 }
 
-void apm_checker::set_ignore_command_monitoring_event(const std::string& event) {
+void apm_checker::set_ignore_command_monitoring_event(std::string const& event) {
     this->_ignore.push_back(event);
 }
 
@@ -356,7 +352,5 @@ void apm_checker::clear() {
     this->_ignore.clear();
 }
 
-}  // namespace spec
-}  // namespace mongocxx
-
-#include <mongocxx/config/private/postlude.hh>
+} // namespace spec
+} // namespace mongocxx
