@@ -1,4 +1,4 @@
-// Copyright 2016 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -16,9 +16,12 @@
 #include <set>
 
 #include <bsoncxx/string/to_string.hpp>
-#include <bsoncxx/test/catch.hh>
+
 #include <mongocxx/exception/operation_exception.hpp>
 #include <mongocxx/instance.hpp>
+
+#include <bsoncxx/test/catch.hh>
+
 #include <mongocxx/test/spec/monitoring.hh>
 #include <mongocxx/test/spec/operation.hh>
 #include <mongocxx/test/spec/util.hh>
@@ -45,14 +48,10 @@ void run_retryable_reads_tests_in_file(std::string test_path) {
     document::view test_spec_view = test_spec->view();
     for (auto&& test : test_spec_view["tests"].get_array().value) {
         client client{get_uri(test.get_document().value), client_opts};
-        if (should_skip_spec_test(client, test_spec_view)) {
-            return;
-        }
+        CHECK_IF_SKIP_SPEC_TEST(test_spec_view);
 
         INFO("Test description: " << test["description"].get_string().value);
-        if (should_skip_spec_test(client, test.get_document())) {
-            continue;
-        }
+        CHECK_IF_SKIP_SPEC_TEST(test.get_document());
 
         auto get_value_or_default = [&](std::string key, std::string default_str) {
             if (test_spec_view[key]) {
@@ -79,14 +78,12 @@ void run_retryable_reads_tests_in_file(std::string test_path) {
             auto chunks_collection = database[chunks_collection_name];
 
             initialize_collection(&files_collection, data[files_collection_name].get_array().value);
-            initialize_collection(&chunks_collection,
-                                  data[chunks_collection_name].get_array().value);
+            initialize_collection(&chunks_collection, data[chunks_collection_name].get_array().value);
         } else {
             initialize_collection(&collection, test_spec_view["data"].get_array().value);
         }
 
-        operation_runner op_runner{
-            &database, &collection, nullptr /* session0 */, nullptr /* session1 */, &client};
+        operation_runner op_runner{&database, &collection, nullptr /* session0 */, nullptr /* session1 */, &client};
 
         configure_fail_point(client, test.get_document().value);
 
@@ -98,17 +95,16 @@ void run_retryable_reads_tests_in_file(std::string test_path) {
             optional<document::value> actual_outcome_value;
             try {
                 actual_outcome_value = op_runner.run(operation);
-            } catch (const operation_exception& e) {
+            } catch (operation_exception const& e) {
+                CAPTURE(e);
                 REQUIRE(operation["error"].get_bool().value);
             }
 
             if (operation["result"]) {
                 // wrap the result, since it might not be a document.
                 bsoncxx::document::view actual_outcome = actual_outcome_value->view();
-                auto actual_result_wrapped =
-                    make_document(kvp("result", actual_outcome["result"].get_value()));
-                auto expected_result_wrapped =
-                    make_document(kvp("result", operation["result"].get_value()));
+                auto actual_result_wrapped = make_document(kvp("result", actual_outcome["result"].get_value()));
+                auto expected_result_wrapped = make_document(kvp("result", operation["result"].get_value()));
                 REQUIRE_BSON_MATCHES(actual_result_wrapped, expected_result_wrapped);
             }
         }
@@ -119,22 +115,22 @@ void run_retryable_reads_tests_in_file(std::string test_path) {
     }
 }
 
-TEST_CASE("retryable reads spec tests", "[retryable_reads_spec]") {
+TEST_CASE("retryable reads spec tests", "[retryable_reads_specs]") {
     instance::current();
 
-    std::set<std::string> unsupported_tests{"gridfs-downloadByName.json",
-                                            "gridfs-downloadByName-serverErrors.json",
-                                            "listCollectionObjects.json",
-                                            "listCollectionObjects-serverErrors.json",
-                                            "listDatabaseObjects.json",
-                                            "listDatabaseObjects-serverErrors.json",
-                                            "listIndexNames.json",
-                                            "listIndexNames-serverErrors.json",
-                                            "mapReduce.json",
-                                            "count.json",
-                                            "count-serverErrors.json"};
+    std::set<std::string> unsupported_tests{
+        "gridfs-downloadByName.json",
+        "gridfs-downloadByName-serverErrors.json",
+        "listCollectionObjects.json",
+        "listCollectionObjects-serverErrors.json",
+        "listDatabaseObjects.json",
+        "listDatabaseObjects-serverErrors.json",
+        "listIndexNames.json",
+        "listIndexNames-serverErrors.json",
+        "mapReduce.json",
+        "count.json",
+        "count-serverErrors.json"};
 
-    run_tests_in_suite(
-        "RETRYABLE_READS_LEGACY_TESTS_PATH", run_retryable_reads_tests_in_file, unsupported_tests);
+    run_tests_in_suite("RETRYABLE_READS_LEGACY_TESTS_PATH", run_retryable_reads_tests_in_file, unsupported_tests);
 }
-}  // namespace
+} // namespace
