@@ -1,4 +1,4 @@
-// Copyright 2021 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -13,45 +13,46 @@
 // limitations under the License.
 
 #include <bsoncxx/string/to_string.hpp>
-#include <bsoncxx/test/catch.hh>
+
 #include <mongocxx/client.hpp>
 #include <mongocxx/exception/operation_exception.hpp>
 #include <mongocxx/instance.hpp>
 #include <mongocxx/options/client.hpp>
 #include <mongocxx/options/server_api.hpp>
-#include <mongocxx/test/client_helpers.hh>
 #include <mongocxx/uri.hpp>
 
+#include <bsoncxx/test/catch.hh>
+
+#include <mongocxx/test/client_helpers.hh>
+
+#include <catch2/matchers/catch_matchers_string.hpp>
+
 using namespace mongocxx;
 
-static bool has_api_version_1(
-    const mongocxx::client& client = mongocxx::client(uri(), test_util::add_test_server_api())) {
+static bool has_api_version_1() {
     // API Version 1 was introduced in 5.0.
-    return test_util::get_max_wire_version(client) >= 13;
+    return test_util::get_max_wire_version() >= 13;
 }
 
-static bool has_api_version_1_with_count(
-    const mongocxx::client& client = mongocxx::client(uri(), test_util::add_test_server_api())) {
-    if (!has_api_version_1(client)) {
+static bool has_api_version_1_with_count() {
+    if (!has_api_version_1()) {
         return false;
     }
 
-    const auto version = test_util::get_server_version(client);
+    auto const version = test_util::get_server_version();
 
     // BACKPORT-12171: count command was backported to 5.0.9.
-    if (test_util::compare_versions(version, "5.0") == 0 &&
-        test_util::compare_versions(version, "5.0.9") >= 0) {
+    if (test_util::compare_versions(version, "5.0") == 0 && test_util::compare_versions(version, "5.0.9") >= 0) {
         return true;
     }
 
     // BACKPORT-12170: count command was backported to 5.3.2.
-    if (test_util::compare_versions(version, "5.3") == 0 &&
-        test_util::compare_versions(version, "5.3.2") >= 0) {
+    if (test_util::compare_versions(version, "5.3") == 0 && test_util::compare_versions(version, "5.3.2") >= 0) {
         return true;
     }
 
     // SERVER-63850: count command was added in 6.0.
-    return test_util::newer_than(client, "6.0");
+    return test_util::newer_than("6.0");
 }
 
 // We'll format many of these examples by hand
@@ -143,7 +144,7 @@ TEST_CASE("Versioned API, non-strict with deprecation errors") {
 
 /// Not actually a version function. Just used to appear in the documentation examples "as if" we
 /// were creating a date from a timestamp string
-static bsoncxx::types::b_date iso_string_to_bson_datetime(const std::string&) {
+static bsoncxx::types::b_date iso_string_to_bson_datetime(std::string const&) {
     return bsoncxx::types::b_date(std::chrono::milliseconds{0});
 }
 
@@ -162,8 +163,7 @@ TEST_CASE("Versioned API, with insert-many for 'count' migration") {
     using namespace mongocxx;
     mongocxx::client client{
         uri{},
-        options::client{}.server_api_opts(
-            options::server_api{options::server_api::version::k_version_1}.strict(true))};
+        options::client{}.server_api_opts(options::server_api{options::server_api::version::k_version_1}.strict(true))};
     using namespace bsoncxx::builder::basic;
 
     // Drop in case we have stale data
@@ -200,12 +200,12 @@ TEST_CASE("Versioned API, with insert-many for 'count' migration") {
     try {
         db.run_command(make_document(kvp("count", "sales")));
         FAIL_CHECK("Did not throw for apiStrict:true usage of old command");
-    } catch (const mongocxx::operation_exception& error) {
+    } catch (mongocxx::operation_exception const& error) {
         INFO(error.what());
         CHECK(error.code().value() == 323);
-        CHECK_THAT(error.what(),
-                   Catch::StartsWith(
-                       "Provided apiStrict:true, but the command count is not in API Version 1."));
+        CHECK_THAT(
+            error.what(),
+            Catch::Matchers::StartsWith("Provided apiStrict:true, but the command count is not in API Version 1."));
     }
 
 #if 0
@@ -213,7 +213,7 @@ TEST_CASE("Versioned API, with insert-many for 'count' migration") {
     /// Don't delete me!
     // clang-format off
     // Begin Versioned API Example 6
-    } catch (const mongocxx::operation_exception& error) {
+    } catch (mongocxx::operation_exception const& error) {
         cerr << error.what();
         // Prints:
         //    Provided apiStrict:true, but the command count is not in API Version 1.
