@@ -1,4 +1,4 @@
-// Copyright 2014 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -14,12 +14,14 @@
 
 #include <bsoncxx/builder/basic/document.hpp>
 #include <bsoncxx/builder/basic/kvp.hpp>
-#include <bsoncxx/test/catch.hh>
+
 #include <mongocxx/exception/exception.hpp>
 #include <mongocxx/exception/logic_error.hpp>
 #include <mongocxx/instance.hpp>
 #include <mongocxx/write_concern.hpp>
 
+#include <bsoncxx/test/catch.hh>
+
 namespace {
 using namespace mongocxx;
 
@@ -64,7 +66,7 @@ TEST_CASE("write_concern fields may be set and retrieved", "[write_concern]") {
     }
 
     SECTION("a tag may be set") {
-        const std::string tag{"MultipleDC"};
+        std::string const tag{"MultipleDC"};
         wc.tag(tag);
         auto maybe_tag = wc.tag();
         REQUIRE(maybe_tag);
@@ -131,8 +133,7 @@ TEST_CASE("acknowledge_level responds to changes in nodes, majority, tag", "[wri
     }
 }
 
-TEST_CASE("confirmation from tags, a repl-member count, and majority are mutually exclusive",
-          "[write_concern]") {
+TEST_CASE("confirmation from tags, a repl-member count, and majority are mutually exclusive", "[write_concern]") {
     instance::current();
 
     SECTION("setting the confirmation number unsets the confirmation tag") {
@@ -358,8 +359,7 @@ TEST_CASE("write_concern to_document works") {
     }
 
     SECTION("majority and journal true") {
-        expected_doc = make_document(
-            kvp("w", "majority"), kvp("j", true), kvp("wtimeout", types::b_int32{10}));
+        expected_doc = make_document(kvp("w", "majority"), kvp("j", true), kvp("wtimeout", types::b_int32{10}));
         wc.journal(true);
         wc.majority(std::chrono::milliseconds{10});
         REQUIRE(wc.is_acknowledged());
@@ -377,8 +377,7 @@ TEST_CASE("write_concern to_document works") {
     }
 
     SECTION("Everything") {
-        expected_doc =
-            make_document(kvp("w", 3), kvp("j", true), kvp("wtimeout", types::b_int32{1000}));
+        expected_doc = make_document(kvp("w", 3), kvp("j", true), kvp("wtimeout", types::b_int32{1000}));
         wc.nodes(3);
         wc.timeout(std::chrono::milliseconds{1000});
         wc.journal(true);
@@ -411,4 +410,4 @@ TEST_CASE("write_concern changes reflected in to_document") {
     REQUIRE(generated_nodes.view() == nodes.view());
 }
 
-}  // namespace
+} // namespace
